/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
var kimchi = {

    widget: {},

    trackingTasks: [],

    /**
     * Get Kimchi details
     */
    getConfig : function(suc, err, done) {
        done = typeof done !== 'undefined' ? done: function(){};
        wok.requestJSON({
            url : "plugins/kimchi/config",
            type : "GET",
            contentType : "application/json",
            dataType : "json",
            success: suc,
            error: err,
            complete: done
        });
    },

    /**
     *
     * Get host capabilities
     * suc: callback if succeed err: callback if failed
     */
    getCapabilities : function(suc, err, done) {
        done = typeof done !== 'undefined' ? done: function(){};
        wok.requestJSON({
            url : "plugins/kimchi/config/capabilities",
            type : "GET",
            contentType : "application/json",
            dataType : "json",
            success: suc,
            error: err,
            complete: done
        });
    },

    /**
     * Get the i18 strings.
     */
    getI18n: function(suc, err, url, sync) {
        wok.requestJSON({
            url : url ? url : 'plugins/kimchi/i18n.json',
            type : 'GET',
            resend: true,
            dataType : 'json',
            async : !sync,
            success : suc,
            error: err
        });
    },

    /**
     *
     * Create a new Virtual Machine. Usage: kimchi.createVM({ name: 'MyUbuntu',
     * template: '/templates/ubuntu_base' }, creationSuc, creationErr);
     *
     * settings: name *(optional)*: The name of the VM. Used to identify the VM
     * in this API. If omitted, a name will be chosen based on the template
     * used. template: The URI of a Template to use when building the VM
     * storagepool *(optional)*: Assign a specific Storage Pool to the new VM
     * suc: callback if succeed err: callback if failed
     */
    createVM : function(settings, suc, err) {
        wok.requestJSON({
            url : "plugins/kimchi/vms",
            type : "POST",
            contentType : "application/json",
            data : JSON.stringify(settings),
            dataType : "json"
        }).done(suc).fail(err);
    },

    /**
     *
     * Create a new Template. settings name: The name of the Template. Used to
     * identify the Template in this API suc: callback if succeed err: callback
     * if failed
     */
    createTemplate : function(settings, suc, err) {
        wok.requestJSON({
            url : "plugins/kimchi/templates",
            type : "POST",
            contentType : "application/json",
            data : JSON.stringify(settings),
            dataType : "json",
            success: suc,
            error: err
        });
    },

    deleteTemplate : function(tem, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/templates/' + encodeURIComponent(tem),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    cloneTemplate : function(tem, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/templates/' + encodeURIComponent(tem) + "/clone",
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    listTemplates : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/templates',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    /**
     * Retrieve the information of a template by the given name.
     */
    retrieveTemplate : function(templateName, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/templates/' + encodeURIComponent(templateName),
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json'
        }).done(suc);
    },

    /**
     * Update a template with new information. TODO: Update me when the RESTful
     * API is available. Now work it around by remove the template and then
     * recreate it with new information.
     */
    updateTemplate : function(name, settings, suc, err) {
        $.ajax({
            url : 'plugins/kimchi/templates/' + encodeURIComponent(name),
            type : 'PUT',
            contentType : 'application/json',
            data : JSON.stringify(settings),
            dataType : 'json'
        }).done(suc).fail(err);
    },

    /**
     * Create a new Storage Pool. settings name: The name of the Storage Pool
     * path: The path of the defined Storage Pool type: The type of the defined
     * Storage Pool capacity: The total space which can be used to store volumes
     * The unit is MBytes suc: callback if succeed err: callback if failed
     */
    createStoragePool : function(settings, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/storagepools',
            type : 'POST',
            contentType : 'application/json',
            data : JSON.stringify(settings),
            dataType : 'json'
        }).done(suc).fail(err);
    },

    updateStoragePool : function(name, content, suc, err) {
        $.ajax({
            url : "plugins/kimchi/storagepools/" + encodeURIComponent(name),
            type : 'PUT',
            contentType : 'application/json',
            dataType : 'json',
            data : JSON.stringify(content)
        }).done(suc).fail(err ? err : function(data) {
            wok.message.error(data.responseJSON.reason);
        });
    },

    startVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/start',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    poweroffVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/poweroff',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    shutdownVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/shutdown',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    resetVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/reset',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    suspendVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/suspend',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    resumeVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/resume',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
     },

    /**
     * Retrieve the information of a given VM by its name.
     *
     * @param vm VM name
     * @param suc callback for success
     * @param err callback for error
     */
    retrieveVM : function(vm, suc, err) {
        $.ajax({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm),
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success: suc,
            error: err
        });
    },

    /**
     * Update a VM with new information.
     */
    updateVM : function(name, settings, suc, err) {
        $.ajax({
            url : "plugins/kimchi/vms/" + encodeURIComponent(name),
            type : 'PUT',
            contentType : 'application/json',
            data : JSON.stringify(settings),
            dataType : 'json',
            success: suc,
            error: err
        });
    },

    deleteVM : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    serialToVM : function(vm) {
        wok.requestJSON({
            url : 'config/',
            type : 'GET',
            dataType : 'json'
        }).done(function(data, textStatus, xhr) {
            proxy_port = data['proxy_port'];
            server_root = data['server_root'];
            wok.requestJSON({
                url : "plugins/kimchi/vms/" + encodeURIComponent(vm) + "/serial",
                type : "POST",
                dataType : "json"
            }).done(function() {
                url = 'https://' + location.hostname + ':' + proxy_port;
                url += server_root;
                url += "/plugins/kimchi/serial/html/serial.html";
                url += "?port=" + proxy_port;
                url += "&path=" + server_root + "websockify";
                url += "?token=" + wok.urlSafeB64Encode(vm+'-console').replace(/=*$/g, "");
                url += '&encrypt=1';
                window.open(url);
            }).fail(function(data) {
                wok.message.error(data.responseJSON.reason);
            });
        }).fail(function(data) {
            wok.message.error(data.responseJSON.reason);
        });
    },

    vncToVM : function(vm) {
        proxy_port = location.port || (location.protocol === 'https:' ? '443' : '80');
        server_root = wok.config['server_root'];
        wok.requestJSON({
            url : "plugins/kimchi/vms/" + encodeURIComponent(vm) + "/connect",
            type : "POST",
            dataType : "json"
        }).done(function() {
            url = 'https://' + location.hostname + ':' + proxy_port;
            url += server_root;
            url += "/plugins/kimchi/novnc/vnc_auto.html";
            url += "?port=" + proxy_port;
            url += "&path=" + server_root + "websockify";
            /*
             * From python documentation base64.urlsafe_b64encode(s)
             * substitutes - instead of + and _ instead of / in the
             * standard Base64 alphabet, BUT the result can still
             * contain = which is not safe in a URL query component.
             * So remove it when needed as base64 can work well without it.
             * */
            url += "?token=" + wok.urlSafeB64Encode(vm).replace(/=*$/g, "");
            url += '&encrypt=1';
            window.open(url);
        });
    },

    spiceToVM : function(vm) {
        proxy_port = location.port || (location.protocol === 'https:' ? '443' : '80');
        server_root = wok.config['server_root'];
        wok.requestJSON({
            url : "plugins/kimchi/vms/" + encodeURIComponent(vm) + "/connect",
            type : "POST",
            dataType : "json"
        }).done(function(data, textStatus, xhr) {
            url = 'https://' + location.hostname + ':' + proxy_port;
            url += server_root;
            if(kimchi.config['with_spice_web_client'])
            {
                /*
                 * Slightly different api for spice-web-client
                 */
                url += "/plugins/kimchi/spice-web-client/index.html";
                url += "?port=" + proxy_port + server_root;
                url += "&host=" + location.hostname;
                url += "&vmInfoToken=" + wok.urlSafeB64Encode(vm).replace(/=*$/g, "");
                url += '&protocol=wss';
            }
            else
            {
                // Using spice-html5 by default
                url += "/plugins/kimchi/spice_auto.html";
                /*
                 * When using server_root we need pass the value with port
                 * argument to be used correctly by spice_auto.html scripts
                 */
                url += "?port=" + proxy_port + server_root;
                url += "&listen=" + location.hostname;
                /*
                 * From python documentation base64.urlsafe_b64encode(s)
                 * substitutes - instead of + and _ instead of / in the
                 * standard Base64 alphabet, BUT the result can still
                 * contain = which is not safe in a URL query component.
                 * So remove it when needed as base64 can work well without it.
                 * */
                url += "&token=" + wok.urlSafeB64Encode(vm).replace(/=*$/g, "");
                url += '&encrypt=1';
            }
            window.open(url);
        });
    },

    listVMs : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms',
            type : 'GET',
            contentType : 'application/json',
            headers: {'Wok-Robot': 'wok-robot'},
            dataType : 'json',
            resend: true,
            success : suc,
            error : err
        });
    },

    listTemplates : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/templates',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend: true,
            success : suc,
            error : err
        });
    },

    listStoragePools : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/storagepools',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend: true,
            success : suc,
            error : err
        });
    },

    listStorageVolumes : function(poolName, suc, err, sync) {
        $.ajax({
            url : 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
	    async : !sync,
            success : suc,
            error : err
        });
    },

    listIsos : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/storagepools/kimchi_isos/storagevolumes',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    listDistros : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/config/distros',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    stepListDeepScanIsos : function(suc, err) {
        var deepScanHandler = {
            stop : false
        };
        var isoPool = 'iso' + new Date().getTime();
        kimchi.createStoragePool({
            name : isoPool,
            type : 'kimchi-iso',
            path : '/'
        }, function(result) {
            var taskId = result.task_id;
            function monitorTask() {
                if (deepScanHandler.stop) {
                    return;
                }
                kimchi.getTask(taskId, function(result) {
                    var status = result.status;
                    if (status === "finished") {
                        if (deepScanHandler.stop) {
                            return;
                        }
                        kimchi.listStorageVolumes(isoPool, function(isos) {
                            if (deepScanHandler.stop) {
                                return;
                            }
                            suc(isos, true);
                        }, err, false);
                    } else if (status === "running") {
                        if (deepScanHandler.stop) {
                            return;
                        }
                        kimchi.listStorageVolumes(isoPool, function(isos) {
                            if (deepScanHandler.stop) {
                                return;
                            }
                            suc(isos, false);
                            setTimeout(monitorTask, 2000);
                        }, err, false);
                    } else if (status === "failed") {
                        if (deepScanHandler.stop) {
                            return;
                        }
                        err(result.message);
                    }
                }, err);
            }
            setTimeout(monitorTask, 2000);
        }, err);
        return deepScanHandler;
    },

    getTask : function(taskId, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/tasks/' + encodeURIComponent(taskId),
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getTasksByFilter : function(filter, suc, err, sync) {
        wok.requestJSON({
            url : 'plugins/kimchi/tasks?' + filter,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            async : !sync,
            success : suc,
            error : err
        });
    },

    trackTask : function(taskID, suc, err, progress) {
        var onTaskResponse = function(result) {
            var taskStatus = result['status'];
            switch(taskStatus) {
            case 'running':
                $('html').addClass('in-progress');
                progress && progress(result);
                setTimeout(function() {
                    kimchi.trackTask(taskID, suc, err, progress);
                }, 2000);
                break;
            case 'finished':
                $('html').removeClass('in-progress');
                suc && suc(result);
                break;
            case 'failed':
                $('html').removeClass('in-progress');
                err && err(result);
                break;
            default:
                $('html').removeClass('in-progress');
                break;
            }
        };

        kimchi.getTask(taskID, onTaskResponse, err);
        if(kimchi.trackingTasks.indexOf(taskID) < 0) {
            kimchi.trackingTasks.push(taskID);
        }
    },

    deleteStoragePool : function(poolName, suc, err) {
        $.ajax({
            url : 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    changePoolState : function(poolName, state, suc, err) {
        if (state === 'activate' || state === 'deactivate') {
            $.ajax({
                url : 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/' + state,
                type : 'POST',
                contentType : 'application/json',
                dataType : 'json',
                success : suc,
                error : err
            });
        }
    },

    listNetworks : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/networks',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    listmacvtapNetworks: function(suc, err) {
        wok.requestJSON({
            url: 'plugins/kimchi/interfaces?type=^nic|bonding|vlan$',
            type: 'GET',
            contentType: 'application/json',
            dataType: 'json',
            resend: true,
            success: suc,
            error: err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    listovsNetworks: function(suc, err) {
        wok.requestJSON({
            url: 'plugins/kimchi/ovsbridges',
            type: 'GET',
            contentType: 'application/json',
            dataType: 'json',
            resend: true,
            success: suc,
            error: err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    toggleNetwork : function(name, on, suc, err) {
        var action = on ? "activate" : "deactivate";
        wok.requestJSON({
            url : 'plugins/kimchi/networks/' + encodeURIComponent(name) + '/' + action,
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    createNetwork : function(network, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/networks',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            data : JSON.stringify(network),
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    getInterfaces : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/interfaces?_inuse=false',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    getInterface : function(iface, suc, err, sync) {
        wok.requestJSON({
            url : 'plugins/kimchi/interfaces/' + encodeURIComponent(iface),
            type : 'GET',
            contentType : 'application/json',
            async : !sync,
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getVEPAInterfaces : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/interfaces?_inuse=false&module=^(?!mlx5_core|mlx5-core).*$',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    retrieveNetwork : function(name, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/networks/' + encodeURIComponent(name),
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success: suc,
            error: err
        });
    },

    deleteNetwork : function(name, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/networks/' + encodeURIComponent(name),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    updateNetwork : function(name, settings, suc, err) {
         wok.requestJSON({
            url : "plugins/kimchi/networks/" + encodeURIComponent(name),
            type : 'PUT',
            contentType : 'application/json',
            data : JSON.stringify(settings),
            dataType : 'json',
            success: suc,
            error: err
        });
    },

    listHostPartitions : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/host/partitions',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getStorageServers: function(type, suc, err) {
        var url = 'plugins/kimchi/storageservers?_target_type=' + type;
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    getStorageTargets: function(server,type, suc, err) {
        var url = 'plugins/kimchi/storageservers/' + server + '/storagetargets?_target_type=' + type;
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            timeout: 2000,
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getStoragePool: function(poolName, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName);
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            timeout: 2000,
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getStoragePoolVolume: function(poolName, volumeName, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName);
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            timeout: 2000,
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    cloneStoragePoolVolume: function(poolName, volumeName, data, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName) + '/clone';
        wok.requestJSON({
            url : url,
            type : 'POST',
            data : JSON.stringify(data),
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    resizeStoragePoolVolume: function(poolName, volumeName, data, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName) + '/resize';
        wok.requestJSON({
            url : url,
            type : 'POST',
            data : JSON.stringify(data),
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    wipeStoragePoolVolume: function(poolName, volumeName, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName) + '/wipe';
        wok.requestJSON({
            url : url,
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    deleteStoragePoolVolume: function(poolName, volumeName, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName);
        wok.requestJSON({
            url : url,
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getHostVgs: function(suc, err) {
        var url = 'plugins/kimchi/host/vgs/';
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            timeout: 2000,
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    addVMStorage : function(settings, suc, err) {
        var vm = encodeURIComponent(settings['vm']);
        delete settings['vm'];
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + vm + '/storages',
            type : 'POST',
            contentType : 'application/json',
            data : JSON.stringify(settings),
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    retrieveVMStorage : function(settings, suc, err) {
        var vm = encodeURIComponent(settings['vm']);
        var dev = encodeURIComponent(settings['dev']);
        wok.requestJSON({
            url : "plugins/kimchi/vms/" + vm + '/storages/' + dev,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success: suc,
            error: err
        });
    },

    replaceVMStorage : function(settings, suc, err) {
        var vm = encodeURIComponent(settings['vm']);
        var dev = encodeURIComponent(settings['dev']);
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + vm + '/storages/' + dev,
            type : 'PUT',
            contentType : 'application/json',
            data : JSON.stringify({
                path: settings['path']
            }),
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    deleteVMStorage : function(settings, suc, err) {
        var vm = settings['vm'];
        var dev = settings['dev'];
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) +
                  '/storages/' + encodeURIComponent(dev),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    listVMStorages : function(params, suc, err) {
        var vm = encodeURIComponent(params['vm']);
        var type = params['storageType'];
        var url = 'plugins/kimchi/vms/' + vm + '/storages';
        if(type) {
            url += '?type=' + type;
        }
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    getHostFCDevices: function(suc, err) {
        var url = 'plugins/kimchi/host/devices?_cap=fc_host';
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    getGuestInterfaces: function(name, suc, err) {
        var url = 'plugins/kimchi/vms/' + encodeURIComponent(name) + '/ifaces';
        wok.requestJSON({
            url : url,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err || function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    createGuestInterface : function(name, interface, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(name) + '/ifaces',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            data : JSON.stringify(interface),
            success : suc,
            error : err || function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    deleteGuestInterface : function(vm, mac, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/ifaces/' + encodeURIComponent(mac),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    updateGuestInterface : function(vm, mac, interface, suc, err) {
        $.ajax({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/ifaces/' + encodeURIComponent(mac),
            type : 'PUT',
            contentType : 'application/json',
            data : JSON.stringify(interface),
            dataType : 'json',
            success: suc,
            error: err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getUserById : function(data, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/users?_user_id=' + data.user_id,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            async : false,
            success : suc && suc(data),
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getUsers : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/users',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getGroups : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/groups',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getHostPCIDevices : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/host/devices?_passthrough=true&_cap=pci',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getAvailableHostPCIDevices : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/host/devices?_passthrough=true&_cap=pci&_available_only=true',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getPCIDeviceCompanions : function(pcidev, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/host/devices?_passthrough_affected_by=' + pcidev,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getISCSITargets : function(server, port, suc, err) {
        server = encodeURIComponent(server);
        port = port ? '&_server_port='+encodeURIComponent(port) : '';
        wok.requestJSON({
            url : 'plugins/kimchi/storageservers/' + server + '/storagetargets?_target_type=iscsi' + port,
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    getVMPCIDevices : function(id, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(id) + '/hostdevs',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    addVMPCIDevice : function(vm, device, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/'+ encodeURIComponent(vm) +'/hostdevs',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            data : JSON.stringify(device),
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    removeVMPCIDevice : function(vm, device, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/'+ encodeURIComponent(vm) +'/hostdevs/' + encodeURIComponent(device),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason,'#alert-modal-container');
            }
        });
    },

    /**
     * Create a new volume with capacity
     */
    createVolumeWithCapacity: function(poolName, settings, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes',
            type : 'POST',
            contentType : "application/json",
            data : JSON.stringify(settings),
            dataType : "json",
            success : suc,
            error : err
        });
    },

    /**
     * Upload volume content
     */
    uploadVolumeToSP: function(poolName, volumeName, settings, suc, err) {
        var url = 'plugins/kimchi/storagepools/' + encodeURIComponent(poolName) + '/storagevolumes/' + encodeURIComponent(volumeName);
        var fd = settings['formData'];
        wok.requestJSON({
            url : url,
            type : 'PUT',
            data : fd,
            processData : false,
            contentType : false,
            dataType: 'json',
            success : suc,
            error : err
        });
    },

    /**
     * Add a volume to a given storage pool by URL.
     */
    downloadVolumeToSP: function(settings, suc, err) {
        var sp = encodeURIComponent(settings['sp']);
        delete settings['sp'];
        wok.requestJSON({
            url : 'plugins/kimchi/storagepools/' + sp + '/storagevolumes',
            type : 'POST',
            data : JSON.stringify(settings),
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err
        });
    },

    cloneGuest: function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + "/clone",
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    migrateGuest: function(vm, data, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + "/migrate",
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            data : JSON.stringify(data),
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    },

    listSnapshots : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/snapshots',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason, '#alert-modal-container');
            }
        });
    },

    getCurrentSnapshot : function(vm, suc, err, sync) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/snapshots/current',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            async : !sync,
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason, '#alert-modal-container');
            }
        });
    },

    revertSnapshot : function(vm, snapshot, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/snapshots/' + encodeURIComponent(snapshot) + '/revert',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason, '#alert-modal-container');
            }
        });
    },

    createSnapshot : function(vm, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/snapshots',
            type : 'POST',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason, '#alert-modal-container');
            }
        });
    },

    deleteSnapshot : function(vm, snapshot, suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/vms/' + encodeURIComponent(vm) + '/snapshots/' + encodeURIComponent(snapshot),
            type : 'DELETE',
            contentType : 'application/json',
            dataType : 'json',
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason, '#alert-modal-container');
            }
        });
    },

    getCPUInfo : function(suc, err) {
        wok.requestJSON({
            url : 'plugins/kimchi/host/cpuinfo',
            type : 'GET',
            contentType : 'application/json',
            dataType : 'json',
            resend : true,
            success : suc,
            error : err ? err : function(data) {
                wok.message.error(data.responseJSON.reason);
            }
        });
    }
};

    /**
    * Get the host information.
    */

    kimchi.serverConfig = function(suc, err) {
        wok.requestJSON({
          url: 'plugins/kimchi/host',
          type: 'GET',
          resend: true,
          contentType: 'application/json',
          dataType: 'json',
          success: suc,
          error: err
      });
    }
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2016
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.guest_add_main = function() {
    var showTemplates = function() {
        wok.topic('templateCreated').unsubscribe(showTemplates);
        kimchi.listTemplates(function(result) {
            if (result && result.length) {
                $('#prompt-create-template').addClass('hidden');
                $('#prompt-choose-template').removeClass('hidden');
                $('#guest-add-window .guest-pager').animate({
                            height: "530px"
                });

                var html = '';
                var tmpl = $('#tmpl-template').html();
                $.each(result, function(index, value) {
                    value.invalid_indicator = "invalid";
                    if ($.isEmptyObject(value.invalid)) {
                        value.invalid_indicator = "valid";
                    }
                    html += wok.substitute(tmpl, value);
                });
                $('#templateTile').html(html);
                $('.iso-radio-hidden[data-invalid="invalid"]').attr("disabled", true);
                $('.template-status[data-invalid="valid"]').hide();
                $('[data-toggle="tooltip"]').tooltip();
                return;
            }

            $('#btn-create-template').on('click', function(event) {
                wok.topic('templateCreated').subscribe(showTemplates);

                wok.window.open('plugins/kimchi/template-add.html','extendCreateTemplate');

                event.preventDefault();
            });

            $('#prompt-choose-template').addClass('hidden');
            $('#prompt-create-template').removeClass('hidden');
            $('#guest-add-window .guest-pager').animate({
                height: "90px"
            });

        }, function(err) {
            wok.message.error(err.responseJSON.reason);
        });
    };

    function validateForm() {
        if (!$('input[name=template]:checked', '#templateTile').val()) {
            return false;
        }
        return true;
    }

    $('#form-vm-add').change(function() {
        if (validateForm()) {
            $('#vm-doAdd').attr('disabled', false);
        }
    });

    var addGuest = function(event) {
        $('#vm-doAdd').attr('disabled', true);
        $('#vm-doAdd').attr('style', 'display:none');
        $('#vm-doAdding').attr('style', 'display');
        var formData = $('#form-vm-add').serializeObject();
        kimchi.createVM(formData, function() {
            kimchi.listVmsAuto();
            wok.window.close();
        }, function(jqXHR, textStatus, errorThrown) {
            $('#vm-doAdd').attr('style', 'display');
            $('#vm-doAdding').attr('style', 'display:none');
            var reason = jqXHR &&
                jqXHR['responseJSON'] &&
                jqXHR['responseJSON']['reason'];
            wok.message.error(reason);
        });

        return false;
    };

    $('#form-vm-add').on('submit', addGuest);
    $('#vm-doAdd').on('click', addGuest);

    showTemplates();
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.guest_edit_main = function() {
    var authType;
    var formTargetId;
    var guestEditForm = $('#form-guest-edit-general');
    var saveButton = $('#guest-edit-button-save');
    var s390xArch = 's390x';
    var macvtapNetworks = "";
    var ovsNetworks = "";
    var networkOptions = "";

    clearTimeout(kimchi.vmTimeout);
    var bootOrderOptions = [];

    $('#guest-edit-window a[data-toggle="tab"]').on('show.bs.tab', function(tab) {
        tab.target; // newly activated tab
        tab.relatedTarget; // previous active tab
        var display_list = ['form-guest-edit-general', 'form-guest-edit-permission'];
        $(saveButton).prop('disabled', true);
        formTargetId = $(tab.target).data('id');
        var deactivated = $('form#' + formTargetId);
        if (display_list.indexOf($(deactivated).attr('id')) >= 0) {
            $(saveButton).prop('disabled', false);
        }
    });

    var submitForm = function(event) {

        var submit_map = {
            0: generalSubmit,
            3: permissionSubmit,
            6: processorSubmit
        };
        var currentTab = $('#guest-edit-window li.active a[data-toggle="tab"]').data('id');
        var toSubmit = parseInt($('#'+currentTab).index());
        var submitFun = submit_map[toSubmit];
        submitFun && submitFun(event);
        event.preventDefault();
    };

    $(guestEditForm).on('submit', submitForm);
    $(saveButton).on('click', submitForm);

    $('#guest-edit-window a[data-toggle="tab"]').on('shown.bs.tab', function(e) {
        var target = $(this).attr('href');
        $(target).css('left', '-' + $(window).width() + 'px');
        var left = $(target).offset().left;
        $(target).css({
            left: left
        }).animate({
            "left": "0px"
        }, "10");
    });

    $('#guest-edit-window a[data-toggle="tab"]:first').tab('show');

    var refreshCDROMs = function() {
        kimchi.listVMStorages({
            vm: kimchi.selectedGuest
        }, function(storages) {
            var container = $('#form-guest-edit-storage .body');
            $(container).empty();
            $.each(storages, function(index, storage) {
                storage['vm'] = kimchi.selectedGuest;
                rowHTML = $('#' + storage['type'] + '-row-tmpl').html();
                var templated = wok.substitute(rowHTML, storage);
                container.append(templated);
            });

            if (kimchi.thisVMState === 'running') {
                $('.detach[data-type="cdrom"]', container).remove();
            }

        });
    };

    var initStorageListeners = function() {
        var container = $('#form-guest-edit-storage .body');
        var toggleCDROM = function(rowNode, toEdit) {
            $('button.replace,button.detach', rowNode)[(toEdit ? 'add' : 'remove') + 'Class']('hidden');
            $('button.save,button.cancel', rowNode)[(toEdit ? 'remove' : 'add') + 'Class']('hidden');
            var pathBox = $('.path input', rowNode)
                .prop('readonly', !toEdit);
            toEdit && pathBox.select();
            pathBox.val(pathBox.attr('value'));
        };

        var replaceCDROM = function(event) {
            event.preventDefault();
            kimchi.selectedGuestStorage = $(this).data('dev');
            $('.item', container).each(function(i, n) {
                toggleCDROM(n);
            });
            var rowNode = $('#cdrom-' + kimchi.selectedGuestStorage);
            toggleCDROM(rowNode, true);
        };

        $(container).on('click', 'button.replace', replaceCDROM);

        $(container).on('click', 'button.detach', function(e) {
            e.preventDefault();
            var settings = {
                title: i18n['KCHAPI6004M'],
                content: i18n['KCHVMCD6001M'],
                confirm: i18n['KCHAPI6002M'],
                cancel: i18n['KCHAPI6003M']
            };
            if ($(this).data('type') === "disk") {
                settings['content'] = i18n['KCHVMCD6009M'];
            }

            var dev = $(this).data('dev');
            wok.confirm(settings, function() {
                kimchi.deleteVMStorage({
                    vm: kimchi.selectedGuest,
                    dev: dev
                }, function() {
                    wok.topic('kimchi/vmCDROMDetached').publish();
                });
            });
        });

        $(container).on('click', 'button.save', function(event) {
            event.preventDefault();
            var path = $('#cdrom-path-' + kimchi.selectedGuestStorage).val();
            var settings = {
                vm: kimchi.selectedGuest,
                dev: kimchi.selectedGuestStorage,
                path: path
            };

            kimchi.replaceVMStorage(settings, function(result) {
                wok.topic('kimchi/vmCDROMReplaced').publish({
                    result: result
                });
            }, function(result) {
                var errText = result['reason'] ||
                    result['responseJSON']['reason'];
                wok.message.error(errText, '#alert-modal-container');
            });
        });

        $(container).on('click', 'button.cancel', function(event) {
            event.preventDefault();
            var rowNode = $('#cdrom-' + kimchi.selectedGuestStorage);
            toggleCDROM(rowNode);
        });
    };

    var setupInterface = function() {
        $(".add", "#form-guest-edit-interface").on('click', function(evt) {
            evt.preventDefault();
            addItem({
                id: -1,
                mac: "",
                ips: "",
                network: "",
                type: "network",
                viewMode: "hide",
                editMode: ""
            });
        });
        var toggleEdit = function(item, on, itemId) {
          if(kimchi.hostarch === s390xArch){
              $("#label-mac-" + itemId, item).toggleClass("hide", on);
              $("#edit-mac-" + itemId, item).toggleClass("hide", !on);
              $("#label-network-" + itemId, item).toggleClass("hide", false);
              $("#label-type-" + itemId, item).toggleClass("hide", false);
              $("#label-mode-" + itemId, item).toggleClass("hide", false);
              $("select", item).toggleClass("hide", true);
              $(".bootstrap-select", item).toggleClass("hide", true);
              $(".action-area", item).toggleClass("hide");

          }else {

            $("#label-mac-" + itemId, item).toggleClass("hide", on);
            $("#edit-mac-" + itemId, item).toggleClass("hide", !on);
            $("#label-network-" + itemId, item).toggleClass("hide", false);
            $("select", item).toggleClass("hide", true);
            $(".bootstrap-select", item).toggleClass("hide", true);
            $(".action-area", item).toggleClass("hide");
          }
        };
        var addItem = function(data) {
            var oriID = data.id;
            if (data.id === -1) {
                data.id = $('#form-guest-edit-interface > .body').children().length;
            }
            if (data.ips === "" || data.ips === null || data.ips === undefined || data.ips.length === 0) {
                data.ips = i18n["KCHNET6001M"];
            } else {
                data.ips = data.ips;
            }
            if (kimchi.hostarch === s390xArch) {
                data.mode = (data.mode) ? data.mode : 'None';
                var itemNode = $.parseHTML(wok.substitute($('#interface-s390x-tmpl').html(), data));
                $(".body", "#form-guest-edit-interface").append(itemNode);

                $("select", "span.column-type", itemNode).empty().append(typeOptions);
                $("select", "span.column-mode", itemNode).empty().append(modeOptions);
                $("select", "span.column-network", itemNode).empty().append(macvtapNetworks);

                $("select", "span.column-type", itemNode).val(data.type);
                $("select", "span.column-network", itemNode).val(data.source);
                $("select", "span.column-mode", itemNode).val(data.mode);

            } else {
                var itemNode = $.parseHTML(wok.substitute($('#interface-tmpl').html(), data));
                $(".body", "#form-guest-edit-interface").append(itemNode);
                $("select", "span.column-network", itemNode).append(networkOptions);
            }

            $("select", itemNode).selectpicker({
                dropupAuto: false
            });


            $('.edit', itemNode).attr('disabled', kimchi.thisVMState === "running");
            $(".edit", itemNode).on('click', function(evt) {
                evt.preventDefault();
                toggleEdit($(this).closest('div'), true, data.id);
            });
            $(".delete", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();
                kimchi.deleteGuestInterface(kimchi.selectedGuest, item.prop("id"), function() {
                    item.remove();
                });
            });
            $(".save", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();

                if (kimchi.hostarch === s390xArch) {
                    if (item.prop("id") === "") { //adding new interface
                        switch ($("span.column-type select", item).val()) {
                            case 'macvtap':
                                var interface = {
                                    source: $("span.column-network select", item).val(),
                                        type: $("span.column-type select", item).val(),
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val(),
                                        mode: $("span.column-mode select", item).val()
                                };
                                break;

                            case 'ovs':
                                var interface = {
                                    source: $("span.column-network select", item).val(),
                                        type: $("span.column-type select", item).val(),
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val()
                                };
                                break;

                            case 'network':
                                var interface = {
                                    network: $("span.column-network select", item).val(),
                                        type: "network",
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val()
                                };
                                break;
                        }
                    } else { //updating existing interface

                        switch ($("#label-type-" + data.id, item).text()) {
                            case 'macvtap':

                                var interface = {
                                    source: $("#label-network-" + data.id, item).text(),
                                        type: $("#label-type-" + data.id, item).text(),
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val(),
                                        mode: $("#label-mode-" + data.id, item).text()
                                };
                                break;

                            case 'ovs':
                                var interface = {
                                    source: $("#label-network-" + data.id, item).text(),
                                        type: $("#label-type-" + data.id, item).text(),
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val()
                                };
                                break;

                            case 'network':
                                var interface = {
                                    network: $("#label-network-" + data.id, item).text(),
                                        type: "network",
                                        mac: $(":text", item).val(),
                                        ips: $(".ipText", item).val()
                                };
                                break;
                        }

                    }
                } else { //in s86 arch
                    var interface = {
                        network: $("select", item).val(),
                            type: "network",
                            mac: $(":text", item).val(),
                            ips: $(".ipText", item).val()
                    };
                }

                var postUpdate = function(mac) {
                    $("#label-network-" + data.id, item).text(interface.network);
                    $("#label-mac-" + data.id, item).text(mac);
                    $("#edit-mac-" + data.id, item).val(mac);
                    toggleEdit(item, false, data.id);
                };

                var posts390xUpdate = function(result) {
                    switch(result.type){
                      case 'macvtap' :
                                      $("#label-type-" + data.id, item).text(result.type);
                                      $("#label-network-" + data.id, item).text(result.source);
                                      $("#label-mode-" + data.id, item).text(result.mode);
                           break;

                      case 'ovs' :
                                      $("#label-type-" + data.id, item).text(result.type);
                                      $("#label-network-" + data.id, item).text(result.source);
                                      $("#label-mode-" + data.id, item).text(i18n['KCHVMED6018M']);
                          break;

                      case 'network' :
                                      $("#label-type-" + data.id, item).text(result.type);
                                      $("#label-network-" + data.id, item).text(result.network);
                                      $("#label-mode-" + data.id, item).text(i18n['KCHVMED6018M']);
                            break;
                    }

                    $("#label-mac-" + data.id, item).text(result.mac);
                    $("#edit-mac-" + data.id, item).val(result.mac);
                    toggleEdit(item, false, data.id);
                };

                if (item.prop("id") === "") {
                    kimchi.createGuestInterface(kimchi.selectedGuest, interface, function(data) {
                        item.prop("id", data.mac);
                        if(kimchi.hostarch == s390xArch){
                          posts390xUpdate(data);
                        }else{
                          postUpdate(data.mac);
                        }
                    });
                } else {
                    if (item.prop('id') === interface.mac) {
                        toggleEdit(item, false, data.id);
                    } else {
                        kimchi.updateGuestInterface(kimchi.selectedGuest, item.prop('id'),
                            interface,
                            function(data) {
                                item.prop("id", data.mac);
                                postUpdate(data.mac);
                            });
                    }
                }
            });
            $(".cancel", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();
                $("label", item).text() === "" ? item.remove() : toggleEdit(item, false, data.id);
            });

            if (kimchi.hostarch === s390xArch) {
                $("#interface-s390x-type-" + data.id).on('change', function() {
                    var itemNode = $(this).closest('div.item');
                    switch ($(this).val()) {
                        case 'macvtap':
                            $('#label-mode-' + data.id).addClass('hide');
                            $('span.column-mode .bootstrap-select', itemNode).toggleClass("hide", false);

                            $("span.column-network select", itemNode).empty().append(macvtapNetworks);
                            $("span.column-network select", itemNode).selectpicker('refresh');

                            break;
                        case 'ovs':
                            $('#label-mode-' + data.id).html(i18n['KCHVMED6018M']);
                            $('#label-mode-' + data.id).removeClass('hide');
                            $('span.column-mode .bootstrap-select', itemNode).toggleClass("hide", true);

                            $("span.column-network select", itemNode).empty().append(ovsNetworks);
                            $("span.column-network select", itemNode).selectpicker('refresh');
                            break;
                        case 'network':
                            $('#label-mode-' + data.id).html(i18n['KCHVMED6018M']);
                            $('#label-mode-' + data.id).removeClass('hide');
                            $('span.column-mode .bootstrap-select', itemNode).toggleClass("hide", true);

                            $("span.column-network select", itemNode).empty().append(networkOptions);
                            $("span.column-network select", itemNode).selectpicker('refresh');
                            break;
                    }
                });
                if (oriID === -1) {
                    $("#interface-s390x-type-" + data.id).trigger('change');
                }
            }

        };


        kimchi.listNetworks(function(data) {
            for (var i = 0; i < data.length; i++) {
                var isSlected = i === 0 ? " selected" : "";
                networkOptions += "<option" + isSlected + ">" + data[i].name + "</option>";
            }

            if (kimchi.hostarch === s390xArch) {

                kimchi.listmacvtapNetworks(function(data) {
                    for (var i = 0; i < data.length; i++) {
                        var isSlected = i === 0 ? ' selected="selected"' : "";
                        macvtapNetworks += "<option" + isSlected + ">" + data[i].name + "</option>";
                    }

                    kimchi.listovsNetworks(function(data) {
                        for (var i = 0; i < data.length; i++) {
                            var isSlected = i === 0 ? " selected" : "";
                            ovsNetworks += "<option" + isSlected + ">" + data[i] + "</option>";
                        }

                        kimchi.getGuestInterfaces(kimchi.selectedGuest, function(data) {
                            for (var i = 0; i < data.length; i++) {
                                data[i].viewMode = "";
                                data[i].editMode = "hide";
                                data[i].id = i;
                                addItem(data[i]);
                            }
                        });
                    });
                });
            } else {
                kimchi.getGuestInterfaces(kimchi.selectedGuest, function(data) {
                    for (var i = 0; i < data.length; i++) {
                        data[i].viewMode = "";
                        data[i].editMode = "hide";
                        data[i].id = i;
                        addItem(data[i]);
                    }
                });
            }
        });

        if (kimchi.hostarch === s390xArch) {
            $('#form-guest-edit-interface > div.header').hide();
            $('#form-guest-edit-interface > div.s390x').show();

            var typeOptionsdata = [{
                label: i18n['KCHVMED6013M'],
                value: 'macvtap'
            }, {
                label: i18n['KCHVMED6014M'],
                value: 'ovs'
            }, {
                label: i18n['KCHVMED6015M'],
                value: 'network'
            }];
            var typeOptions = '';

            for (var i = 0; i < typeOptionsdata.length; i++) {
                var isSlected = i === 0 ? ' selected="selected"' : "";
                typeOptions += '<option' + isSlected + ' value="' + typeOptionsdata[i].value + '">' + typeOptionsdata[i].label + '</option>';
            }

            var modeOptionsdata = [{
                label: i18n['KCHVMED6016M'],
                value: 'bridge'
            }, {
                label: i18n['KCHVMED6017M'],
                value: 'vepa'
            }];
            var modeOptions = '';

            for (var i = 0; i < modeOptionsdata.length; i++) {
                var isSlected = i === 0 ? " selected" : "";
                modeOptions += '<option' + isSlected + ' value="' + modeOptionsdata[i].value + '">' + modeOptionsdata[i].label + '</option>';
            }
        } else {
            $('#form-guest-edit-interface > div.header').show();
            $('#form-guest-edit-interface > div.s390x').hide();
        }
    };

    var setupPermission = function() {
        //set up for LDAP
        $(".add", "#form-guest-edit-permission").on('click', function(evt) {
            evt.preventDefault();
            addItem({
                user: "",
                freeze: false,
                viewMode: "hide",
                editMode: "",
                checked: true
            });
        });
        var addItem = function(data) {
            var itemNode = $.parseHTML(wok.substitute($('#ldap-user-tmpl').html(), data));
            $(".body", "#form-guest-edit-permission .ldap").append(itemNode);
            $(".delete", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();
                item.remove();
            });
            $("input").focusout(function() {
                var item = $(this).parent().parent();
                var user = $(this).val();
                item.prop("id", user);
                $("label", item).text(user);
            });
            $("input").focusin(function() {
                $(this).removeClass("checked");
            });

            if (data.checked === true) {
                $(".checked", itemNode).addClass("hide");
            }
        };
        var toggleEdit = function(item, on) {
            $(".cell span", item).toggleClass("hide", on);
            $("input", item).toggleClass("hide", !on);
            $(".action-area", item).toggleClass("hide");
        };
        //set up for PAM
        var userNodes = {},
            groupNodes = {};
        authType = wok.config['auth'];
        if (authType === 'pam') {
            $("#form-guest-edit-permission .ldap").hide();
            kimchi.retrieveVM(kimchi.selectedGuest, function(vm) {
                kimchi.getUsers(function(users) {
                    kimchi.getGroups(function(groups) {
                        var subArray = function(a1, a2) { //a1-a2
                            for (var i = 0; i < a2.length; i++) {
                                for (var j = 0; j < a1.length; j++) {
                                    if (a2[i] === a1[j]) {
                                        a1.splice(j, 1);
                                        break;
                                    }
                                }
                            }
                        };
                        subArray(users, vm.users);
                        subArray(groups, vm.groups);
                        init(users, groups, vm.users, vm.groups);
                    });
                });
            });
        } else if (authType === 'ldap') {
            $("#form-guest-edit-permission .pam").hide();
            kimchi.retrieveVM(kimchi.selectedGuest, function(vm) {
                for (var i = 0; i < vm.users.length; i++) {
                    addItem({
                        user: vm.users[i],
                        viewMode: "",
                        freeze: true,
                        editMode: "hide",
                        checked: true
                    });
                }
            });
        }
        var sortNodes = function(container, isUser) {
            nodes = container.children();
            var keys = [];
            nodes.each(function() {
                keys.push($("label", this).text());
            });
            keys.sort();
            container.empty();
            for (var i = 0; i < keys.length; i++) {
                var itemNode = isUser ? userNodes[keys[i]] : groupNodes[keys[i]];
                $(itemNode).click(function() {
                    $(this).toggleClass("item-picked");
                });
                container.append(itemNode);
            }
        };
        var init = function(availUsers, availGroups, selUsers, selGroups) {
            var initNode = function(key, isUserNode) {
                var nodeGroups = isUserNode ? userNodes : groupNodes;
                nodeGroups[key] = $.parseHTML(wok.substitute($('#permission-item-pam').html(), {
                    val: key,
                    class: isUserNode ? "fa-user" : "fa-users"
                }));
            };
            for (var i = 0; i < availUsers.length; i++) {
                initNode(availUsers[i], true);
                $("#permission-avail-users").append(userNodes[availUsers[i]]);
            }
            sortNodes($("#permission-avail-users"), true);
            for (var i = 0; i < selUsers.length; i++) {
                initNode(selUsers[i], true);
                $("#permission-sel-users").append(userNodes[selUsers[i]]);
            }
            sortNodes($("#permission-sel-users"), true);
            for (var i = 0; i < availGroups.length; i++) {
                initNode(availGroups[i], false);
                $("#permission-avail-groups").append(groupNodes[availGroups[i]]);
            }
            sortNodes($("#permission-avail-groups"), false);
            for (var i = 0; i < selGroups.length; i++) {
                initNode(selGroups[i], false);
                $("#permission-sel-groups").append(groupNodes[selGroups[i]]);
            }
            sortNodes($("#permission-sel-groups"), false);
        };
        var filterNodes = function(key, container) {
            container.children().each(function() {
                $(this).css("display", $("label", this).text().indexOf(key) === -1 ? "none" : "");
            });
        };
        $("#permission-avail-searchBox").on("keyup", function() {
            var key = $(this).val();
            filterNodes(key, $("#permission-avail-users"));
            filterNodes(key, $("#permission-avail-groups"));
        });
        $("#permission-sel-searchBox").on("keyup", function() {
            var key = $(this).val();
            filterNodes(key, $("#permission-sel-users"));
            filterNodes(key, $("#permission-sel-groups"));
        });
        $('#permissionGo').on('click', function(evt) {
            evt.preventDefault();
            $("#permission-avail-users").children(".item-picked").appendTo("#permission-sel-users").removeClass("item-picked");
            sortNodes($("#permission-sel-users"), true);
            $("#permission-avail-groups").children(".item-picked").appendTo("#permission-sel-groups").removeClass("item-picked");
            sortNodes($("#permission-sel-groups"), false);
            $("#permission-sel-searchBox").val("");
            filterNodes("", $("#permission-sel-users"));
            filterNodes("", $("#permission-sel-groups"));
        });
        $('#permissionBack').on('click', function(evt) {
            evt.preventDefault();
            $("#permission-sel-users").children(".item-picked").appendTo("#permission-avail-users").removeClass("item-picked");
            sortNodes($("#permission-avail-users"), true);
            $("#permission-sel-groups").children(".item-picked").appendTo("#permission-avail-groups").removeClass("item-picked");
            sortNodes($("#permission-avail-groups"), false);
            $("#permission-avail-searchBox").val("");
            filterNodes("", $("#permission-avail-users"));
            filterNodes("", $("#permission-avail-groups"));
        });
    };

    var filterPCINodes = function(group, text) {
        text = text.trim().split(" ");
        var rows = $('.body', '#form-guest-edit-pci').find('div');
        if (text === "") {
            rows.show();
            return;
        }
        rows.hide();

        rows.filter(function(index, value) {
            var $span = $(this);
            var $itemGroup = $('button i', this);
            for (var i = 0; i < text.length; ++i) {
                if ($span.is(":containsNC('" + text[i] + "')")) {
                    if (group === 'all') {
                        return true;
                    } else if (group === 'toAdd' && $itemGroup.hasClass('fa-power-off')) {
                        return true;
                    } else if (group === 'added' && $itemGroup.hasClass('fa-ban')) {
                        return true;
                    }
                }
            }
            return false;
        }).show();
    };

    var _generatePciDeviceHtml = function(devices, pciType) {
        var pciEnabled = kimchi.capabilities.kernel_vfio;
        var deviceHTml = devices.map(function(device, index) {
            device.iconClass = (pciType === 'hostPCIs' ? 'fa-power-off' : (pciType === 'vmPCIs' ? 'fa-ban' : 'fa-power-off'));
            device.status = (pciType === 'vmPCIs' ? 'enabled' : 'disabled');
            device.product = (device.product !== null ? device.product.description : '');
            device.vendor = (device.vendor !== null ? device.vendor.description : '');
            deviceHtml = $.parseHTML(wok.substitute($('#pci-tmpl').html(), {
                status: device.status,
                name: device.name,
                product: device.product,
                vendor: device.vendor
            }));
            pciEnabled || $('button', deviceHtml).remove();
            $('button > i', deviceHtml).addClass(device.iconClass);
            if (kimchi.thisVMState === "running" && device.vga3d) {
                $('button', deviceHtml).prop("disabled", true);
            }
            device = deviceHtml[0].outerHTML;
            $('.body', '#form-guest-edit-pci').append(device);
        });
    };
    var getOngoingAttachingDevices = function(task) {
        kimchi.trackTask(task.id, function(result) {
            kimchi.getAvailableHostPCIDevices(function(arrPCIDevices) {
                kimchi.getVMPCIDevices(kimchi.selectedGuest, function(vmPCIs) {
                    for (var k = 0; k < vmPCIs.length; k++) {
                        $('#' + vmPCIs[k].name + '.item').removeClass('disabled').addClass('enabled');
                        $('#' + vmPCIs[k].name + ' .action-area button i').removeClass('fa-power-off').addClass('fa-ban');
                    }
                });
            });
            $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
            wok.message.success(i18n['KCHVMED6010M'], '#alert-modal-container');
            filterPCINodes($('select', '#form-guest-edit-pci').val(), $('input#guest-edit-pci-filter', '#form-guest-edit-pci').val());
        }, function(result) {
            if (result['message']) {
                var errText = result['message'];
            } else {
                var errText = result['responseJSON']['reason'];
            }
            $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
            filterPCINodes($('select', '#form-guest-edit-pci').val(), $('input#guest-edit-pci-filter', '#form-guest-edit-pci').val());
            result && wok.message.error(errText, '#alert-modal-container');
        }, function(result) {
            $('#form-guest-edit-pci > .wok-mask').show();
        });
    };
    var getOngoingDetachingDevices = function(task) {
        kimchi.trackTask(task.id, function(result) {
            kimchi.getAvailableHostPCIDevices(function(arrPCIDevices) {
                kimchi.getVMPCIDevices(kimchi.selectedGuest, function(vmPCIs) {
                    for (var k = 0; k < arrPCIDevices.length; k++) {
                        $('#' + arrPCIDevices[k].name + '.item').removeClass('enabled').addClass('disabled');
                        $('#' + arrPCIDevices[k].name + ' .action-area button i').removeClass('fa-ban').addClass('fa-power-off');
                    }
                    for (var k = 0; k < vmPCIs.length; k++) {
                        $('#' + arrPCIDevices[k].name + '.item').removeClass('disabled').addClass('enabled');
                        $('#' + arrPCIDevices[k].name + ' .action-area button i').removeClass('fa-power-off').addClass('fa-ban');
                    }
                });
            });
            $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
            wok.message.success(i18n['KCHVMED6011M'], '#alert-modal-container');
            //id is for the object that is being added back to the available PCI devices
            filterPCINodes($('select', '#form-guest-edit-pci').val(), $('input#guest-edit-pci-filter', '#form-guest-edit-pci').val());
        }, function(result) {
            if (result['message']) {
                var errText = result['message'];
            } else {
                var errText = result['responseJSON']['reason'];
            }
            $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
            filterPCINodes($('select', '#form-guest-edit-pci').val(), $('input#guest-edit-pci-filter', '#form-guest-edit-pci').val());
            result && wok.message.error(errText, '#alert-modal-container');
        }, function(result) {
            $('#form-guest-edit-pci > .wok-mask').show();
        });
    };
    var pciDeviceButtonHandler = function() {
        $('.btn.btn-link', '#form-guest-edit-pci').on('click', function(event) {
            event.preventDefault();
            if (event.originalEvent.detail > 1)
                return;
            var obj = $(this);
            var objIcon = obj.find('i');
            var id = obj.parent().parent().attr('id');
            if (objIcon.hasClass('fa-ban')) {
                kimchi.removeVMPCIDevice(kimchi.selectedGuest, id, function(task) {
                    getOngoingDetachingDevices(task);
                }, function(err) {
                    wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                });
            } else {
                $('html').addClass('in-progress');
                $('#form-guest-edit-pci > .wok-mask').show();
                var haveCompanions = false;
                var pciTitle = i18n['KCHVMED6007M'] + '\n';
                kimchi.getPCIDeviceCompanions(id, function(infoData) {
                    for (var p = 0; p < infoData.length; p++) {
                        if (infoData[p].device_type === 'net') {
                            haveCompanions = true;
                            pciTitle += '   ' + infoData[p].name + '\n';
                            pciTitle += '      ' + i18n['KCHVMED6001M'] + ' ' + infoData[p].interface;
                            pciTitle += ', ' + i18n['KCHVMED6002M'] + ' ' + infoData[p].address;
                            pciTitle += ', ' + i18n['KCHVMED6003M'] + ' ' + infoData[p].link_type + '\n';
                        } else if (infoData[p].device_type === 'storage') {
                            haveCompanions = true;
                            pciTitle += '   ' + infoData[p].name + '\n';
                            pciTitle += '      ' + i18n['KCHVMED6004M'] + ' ' + infoData[p].block;
                            pciTitle += ', ' + i18n['KCHVMED6005M'] + ' ' + infoData[p].drive_type;
                            pciTitle += ', ' + i18n['KCHVMED6006M'] + ' ' + infoData[p].model + '\n';
                        }
                    }
                });
                $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
                $('html').removeClass('in-progress');

                var settings = {
                    title: i18n['KCHVMED6012M'],
                    content: pciTitle,
                    confirm: i18n['KCHAPI6002M'],
                    cancel: i18n['KCHAPI6003M']
                };

                if (haveCompanions) {
                    wok.confirm(settings, function() {
                        kimchi.addVMPCIDevice(kimchi.selectedGuest, {
                            name: id
                        }, function(task) {
                            getOngoingAttachingDevices(task);
                        }, function(err) {
                            wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                        });
                    });
                } else {
                    kimchi.addVMPCIDevice(kimchi.selectedGuest, {
                        name: id
                    }, function(task) {
                        getOngoingAttachingDevices(task);
                    }, function(err) {
                        wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                    });
                }
            }
        });
    };

    var setupPCIDevice = function() {
        kimchi.getAvailableHostPCIDevices(function(hostPCIs) {
            kimchi.getVMPCIDevices(kimchi.selectedGuest, function(vmPCIs) {
                _generatePciDeviceHtml(hostPCIs, 'hostPCIs');
                _generatePciDeviceHtml(vmPCIs, 'vmPCIs');
                pciDeviceButtonHandler();
                $('#form-guest-edit-pci > .wok-mask').fadeOut(300, function() {});
            });
        });
        $('select', '#form-guest-edit-pci').change(function() {
            filterPCINodes($(this).val(), $('input#guest-edit-pci-filter', '#form-guest-edit-pci').val());
        });
        $('select', '#form-guest-edit-pci').selectpicker();
        $('input#guest-edit-pci-filter', '#form-guest-edit-pci').on('keyup', function() {
            filterPCINodes($('select', '#form-guest-edit-pci').val(), $(this).val());
        });
    };


    var setupSnapshot = function() {
        var currentSnapshot;
        var setCurrentSnapshot = function(aSnapshot) {
            if (!aSnapshot) {
                kimchi.getCurrentSnapshot(kimchi.selectedGuest, function(snapshot) {
                    if (snapshot && snapshot.name) {
                        aSnapshot = snapshot.name;
                    }
                }, null, true);
            }
            if (aSnapshot) {
                if (currentSnapshot) {
                    $(".fa.fa-check", "#" + currentSnapshot).addClass("hide");
                }
                $(".fa.fa-check", "#" + aSnapshot).removeClass("hide");
                currentSnapshot = aSnapshot;
            }
        };
        var addItem = function(data, container) {
            var itemNode = $.parseHTML(wok.substitute($('#snapshot-tmpl').html(), data));
            $("." + container, "#form-guest-edit-snapshot").append(itemNode);
            $(".delete", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();
                $("button", "#form-guest-edit-snapshot").prop("disabled", true);
                kimchi.deleteSnapshot(kimchi.selectedGuest, item.prop("id"), function() {
                    item.remove();
                    setCurrentSnapshot();
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                }, function(data) {
                    wok.message.error(data.responseJSON.reason, '#alert-modal-container');
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                });
            });
            $(".revert", itemNode).on('click', function(evt) {
                evt.preventDefault();
                var item = $(this).parent().parent();
                $(".fa.fa-check", item).addClass("hide");
                $(".wok-loading", item).removeClass("hide");
                $("button", "#form-guest-edit-snapshot").prop("disabled", true);
                kimchi.revertSnapshot(kimchi.selectedGuest, item.prop("id"), function() {
                    $(".wok-loading", item).addClass("hide");
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                    setCurrentSnapshot(item.prop("id"));
                    kimchi.listVmsAuto();
                    wok.window.close();
                }, function(data) {
                    wok.message.error(data.responseJSON.reason, '#alert-modal-container');
                    $(".wok-loading-icon", item).addClass("hide");
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                });
            });
        };
        var addOngoingItem = function(task) {
            var uri = task.target_uri;
            addItem({
                name: uri.substring(uri.lastIndexOf('/') + 1, uri.length),
                created: "",
                listMode: "hide",
                createMode: ""
            }, 'task');
            if (kimchi.trackingTasks.indexOf(task.id) === -1) {
                kimchi.trackTask(task.id, function(task) {
                    listGeneratingSnapshots();
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                }, function(err) {
                    wok.message.error(err.message, '#alert-modal-container');
                    listGeneratingSnapshots();
                    $("button", "#form-guest-edit-snapshot").prop("disabled", false);
                });
            }
        };
        var listGeneratingSnapshots = function() {
            kimchi.getTasksByFilter('status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/snapshots/*'), function(tasks) {
                $(".task", "#form-guest-edit-snapshot").empty();
                for (var i = 0; i < tasks.length; i++) {
                    addOngoingItem(tasks[i]);
                }
                if (tasks.length === 0) {
                    listSnapshots();
                }
            });
        };
        var listSnapshots = function() {
            kimchi.listSnapshots(kimchi.selectedGuest, function(data) {
                $(".body", "#form-guest-edit-snapshot").empty();
                for (var i = 0; i < data.length; i++) {
                    data[i].created = new Date(data[i].created * 1000).toLocaleString();
                    data[i].createMode = "hide";
                    data[i].listMode = "";
                    addItem(data[i], 'body');
                }
                setCurrentSnapshot();
            });
        };
        listGeneratingSnapshots();
        $(".add", "#form-guest-edit-snapshot").on('click', function(evt) {
            evt.preventDefault();
            kimchi.createSnapshot(kimchi.selectedGuest, function(task) {
                $("button", "#form-guest-edit-snapshot").prop("disabled", true);
                addOngoingItem(task);
            });
        });
    };

    var setupBootOrder = function(guest) {
        var guestBootOrder = guest['bootorder'];
        var dev = ["cdrom", "hd", "network"];
        var excludedDev = dev.filter(function(e){return this.indexOf(e)<0;},guestBootOrder);

        $('#myList').empty();
        $.each(guestBootOrder, function(index, value) {
          item = $.parseHTML("<li class='list-group-item " + value + "' data-value=" + value + "><i class='fa fa-check'></i> " + value + "<span style='float: right; margin-top: -10px; padding: 0;'><button class='btn btn-link addBootOrderElem'><i class='fa fa-plus-circle'></i> Add</button><button class='btn btn-link deleteBootOrderElem'><i class='fa fa-minus-circle'></i> Remove</button></<span></li>");
          $('#myList').append(item);
          $('#myList .' + value + ' .addBootOrderElem').prop('disabled', true);
          $('#myList .' + value + ' .deleteBootOrderElem').prop('disabled', false);
        });
        if (excludedDev) {
          $.each(excludedDev, function(index, value) {
            item = $.parseHTML("<li class='list-group-item " + value + "' data-value=" + value + ">" + value + "<span style='float: right; margin-top: -10px; padding: 0;'><button class='btn btn-link addBootOrderElem'><i class='fa fa-plus-circle'></i> Add</button><button class='btn btn-link deleteBootOrderElem'><i class='fa fa-minus-circle'></i> Remove</button></<span></li>");
            $('#myList').append(item);
            $('#myList .' + value + ' .deleteBootOrderElem').prop('disabled', true);
          });
        }

        if (guestBootOrder.length == 1) {
          $('#myList .deleteBootOrderElem').prop('disabled', true);
        }

        $('.boot-order').sortable({
            items: 'li',
            cursor: 'move',
            opacity: 0.6,
            containment: "parent",
            start: function(event, ui) {
                $(this).addClass('focus');
            },
            stop: function(event, ui) {
                $(this).removeClass('focus');
            },
            change: function(event, ui) {
                // callback once started changing order
            },
            update: function(event, ui) {
                // callback once finished order
                $(saveButton).prop('disabled', false);
                bootOrderOptions = [];
                $("#myList li").each(function() {
                    bootOrderOptions.push($(this).attr("data-value").toLowerCase())
                });
                bootOrderOptions.forEach(function(entry) {
                    console.log(entry);
                });
                var data = {
                    bootorder: bootOrderOptions
                };
            }
        });

        $(".deleteBootOrderElem").on('click', function(evt) {
            evt.preventDefault();
            var item = $(this).parent().parent().attr("data-value").toLowerCase();
            var index = guestBootOrder.indexOf(item);

            $('.' + item + ' i.fa.fa-check').replaceWith('');
            $('#myList .' + item + ' .deleteBootOrderElem').prop('disabled', true);
            $('#myList .' + item + ' .addBootOrderElem').prop('disabled', false);

            if (index !== -1) {
              guestBootOrder.splice(index, 1);
            }
            if (guestBootOrder.length == 1) {
              $('#myList .deleteBootOrderElem').prop('disabled', true);
            }
            var data = {
                bootorder: guestBootOrder
            };
        });

        $(".addBootOrderElem").on('click', function(evt) {
            evt.preventDefault();
            var item = $(this).parent().parent().attr("data-value").toLowerCase();
            var index = guestBootOrder.indexOf(item);

            $('.' + item).prepend("<i class='fa fa-check'></i> ");
            $('#myList .' + item + ' .addBootOrderElem').prop('disabled', true);
            $('#myList .' + item + ' .deleteBootOrderElem').prop('disabled', false);

            guestBootOrder.push(item);

            if (guestBootOrder.length > 1) {
              $('#myList .deleteBootOrderElem').prop('disabled', false);
            }
            var data = {
                bootorder: guestBootOrder
            };
        });
    };

    var initContent = function(guest) {
        guest['icon'] = guest['icon'] || 'plugins/kimchi/images/icon-vm.png';
        $('#form-guest-edit-general').fillWithObject(guest);
        $('#guest-edit-memory-textbox').val(parseInt(guest.memory.current));
        $('#guest-edit-max-memory-textbox').val(parseInt(guest.memory.maxmemory));
        $("#enableGuestAutostart").prop('checked', parseInt(guest.autostart));
        kimchi.thisVMState = guest['state'];
        refreshCDROMs();
        $('#guest-edit-attach-cdrom-button').on('click', function(event) {
            event.preventDefault();
            wok.window.open('plugins/kimchi/guest-storage-add.html', 'extendCreateStorage');
        });
        if ((kimchi.thisVMState === "running") || (kimchi.thisVMState === "paused")) {
            if (kimchi.capabilities.mem_hotplug_support) {
                $("#form-guest-edit-general input").not("#guest-edit-memory-textbox").not("#enableGuestAutostart").prop("disabled", true);
            } else {
                $("#form-guest-edit-general input").not("#enableGuestAutostart").prop("disabled", true);
            }
        }
        if (! kimchi.capabilities.mem_hotplug_support) {
            $("#guest-edit-max-memory-textbox").prop("disabled", true);
            $("#guest-edit-memory-hotplug-unsupported").removeClass('hidden');
        }

        $('#guest-show-max-memory').on('click', function(e) {
            e.preventDefault;
            $('#guest-max-memory-panel').slideToggle();
            var text = $('#guest-show-max-memory span.text').text();
            $('#guest-show-max-memory span.text').text(text == i18n['KCHVMED6008M'] ? i18n['KCHVMED6009M'] : i18n['KCHVMED6008M']);
            $('#guest-show-max-memory i.fa').toggleClass('fa-plus-circle fa-minus-circle');
        });

        if ((kimchi.thisVMState !== "running") && (kimchi.thisVMState !== "paused")) {
            $("#guest-edit-memory-textbox").bind('keyup blur', function(e) {
                $('#guest-edit-max-memory-textbox').val($(this).val());
            });
        }

        if(kimchi.hostarch === s390xArch){
            var consoleData = guest.console ? guest.console : '';
            $('#guest-edit-console').val(consoleData);

            if (kimchi.thisVMState === "shutoff") {
                $('#guest-edit-console').prop('disabled', false);
            }else{
                $('#guest-edit-console').prop('disabled', true);
            }
            $('#guest-console-panel').show();
            $('#guest-edit-console').selectpicker();
        }

        var onAttached = function(params) {
            refreshCDROMs();
        };
        var onReplaced = function(params) {
            refreshCDROMs();
        };
        var onDetached = function(params) {
            refreshCDROMs();
        };

        initStorageListeners();
        setupInterface();
        setupPermission();
        setupPCIDevice();
        setupSnapshot();
        setupBootOrder(guest);

        kimchi.init_processor_tab(guest.cpu_info, $(saveButton));
        if ((kimchi.thisVMState === "running") || (kimchi.thisVMState === "paused")) {
            $('#guest-edit-max-processor-textbox').attr("disabled", true);
            $('#sockets').attr("disabled", true);
            $('#cores').attr("disabled", true);
            $('#threads').attr("disabled", true);

            $("#topology-checkbox").hide();
            $("#settings-readonly-help").removeClass('hidden');
        }

        wok.topic('kimchi/vmCDROMAttached').subscribe(onAttached);
        wok.topic('kimchi/vmCDROMReplaced').subscribe(onReplaced);
        wok.topic('kimchi/vmCDROMDetached').subscribe(onDetached);

        kimchi.clearGuestEdit = function() {
            wok.topic('kimchi/vmCDROMAttached').unsubscribe(onAttached);
            wok.topic('kimchi/vmCDROMReplaced').unsubscribe(onReplaced);
            wok.topic('kimchi/vmCDROMDetached').unsubscribe(onDetached);
        };
    };

    kimchi.retrieveVM(kimchi.selectedGuest, initContent);

    var generalSubmit = function(event) {
        kimchi.retrieveVM(kimchi.selectedGuest, function(org) {
            $(saveButton).prop('disabled', true);
            var data = $('#form-guest-edit-general').serializeObject();
            data['autostart'] = $("#enableGuestAutostart").prop('checked');
            data['memory'] = {current: Number(data['memory-ui']), maxmemory: Number(data['max-memory'])};

            var changedFields = {};
            for (var key in data) {
                valueFromUI = data[key];
                if (valueFromUI instanceof Object) {
                    // Compare if Objects of original and data are identical
                    // Handle special case when key is memory and guest is running as valueFromUI will return a null for max mem
                    // since it is disabled;
                    if (kimchi.thisVMState === 'running' || kimchi.thisVMState === 'paused') {
                        if (key === 'memory') {
                            // Replace valueFromUI of max mem with one from original as otherwise the value is undefined
                            data['memory']['maxmemory'] = org.memory.maxmemory;
                        }
                    }
                    // NOTE:  Be aware of using this comparison as the order of the properties matter
                    if (JSON.stringify(valueFromUI) !== JSON.stringify(org[key])) {
                        changedFields[key] = valueFromUI;
                    }
                } else {
                    if (org[key] !== undefined) {
                        if (data[key] != org[key]) {
                            changedFields[key] = valueFromUI;
                        }
                    }
                }
            }
            var origMem = Number(org.memory.current);
            var origMaxMem = Number(org.memory.maxmemory);
            var currentMem = data['memory-ui'];
            var currentMaxMem = data['max-memory'];

            if ('memory' in changedFields) {
                if (currentMaxMem !== undefined) {
                    currentMaxMem = Number(currentMaxMem);
                    if (currentMaxMem === origMaxMem) {
                        delete changedFields.memory.maxmemory;
                    }
                } else {
                    delete changedFields.memory.maxmemory;
                }
                if (currentMem !== undefined) {
                    currentMem = Number(currentMem);
                    if (kimchi.thisVMState === 'running' || kimchi.thisVMState === 'paused') {
                        // Compare to original max mem since current max mem is undefined in UI due to being disabled
                        if (currentMem > origMaxMem) {
                            wok.message.error(i18n['KCHVM0002E'], '#alert-modal-container');
                            $(saveButton).prop('disabled', false);
                            return;
                        }
                    }
                    if (currentMem === origMem) {
                        delete changedFields.memory.current;
                    }
                } else {
                    delete changedFields.memory.current;
                }
            }

            checkedValue = [];
            $("#myList i.fa.fa-check").each(function() {
              checkedValue.push($(this).parent().attr("data-value").toLowerCase());
            });
            changedFields.bootorder = checkedValue;

            kimchi.updateVM(kimchi.selectedGuest, changedFields, function() {
                kimchi.listVmsAuto();
                wok.window.close();
            }, function(err) {
                wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                $(saveButton).prop('disabled', false);
            });

        });
    };

    var permissionSubmit = function(event) {
        var content = {
            users: [],
            groups: []
        };
        authType = wok.config['auth'];
        if (authType === 'pam') {
            $("#permission-sel-users").children().each(function() {
                content.users.push($("label", this).text());
            });
            $("#permission-sel-groups").children().each(function() {
                content.groups.push($("label", this).text());
            });
            kimchi.updateVM(kimchi.selectedGuest, content, function() {
                wok.window.close();
            });
        } else if (authType === 'ldap') {
            $(saveButton).prop('disabled', true);
            var errors = 0;

            $(".body", "#form-guest-edit-permission .ldap").children().each(function() {
                var elem = $(this);
                content.users.push(elem.attr("id"));

                if (!$('input', elem).hasClass('hide')) {
                    var user = {
                        'user_id': $(this).attr("id")
                    };
                    kimchi.getUserById(user, null, function(data) {
                        errors += 1;
                        $("input", elem).addClass("checked");
                    });
                }
            });
            if (errors === 0) {
                kimchi.updateVM(kimchi.selectedGuest, content, function() {
                    wok.window.close();
                });
            } else {
                $(saveButton).prop('disabled', false);
            }
        }
    };

    var processorSubmit = function(event) {
        kimchi.retrieveVM(kimchi.selectedGuest, function(org) {
            $(saveButton).prop('disabled', true);
            var data = {};

            var cpu = parseInt($('#vcpus').val());
            var maxCpu = parseInt($('#guest-edit-max-processor-textbox').val());
            var maxCpuFinal = cpu;
            if (maxCpu >= cpu) {
                maxCpuFinal = maxCpu;
            }
            if (kimchi.thisVMState === 'running' || kimchi.thisVMState === 'paused') {
                data['cpu_info'] = {vcpus: cpu};
            } else {
                if ($("input:checkbox", "#form-edit-processor").prop("checked")) {
                    data['cpu_info'] = {
                        vcpus: cpu,
                        maxvcpus: maxCpuFinal,
                        topology: {
                            sockets: parseInt($("#sockets").val()),
                            cores: parseInt($("#cores").val()),
                            threads: parseInt($("#threads").val())
                        }
                    };
                } else {
                    data['cpu_info'] = {
                        vcpus: cpu,
                        maxvcpus: maxCpuFinal,
                        topology: {}
                    };
                }
            }

            kimchi.updateVM(kimchi.selectedGuest, data, function() {
                kimchi.listVmsAuto();
                wok.window.close();
            }, function(err) {
                wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                $(saveButton).prop('disabled', false);
            });
        });
    };

    if(kimchi.hostarch === s390xArch){
        $('#guest-edit-window ul li a[data-id="form-guest-edit-pci"],a[data-id="form-guest-edit-snapshot"]').parent().hide();
    }
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2016-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.guest_livemigration_main = function() {
    kimchi.setupLiveMigrationFormEvent();
    kimchi.initLiveMigrationDialog();
};


kimchi.getOngoingMigration = function(guestName, toDelete) {
    var guests = [];
    kimchi.getTasksByFilter('status=running&target_uri='+ encodeURIComponent('^/plugins/kimchi/vms/' + guestName + '/migrate'), function(tasks) {
        for (var i = 0; i < tasks.length; i++) {
            var guestUri = tasks[i].target_uri;
            var guestName = guestUri.split('/')[4];
            guests[guestName] = tasks[i];

            if (kimchi.trackingTasks.indexOf(tasks[i].id) >= 0) {
                continue;
            }

            kimchi.trackTask(tasks[i].id, function(guests) {
                if (toDelete) {
                    kimchi.deleteVM(guestName, function(result) {
                        return;
                    });
                }
                kimchi.listVmsAuto();
            }, function(guests) {
                wok.message.error('<strong>'+guestName+'</strong>: '+guests.message,'#alert-container', true, 'failed-migration-'+guests.id);
                return;
            }, function(guests) {
                return;
            });
        }
    }, null, true);
    return guests;
};

kimchi.initLiveMigrationDialog = function(okCallback) {
    $("#migrateFormOk").on("click", function() {
        $("#migrateFormOk").prop("disabled", true);
        $("#remote_host").prop("readonly", "readonly");
        $("#user").prop("readonly", "readonly");
        $("#password").prop("readonly", "readonly");
        $("#deleteVM").prop("readonly", "readonly");
        wok.window.close();
        kimchi.initLiveMigrationProccess();
    });
};

kimchi.initLiveMigrationProccess = function() {
    var obj = kimchi.getLiveMigrationInputValues();
    var toDelete = obj[kimchi.selectedGuest].toDelete;
    kimchi.migrateGuest(kimchi.selectedGuest, obj[kimchi.selectedGuest].values, function() {
        kimchi.listVmsAuto();
        kimchi.getOngoingMigration(kimchi.selectedGuest, toDelete);
    }, function(err) {
        wok.message.error(err.responseJSON.reason);
    });
}

kimchi.getLiveMigrationInputValues = function() {
    var host = $("#remote_host").val();
    var username = $("#user").val();
    var password = $("#password").val();
    var toDelete = $("#deleteVM").prop('checked');
    var enable_rdma = $("#enableRDMA").prop('checked');
    var data = {};
    data[kimchi.selectedGuest] = {
        values: {
            remote_host: host,
            enable_rdma: enable_rdma
        },
        toDelete: toDelete
    };
    if (username && password) {
        data[kimchi.selectedGuest].values.user = username;
        data[kimchi.selectedGuest].values.password = password;
    }
    return data;
};

kimchi.setupLiveMigrationFormEvent = function() {
    $("#migrateFormOk").prop("disabled", true);
    $("#remote_host").on("keyup", function(event) {
        if (!this.value) {
            $(this).parent().addClass('has-error');
        } else {
            $(this).parent().removeClass('has-error');
        }
        kimchi.updateLiveMigrationButton();
    });
    $("#user").on("keyup", function(event) {
        if (this.value && !$("#password").val()) {
            $("#user").parent().removeClass('has-warning');
            $("#password").parent().addClass('has-warning');
        } else {
            $("#user").parent().removeClass('has-warning');
            $("#password").parent().removeClass('has-warning');
        }
        kimchi.updateLiveMigrationButton();
    });
    $("#password").on("keyup", function(event) {
        if (this.value && !$("#user").val()) {
            $("#user").parent().addClass('has-warning');
        } else {
            $("#user").parent().removeClass('has-warning');
            $("#password").parent().removeClass('has-warning');
            kimchi.updateLiveMigrationButton();
        }
    });
};

kimchi.updateLiveMigrationButton = function() {
    if ($("#remote_host").val()) {
        if ($("input[type='text']").parent().hasClass("has-error") || $("input[type='text']").parent().hasClass("has-warning")) {
            $("#migrateFormOk").prop("disabled", true);
        } else {
            $("#migrateFormOk").prop("disabled", false);
        }
    };
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// init Guest Filter List global variable
var guestFilterList;
var listFiltered;

//init s390x Architecture
var s390xArch = 's390x';

kimchi.sampleGuestObject = {
    "name": "",
    "uuid": "",
    "state": "shutoff",
    "persistent": true,
    "icon": null,
    "cpus": 0,
    "memory": 0,
    "stats": {
        "net_throughput": 0,
        "io_throughput_peak": 100,
        "cpu_utilization": 0,
        "mem_utilization": 0,
        "io_throughput": 0,
        "net_throughput_peak": 100
    },
    "screenshot": null,
    "graphics": {
        "passwd": null,
        "passwdValidTo": null,
        "type": "vnc",
        "port": null,
        "listen": "127.0.0.1"
    },
    "users": [],
    "groups": [],
    "access": "full"
};

kimchi.vmstart = function(event) {
    var button = event.target;
    if (!$(button).hasClass('loading')) {
        $(button).addClass('loading');
        var vm = $(button).closest('li[name=guest]');
        var vm_id = $(vm).attr("id");
        // setting up css class when starting
        $(vm).find('.guest-state').removeClass('shutoff');
        $(vm).find('.guest-state').addClass('starting');
        $(vm).find('.progress').css("display", "none");
        $(vm).find('.percentage - label').html('--');
        $(vm).find('.measure-label').html('--');
        $(vm).addClass('inactive');
        $(vm).find('.distro-icon').addClass('inactive');
        $(vm).find('.vnc-link').css("display", "none");
        $(vm).find('.column-vnc').html('--');
        kimchi.startVM(vm_id, function(result) {
            $(button).removeClass('loading');
            kimchi.listVmsAuto();
        }, function(err) {
            $(button).removeClass('loading');
            wok.message.error(err.responseJSON.reason);
        });
    } else {
        event.preventDefault();
        event.stopPropagation();
        return;
    }
};

kimchi.vmsuspend = function(event) {
    var button = event.target;
    if (!$(button).hasClass('pause-gray')) {
        $(button).addClass('pause-gray');
        var vm = $(button).closest('li[name=guest]');
        var vm_id = $(vm).attr("id");
        kimchi.suspendVM(vm_id, function(result) {
            $(button).removeClass('pause-gray');
            kimchi.listVmsAuto();
        }, function(err) {
            $(button).removeClass('pause-gray');
            wok.message.error(err.responseJSON.reason);
        });
    } else {
        event.preventDefault();
        event.stopPropagation();
        return;
    }
};

kimchi.vmresume = function(event) {
    var button = event.target;
    if (!$(button).hasClass('resume-gray')) {
        $(button).addClass('resume-gray');
        var vm = $(button).closest('li[name=guest]');
        var vm_id = vm.attr("id");
        kimchi.resumeVM(vm_id, function(result) {
            $(button).removeClass('resume-gray');
            kimchi.listVmsAuto();
        }, function(err) {
            $(button).removeClass('resume-gray');
            wok.message.error(err.responseJSON.reason);
        });
    } else {
        event.preventDefault();
        event.stopPropagation();
        return;
    }
};

kimchi.vmpoweroff = function(event) {
    var button = event.target;
    if (!$(button).hasClass('loading')) {
        $(button).addClass('loading');
        var vm = $(button).closest('li[name=guest]');
        var vm_id = vm.attr("id");
        var vmObject = vm.data();
        var vm_persistent = vmObject.persistent == true;
        var content_msg_1 = i18n['KCHVM6003M'].replace('%1', '<strong>'+vm_id+'</strong>');
        var content_msg_2 = i18n['KCHVM6009M'].replace('%1', '<strong>'+vm_id+'</strong>');
        var content_msg = vm_persistent ? content_msg_1 : content_msg_2;
        var settings = {
            title: i18n['KCHVM6002M'],
            content: content_msg,
            confirm: i18n['KCHAPI6002M'],
            cancel: i18n['KCHAPI6003M']
        };
        wok.confirm(settings, function() {
            kimchi.poweroffVM(vm_id, function(result) {
                $(button).removeClass('loading');
                kimchi.listVmsAuto();
            }, function(err) {
                wok.message.error(err.responseJSON.reason);
            });
        }, function() {});
    } else {
        event.preventDefault();
        event.stopPropagation();
    }
};

kimchi.vmshutdown = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vm_id = vm.attr("id");
    var confirmMessage = i18n['KCHVM6007M'].replace('%1', '<strong>'+vm_id+'</strong>');
    var settings = {
        title: i18n['KCHVM6006M'],
        content: confirmMessage,
        confirm: i18n['KCHAPI6002M'],
        cancel: i18n['KCHAPI6003M']
    };
    wok.confirm(settings, function() {
        kimchi.shutdownVM(vm_id, function(result) {
            kimchi.listVmsAuto();
        }, function(err) {
            wok.message.error(err.responseJSON.reason);
        });
    }, function() {});
};

kimchi.vmreset = function(event) {
    var button = event.target;
    if (!$(button).hasClass('loading')) {
        $(button).addClass('loading');
        var vm = $(button).closest('li[name=guest]');
        var vm_id = $(vm).attr("id");
        var confirmMessage = i18n['KCHVM6005M'].replace('%1', '<strong>'+vm_id+'</strong>');
        var settings = {
            title: i18n['KCHVM6004M'],
            content: confirmMessage,
            confirm: i18n['KCHAPI6002M'],
            cancel: i18n['KCHAPI6003M']
        };
        wok.confirm(settings, function() {
            // setting up css class when resetting
            $(vm).find('.guest-state').removeClass('running');
            $(vm).find('.guest-state').addClass('resetting');
            $(vm).find('.fa-spin').addClass('active');
            kimchi.resetVM(vm_id, function(result) {
                $(button).removeClass('loading');
                kimchi.listVmsAuto();
            }, function(err) {
                $(button).removeClass('loading');
                wok.message.error(err.responseJSON.reason);
            });
        }, function() {});
    } else {
        event.preventDefault();
        event.stopPropagation();
        return;
    }
};

kimchi.vmdelete = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vm_id = $(vm).attr("id");
    var confirmMessage = i18n['KCHVM6001M'].replace('%1', '<strong>'+vm_id+'</strong>');
    var settings = {
        title: i18n['KCHVM6008M'],
        content: confirmMessage,
        confirm: i18n['KCHAPI6002M'],
        cancel: i18n['KCHAPI6003M']
    };
    wok.confirm(settings, function() {
        kimchi.deleteVM(vm_id, function(result) {
            kimchi.listVmsAuto();
        }, function(err) {
            wok.message.error(err.responseJSON.reason);
        });
    }, function() {});
};

kimchi.vmedit = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vm_id = $(vm).attr("id");
    kimchi.selectedGuest = vm_id;
    wok.window.open({
        url: 'plugins/kimchi/guest-edit.html',
        close: function() {
            kimchi.clearGuestEdit();
        }
    });
};

kimchi.vmmigrate = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vm_id = $(vm).attr("id");
    kimchi.selectedGuest = vm_id;
    wok.window.open('plugins/kimchi/guest-migration.html');
};

kimchi.vmclone = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vm_id = $(vm).attr("id");
    kimchi.selectedGuest = vm_id;
    wok.window.open('plugins/kimchi/guest-clone.html');
};

kimchi.openVmSerialConsole = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    kimchi.serialToVM($(vm).attr('id'));
};

kimchi.openVmConsole = function(event) {
    var button = event.target;
    var vm = $(button).closest('li[name=guest]');
    var vmObject = $(vm).data();
    if (vmObject.graphics['type'] == 'vnc') {
        kimchi.vncToVM($(vm).attr('id'));
    } else if (vmObject.graphics['type'] == 'spice') {
        kimchi.spiceToVM($(vm).attr('id'));
    }

};

kimchi.getVmsCurrentConsoleImgs = function() {
    var res = new Object();
    $('#guestList').children().each(function() {
        res[$(this).attr('id')] = $(this).find('img.imgactive').attr('src');
    })
    return res;
};

kimchi.getOpenMenuVmId = function() {
    var result;
    var openMenu = $('#guestList div[name="actionmenu"] .dropdown-menu:visible');
    if (openMenu) {
        var li_element = openMenu.closest('li');
        result = li_element.attr('id');
    }
    return result;
};

kimchi.initGuestFilter = function() {
    // Create the list with the css classes that could be filtered at
    // the first click at the Filter Input Field
    $('#search_input').one('keyup', function(event) {
        var options = {
            valueNames: ['title', 'distro-icon', 'processors-percentage', 'memory-percentage', 'storage-percentage', 'network-percentage']
        };
        guestFilterList = new List('guest-content-container', options);
    });
};

kimchi.resetGuestFilter = function() {
    if (guestFilterList) {
        $('#search_input').val();
        listFiltered = false;
    }
};


kimchi.initClone = function() {
    var numTimesToClone = $('#numberClone').val();
    for (var i = 0; i < numTimesToClone; i++) {
        kimchi.cloneGuest(kimchi.selectedGuest, function(data) {
            kimchi.listVmsAuto();
        });
    }
   wok.window.close();
};

kimchi.guestSetRequestHeader = function(xhr) {
    xhr.setRequestHeader('Accept', 'text/html');
};

kimchi.toggleGuestsGallery = function() {
    $(".wok-guest-list, .wok-guest-gallery").toggleClass("wok-guest-list wok-guest-gallery");
    $(".wok-list, .wok-gallery").toggleClass("wok-list wok-gallery");
    var text = $('#guest-gallery-table-button span.text').text();
    $('#guest-gallery-table-button span.text').text(text == i18n['KCHTMPL6005M'] ? i18n['KCHTMPL6004M'] : i18n['KCHTMPL6005M']);
    var buttonText = $('#guest-gallery-table-button span.text').text();
    if (buttonText.indexOf("Gallery") !== -1) {
        // Currently in list view
        kimchi.setGuestView("guestView", "list");
     } else {
        // Currently in gallery
        kimchi.setGuestView("guestView", "gallery");
     }
};

kimchi.setGuestView = function(name, value) {
    window.localStorage.setItem(name, value);
};

kimchi.readGuestView = function(name) {
    var viewName = window.localStorage.getItem(name);
    if (viewName !== "") {
        return viewName;
    } else {
        return null;
    }
};

kimchi.showGuestGallery = function() {
    $(".wok-guest-list").addClass("wok-guest-gallery");
    $(".wok-list").addClass("wok-gallery");
    $(".wok-guest-gallery").removeClass("wok-guest-list");
    $(".wok-gallery").removeClass("wok-list");
    $('#guest-gallery-table-button span.text').text(i18n['KCHTMPL6004M']);
};

kimchi.showGuestList = function() {
    $(".wok-guest-list").removeClass("wok-guest-gallery");
    $(".wok-list").removeClass("wok-gallery");
    $(".wok-guest-gallery").addClass("wok-guest-list");
    $(".wok-gallery").addClass("wok-list");
    $('#guest-gallery-table-button span.text').text(i18n['KCHTMPL6005M']);
};

kimchi.guest_main = function() {
    $('body').addClass('wok-list');
    var viewFound = kimchi.readGuestView("guestView");
    if (viewFound) {
        if(viewFound === "gallery") {
            // should be showing gallery
            kimchi.showGuestGallery();
        } else {
            // Should be showing list
            kimchi.showGuestList();
        }
    } else {
        // Default to showing list
        kimchi.showGuestList();
    }

    var toolsHtml = '<li><a id="vm-add" class="btn-tool" href="javascript:void(0);">'
    toolsHtml += '<i class="fa fa-plus-circle"></i><span>' + i18n['KCHVM6010M'] + '</span></a></li>'

    if (wok.tabMode['guests'] === 'admin') {
        $('#toolbar ul.tools').html(toolsHtml);
        $("#vm-add").on("click", function(event) {
            wok.window.open('plugins/kimchi/guest-add.html');
        });
    }
    kimchi.guestTemplate = $('#guest-tmpl').html();
    kimchi.guestElem = $('<div/>').html(kimchi.guestTemplate).find('li[name="guest"]');

    $('#guest-gallery-table-button').on('click', function(event) {
        kimchi.toggleGuestsGallery();
    });

    kimchi.resetGuestFilter();
    kimchi.initGuestFilter();
    kimchi.listVmsAuto();
    wok.addNotificationListener('METHOD:/kimchi/vms', kimchi.listVmsAuto);
};

kimchi.guest_clonevm_main = function() {
   kimchi.initCloneDialog();
};

kimchi.initCloneDialog = function(callback) {
    $("#numberClone").val("1");
    $("#cloneFormOk").on("click", function() {
        //Check if input is a number
        var numClone = parseInt($('#numberClone').val());
        var err = "";
        if (isNaN(numClone)) {
            err = i18n['KCHVM0001E'];
            wok.message.error(err,'#alert-modal-container');
        } else {
            $("#cloneFormOk").prop("disabled", true);
            kimchi.initClone();
        }
   });
};


kimchi.createGuestLi = function(vmObject, prevScreenImage, openMenu) {
    var result;
    if (typeof kimchi.guestElem !== 'undefined') {
        result = kimchi.guestElem.clone();
        //Setup the VM list entry
        var currentState = result.find('.guest-state');
        var vmRunningBool = (vmObject.state == "running");
        var vmSuspendedBool = (vmObject.state == "paused");
        var vmPoweredOffBool = (vmObject.state == "shutoff");
        var vmPersistent = (vmObject.persistent == true);

        if (vmObject.state !== 'undefined') {
            currentState.addClass(vmObject.state);
        };
        result.attr('id', vmObject.name);
        result.data(vmObject);

        //Add the Name
        var guestTitle = result.find('.title').attr({ 'val': vmObject.name, 'title': vmObject.name });
        guestTitle.html(vmObject.name);

        if (vmObject.screenshot !== null) {
            var scrensh = result.find('.screenshot').css('background-image', 'url(' + vmObject.screenshot + ')');
            scrensh.attr('title', vmObject.name);
        } else {
            var scrensh = result.find('.screenshot').css('background-image', 'none');
            scrensh.attr('title', vmObject.name);
        }

        //Add the OS Type and Icon
        var osType = result.find('.column-type.distro-icon');
        if (vmObject.icon == 'plugins/kimchi/images/icon-fedora.png') {
            osType.addClass('icon-fedora');
            osType.attr('val', 'Fedora');
            osType.html('Fedora');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-ubuntu.png') {
            osType.addClass('icon-ubuntu');
            osType.attr('val', 'Ubuntu');
            osType.html('Ubuntu');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-centos.png') {
            osType.addClass('icon-centos');
            osType.attr('val', 'Centos');
            osType.html('Centos');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-opensuse.png') {
            osType.addClass('icon-opensuse');
            osType.attr('val', 'openSUSE');
            osType.html('openSUSE');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-gentoo.png') {
            osType.addClass('icon-gentoo');
            osType.attr('val', 'Gentoo');
            osType.html('Gentoo');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-debian.png') {
            osType.addClass('icon-debian');
            osType.attr('val', 'Debian');
            osType.html('Debian');
        } else if (vmObject.icon !== null) {
            osType.css('background-image', vmObject.icon);
            osType.attr('val', 'Unknown');
            osType.html('Unknown');
        } else {
            //Unknown
            osType.addClass('icon-unknown');
            osType.attr('val', 'Unknown');
            osType.html('Unknown');
        }
        //Add the OS Icon to VM name in Gallery View
        var osName = result.find('.column-name.distro-icon');
        if (vmObject.icon == 'plugins/kimchi/images/icon-fedora.png') {
            osName.addClass('icon-fedora');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-ubuntu.png') {
            osName.addClass('icon-ubuntu');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-centos.png') {
            osName.addClass('icon-centos');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-opensuse.png') {
            osName.addClass('icon-opensuse');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-gentoo.png') {
            osName.addClass('icon-gentoo');
        } else if (vmObject.icon == 'plugins/kimchi/images/icon-debian.png') {
            osName.addClass('icon-debian');
        } else if (vmObject.icon !== null) {
            osName.css('background-image', vmObject.icon);
        } else {
            osName.addClass('icon-unknown');
        }

        //Setup the VM console thumbnail display
        var curImg = vmObject.icon;
        if (vmObject.screenshot) {
            curImg = vmObject.screenshot.replace(/^\//, '');
        }
        var load_src = curImg || 'plugins/kimchi/images/icon-vm.png';
        var tile_src = prevScreenImage || vmObject['load-src'];
        var liveTile = result.find('div[name=guest-tile] > .tile');
        liveTile.addClass(vmObject.state);
        liveTile.find('.imgactive').attr('src', tile_src);
        var imgLoad = liveTile.find('.imgload');
        imgLoad.on('load', function() {
            var oldImg = $(this).parent().find('.imgactive');
            oldImg.removeClass("imgactive").addClass("imgload");
            oldImg.attr("src", "");
            $(this).addClass("imgactive").removeClass("imgload");
            $(this).off('load');
        });
        imgLoad.attr('src', load_src);

        //Link the stopped tile to the start action, the running tile to open the console, and the paused tile to resume
        if (!(vmObject.isCloning || vmObject.isCreating || vmObject.isMigrating)) {
            if (vmPoweredOffBool) {
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.openVmConsole(event);
                });
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.vmresume(event);
                });
                liveTile.on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmstart(event);
                });
                liveTile.hover("click", function(event) {
                    event.preventDefault();
                    $(this).find('.overlay').show()
                }, function(event) {
                    $(this).find('.overlay').hide()
                });
            } else if (vmSuspendedBool) {
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.vmstart(event);
                });
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.openVmConsole(event);
                });
                liveTile.on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmresume(event);
                });
                liveTile.hover("click", function(event) {
                    event.preventDefault();
                    $(this).find('.overlay').show()
                }, function(event) {
                    $(this).find('.overlay').hide()
                });
                if (vmObject.state = "paused") {
                    liveTile.find('.overlay').attr('src', "plugins/kimchi/images/theme-default/ac24_resume.png");
                    liveTile.find('.overlay').attr('alt', "Resume");
                }
                liveTile.hover(function(event) {
                    $(this).find('.overlay').show()
                }, function(event) {
                    $(this).find('.overlay').hide()
                });
            } else {
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.vmstart(event);
                });
                liveTile.off("click", function(event) {
                    event.preventDefault();
                    kimchi.vmresume(event);
                });
                liveTile.on("click", function(event) {
                    event.preventDefault();
                    kimchi.openVmConsole(event);
                });
            }
        }

        //Setup progress bars
        if (!vmPoweredOffBool) {
            var cpuUtilization = 0;
            var cpuMaxThreshold = 80;
            var cpuMediumThreshold = 60;
            cpuUtilization = parseInt(vmObject.stats.cpu_utilization);
            result.find('.cpu-progress-bar').width(cpuUtilization + '%');
            result.find('.processors-percentage').html(cpuUtilization + '%');
            result.find('.medium-grey.cpu').width(cpuMaxThreshold + '%');
            result.find('.light-grey.cpu').width(cpuMediumThreshold + '%');

            var memoryUtilization = 0;
            var memoryMaxThreshold = 80;
            var memoryMediumThreshold = 60;
            memoryUtilization = parseInt(vmObject.stats.mem_utilization);
            result.find('.memory-progress-bar').width(memoryUtilization + '%');
            result.find('.memory-percentage').html(memoryUtilization + '%');
            result.find('.medium-grey.memory').width(memoryMaxThreshold + '%');
            result.find('.light-grey.memory').width(memoryMediumThreshold + '%');

            var ioThroughput = 0;
            var ioMaxThreshold = 80;
            var ioMediumThreshold = 60;
            ioValue = parseInt(vmObject.stats.io_throughput);
            ioThroughput = (ioValue * 100 / vmObject.stats.io_throughput_peak);
            result.find('.storage-progress-bar').width(ioThroughput + '%');
            result.find('.storage-percentage').html(Math.round(ioThroughput) + 'KB/s');
            result.find('.medium-grey.io').width(ioMaxThreshold + '%');
            result.find('.light-grey.io').width(ioMediumThreshold + '%');

            var netThroughput = 0;
            var netMaxThreshold = 80;
            var netMediumThreshold = 60;
            netValue = parseInt(vmObject.stats.net_throughput);
            netThroughput = (netValue * 100 / vmObject.stats.net_throughput_peak);
            result.find('.network-progress-bar').width(netThroughput + '%');
            result.find('.network-percentage').html(Math.round(netThroughput) + 'KB/s');
            result.find('.medium-grey.network').width(netMaxThreshold + '%');
            result.find('.light-grey.network').width(netMediumThreshold + '%');
        } else {
            result.find('.progress').css("display", "none");
            result.find('.percentage-label').html('--');
            result.find('.measure-label').html('--');
        }

        //Setup the VM Actions
        var guestActions = result.find("div[name=guest-actions]");
        guestActions.find(".shutoff-disabled").prop("disabled", !vmRunningBool);
        guestActions.find(".non-persistent-disabled").prop("disabled", !vmPersistent);
        guestActions.find(".reset-disabled").prop("disabled", vmPoweredOffBool || !vmPersistent);
        guestActions.find(".pause-disabled").prop("disabled", vmPoweredOffBool || !vmPersistent);

        if (vmSuspendedBool) { //VM is paused
            //Hide Start
            guestActions.find(".running-hidden").hide();
            //Hide Pause button and menu
            guestActions.find(".pause-disabled").hide();
            guestActions.find(".pause-hidden").hide();
        }

        if (vmRunningBool) { //VM IS running
            //Hide Start
            guestActions.find(".running-hidden").hide();
            //Hide Resume
            guestActions.find(".resume-hidden").hide();
        }

        if (vmPoweredOffBool) { //VM is powered off
            result.addClass('inactive');
            result.find('.distro-icon').addClass('inactive');
            result.find('.vnc-link').css("display", "none");
            result.find('.column-vnc').html('--');
            //Hide PowerOff
            guestActions.find(".shutoff-hidden").hide();
            //Hide Pause
            guestActions.find(".pause-hidden").hide();
            //Hide Resume
            guestActions.find(".resume-hidden").hide();
        }

        var serialConsoleLinkActions = guestActions.find("[name=vm-serial-console]");
        serialConsoleLinkActions.on("click", function(event) {
            event.preventDefault();
            kimchi.openVmSerialConsole(event);
        });

        var consoleActions = guestActions.find("[name=vm-console]");
        var consoleLinkActions = result.find(".vnc-link");

        if (((vmObject.graphics['type'] == 'vnc') || (vmObject.graphics['type'] == 'spice')) && (!vmPoweredOffBool)) {
            consoleActions.on("click", function(event) {
                event.preventDefault();
                kimchi.openVmConsole(event);
            });
            consoleLinkActions.on("click", function(event) {
                event.preventDefault();
                kimchi.openVmConsole(event);
            });
            consoleActions.show();
        } else { //we don't recognize the VMs supported graphics, so hide the menu choice
            result.find('.vnc-link').css("display", "none");
            result.find('.column-vnc').html('--');
            consoleActions.hide();
            consoleActions.off("click", function(event) {
                event.preventDefault();
                kimchi.openVmConsole(event);
            });
            consoleLinkActions.off("click", function(event) {
                event.preventDefault();
                kimchi.openVmConsole(event);
            });
        }

        //Setup action event handlers
        if (!(vmObject.isCloning || vmObject.isCreating || vmObject.isMigrating)) {

            guestActions.find("[name=vm-start]").on("click", function(event) {
                event.preventDefault();
                kimchi.vmstart(event);
            });
            guestActions.find("[name=vm-poweroff]").on("click", function(event) {
                event.preventDefault();
                kimchi.vmpoweroff(event);
            });
            if ((vmRunningBool) || (vmSuspendedBool)) {
                //If the guest is not running, do not enable reset; otherwise, reset is enabled (when running or paused)
                guestActions.find("[name=vm-reset]").on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmreset(event);
                });
                //If the guest is not running, do not enable shutdown;otherwise, shutdown is enabled (when running or paused)
                guestActions.find("[name=vm-shutdown]").on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmshutdown(event);
                });
            }

            if (vmSuspendedBool) {
                guestActions.find("[name=vm-resume]").on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmresume(event);
                });
            }

            if (vmRunningBool) {
                guestActions.find("[name=vm-pause]").on("click", function(event) {
                    event.preventDefault();
                    kimchi.vmsuspend(event);
                });
            }

            guestActions.find("[name=vm-edit]").on("click", function(event) {
                event.preventDefault();
                kimchi.vmedit(event);
            });
            guestActions.find("[name=vm-delete]").on("click", function(event) {
                event.preventDefault();
                kimchi.vmdelete(event);
            });
            guestActions.find("[name=vm-clone]").on("click", function(event) {
                event.preventDefault();
                kimchi.vmclone(event);
            });
            guestActions.find("[name=vm-migrate]").on('click', function(event) {
                event.preventDefault();
                kimchi.vmmigrate(event);
            });
        } else {
            guestActions.find('.btn').attr('disabled', true);
            result.find('.guest-actions').addClass('hidden');
            result.find('.guest-state').addClass('hidden');
            result.find('.guest-pending').removeClass('hidden');
            pendingText = result.find('.guest-pending .text')
            if (vmObject.isCloning)
                pendingText.text(i18n['KCHAPI6009M']);
            else if (vmObject.isMigrating)
                pendingText.text(i18n['KCHAPI6012M']);
            else
                pendingText.text(i18n['KCHAPI6008M']);
        }
    }
    return result;
};


kimchi.listVmsAuto = function() {
    $('#guests-root-container > .wok-mask').removeClass('hidden');
    //Check if the actions button is opened or not,
    //if opended stop the reload of the itens until closed
    var $isDropdownOpened = $('[name="guest-actions"] ul.dropdown-menu').is(":visible");
    var $isModalOpened = $('#migrate-guest-window').is(":visible");
    if (!$isDropdownOpened && !$isModalOpened) {
        var getCreatingGuests = function() {
            var guests = [];
            kimchi.getTasksByFilter('status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/vms/[^/]+$'), function(tasks) {
                for (var i = 0; i < tasks.length; i++) {
                    var guestUri = tasks[i].target_uri;
                    var guestName = guestUri.split('/')[4]
                    guests.push($.extend({}, kimchi.sampleGuestObject, {
                        name: guestName,
                        isCreating: true
                    }));
                    if (kimchi.trackingTasks.indexOf(tasks[i].id) == -1)
                        kimchi.trackTask(tasks[i].id, null, function(err) {
                            wok.message.error(err.message);
                        }, null);
                }
            }, null, true);
            return guests;
        };
        var getCloningGuests = function() {
            var guests = [];
            kimchi.getTasksByFilter('status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/vms/.+/clone'), function(tasks) {
                for (var i = 0; i < tasks.length; i++) {
                    var guestUri = tasks[i].target_uri;
                    var guestName = guestUri.split('/')[4]
                    guests.push($.extend({}, kimchi.sampleGuestObject, {
                        name: guestName,
                        isCloning: true
                    }));
                    if (kimchi.trackingTasks.indexOf(tasks[i].id) == -1)
                        kimchi.trackTask(tasks[i].id, null, function(err) {
                        wok.message.error(err.message);
                    }, null);
                }
            }, null, true);
            return guests;
        };

        var trackFailedCloningGuests = function() {
            kimchi.getTasksByFilter('status=failed&target_uri=' + encodeURIComponent('^/plugins/kimchi/vms/.+/clone'), function(tasks) {
                for (var i = 0; i < tasks.length; i++) {
                    if (kimchi.trackingTasks.indexOf(tasks[i].id) == -1)
                        kimchi.trackTask(tasks[i].id, null, function(err) {
                           wok.message.error(err.message);
                        }, null);
                }
            }, null, true);
        };

        var getMigratingGuests = function() {
            var guests = [];
            kimchi.getTasksByFilter('status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/vms/.+/migrate'), function(tasks) {
                for (var i = 0; i < tasks.length; i++) {
                    var guestUri = tasks[i].target_uri;
                    var guestName = guestUri.split('/')[4]
                    guests.push($.extend({}, kimchi.sampleGuestObject, {
                        name: guestName,
                        isMigrating: true
                    }));
                    if (kimchi.trackingTasks.indexOf(tasks[i].id) == -1)
                        kimchi.trackTask(tasks[i].id, null, function(err) {
                            wok.message.error(err.message);
                        }, null);
                }
            }, null, true);
            return guests;
        };

        kimchi.listVMs(function(result, textStatus, jqXHR) {
                if (result && textStatus == "success") {
                    // Some clone tasks may fail before being tracked. Show
                    // error message for them.
                    trackFailedCloningGuests();
                    var migrated = getMigratingGuests();
                    for (i = migrated.length - 1; i >= 0; i--) {
                        for (j = result.length - 1; j >= 0; j--) {
                            if (result[j].name == migrated[i].name) result.splice(j, 1);
                        }
                    }
                    result = getMigratingGuests().concat(result);
                    result = getCloningGuests().concat(result);
                    result = getCreatingGuests().concat(result);
                    if (result.length) {
                        var listHtml = '';
                        var guestTemplate = kimchi.guestTemplate;
                        var currentConsoleImages = kimchi.getVmsCurrentConsoleImgs();
                        var openMenuGuest = kimchi.getOpenMenuVmId();
                        $('#guestList').empty();
                        $('.grid-control').removeClass('hidden');
                        $('#guestListField').show();
                        $('#noGuests').hide();
                        // Check if the list is being filtered, if true populate
                        // the #guestList only with the filtered elements
                        listFiltered = ((guestFilterList != undefined) && (guestFilterList.matchingItems.length != result.length) && $('#search_input').val() != "");
                        if (!listFiltered) {
                            $.each(result, function(index, vm) {
                                var guestLI = kimchi.createGuestLi(vm, currentConsoleImages[vm.name], vm.name == openMenuGuest);
                                $('#guestList').append(guestLI);
                            });
                        } else {
                            $.each(result, function(index, vm) {
                                $.each(guestFilterList.matchingItems, function(index, listFiltered) {
                                    if (listFiltered._values.title === vm.name) {
                                        var guestLI = kimchi.createGuestLi(vm, currentConsoleImages[vm.name], vm.name == openMenuGuest);
                                        $('#guestList').append(guestLI);
                                    }
                                });
                            });
                        }
                        $('#guests-root-container > .wok-mask').fadeOut(300, function() {
                        });
                        //check if Architecture is s390x and hide VNC column
                        if(kimchi.hostarch === s390xArch){
                            $('#guests-root-container span.column-vnc').addClass('hidden');
                            $('#guestList a[name="vm-clone"]').hide();
                        }
                    } else {
                        $('.grid-control').addClass('hidden');
                        $('#guestListField').hide();
                        $('#noGuests').show();
                        $('#guests-root-container > .wok-mask').fadeOut(300, function() {});
                    }
                }
            },
            function(errorResponse, textStatus, errorThrown) {
                if (errorResponse.responseJSON && errorResponse.responseJSON.reason) {
                    wok.message.error(errorResponse.responseJSON.reason);
                    $('#guests-root-container > .wok-mask').fadeOut(300, function() {
                        $('#guests-root-container > .wok-mask').addClass('hidden');
                    });
                }
            });
    }
};

kimchi.editTemplate = function(guestTemplate, oldPopStat) {
    if (oldPopStat) {
        return guestTemplate.replace("vm-action", "vm-action open");
    }
    return guestTemplate;
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2014-2016
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.guest_media_main = function() {

    var refreshCDROMs = function() {
        kimchi.listVMStorages({
            vm: kimchi.selectedGuest,
            storageType: 'cdrom'
        }, function(storages) {
            var rowHTML = $('#cdrom-row-tmpl').html();
            var container = $('#guest-edit-cdrom-row-container');
            $(container).empty();

            $.each(storages, function(index, storage) {
                storage['vm'] = kimchi.selectedGuest;
                var templated = wok.substitute(rowHTML, storage);
                container.append(templated);
            });

            var replaceCDROM = function(event) {
                event.preventDefault();
                kimchi.selectedGuestStorage = $(this).data('dev');
                wok.window.open("plugins/kimchi/guest-cdrom-edit.html");
            };

            $('input[type="text"][name="cdrom"]', container).on('click', replaceCDROM);
            $('.replace', container).on('click', replaceCDROM);
        });
    };

    refreshCDROMs();

    var onReplaced = function(params) {
        refreshCDROMs();
    };
    wok.topic('kimchi/vmCDROMReplaced').subscribe(onReplaced);

    kimchi.clearGuestMedia = function() {
        wok.topic('kimchi/vmCDROMReplaced').unsubscribe(onReplaced);
    };
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2014-2016
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.switchPage = function(fromPageId, toPageId, direction) {
    $('.tab-content').css('overflow', 'hidden');
    direction = direction || 'left';
    var toLeftBegin;
    var fromLeftEnd;
    if ('left' === direction) {
        toLeftBegin = '100%';
        fromLeftEnd = '-100%';
    } else if ('right' === direction) {
        toLeftBegin = '-100%';
        fromLeftEnd = '100%';
    }
    var formPage = $('#' + fromPageId);
    var toPage = $('#' + toPageId);
    toPage.css({
        left: toLeftBegin
    });
    formPage.animate({
        left: fromLeftEnd,
        opacity: 0.1
    }, 400, function() {
        $('.tab-content').css('overflow', 'visible');
    });
    toPage.animate({
        left: '0',
        opacity: 1
    }, 400, function() {
        $('.tab-content').css('overflow', 'visible');
    });
};

kimchi.guest_storage_add_main = function() {
    var types = [{
        label: i18n.KCHVMSTOR0001M,
        value: 'cdrom',
    },
    {
        label: i18n.KCHVMSTOR0002M,
        value: 'disk',
    }];
    var typesRunning = [{
        label: i18n.KCHVMSTOR0002M,
        value: 'disk'
    }];

    var source = [{
        label: i18n.KCHVMSTOR0003M,
        value: 'pool'
    },{
        label: i18n.KCHVMSTOR0004M,
        value: 'path'
    }];

    var storageAddForm = $('#form-guest-storage-add');
    var submitButton = $('#guest-storage-button-add');
    var typeTextbox = $('select#guest-storage-type', storageAddForm);
    var pathTextbox = $('input[name="path"]', storageAddForm);
    var poolTextbox = $('select#guest-disk-pool', storageAddForm);
    var sourceTextbox = $('select#guest-disk-source', storageAddForm);
    var sourcenewTextbox = $('select#guest-disk-source-new', storageAddForm);
    var directorypathTextbox = $('#directorypath', storageAddForm);
    var diskpathTextbox = $('#diskpath', storageAddForm);
    var volTextbox = $('select#guest-disk-vol', storageAddForm);
    var newPoolTextbox = $('select#guest-disk-pool-new', storageAddForm);
    var capacityTextbox = $('input[name="capacity"]', storageAddForm);
    var formatTextbox = $('select#guest-disk-format-new', storageAddForm);
    var selectStorageTypeHTML = '';
    var selectStoragePoolHTML = '';
    var selectStorageVolHTML  = '';
    var rbExisting = 'false';
    var s390xArch = 's390x';

    var getFormatList = function() {
        var format = [i18n['KCHVMSTOR0005M'], i18n['KCHVMSTOR0006M'], i18n['KCHVMSTOR0007M'], i18n['KCHVMSTOR0008M'], i18n['KCHVMSTOR0009M'], i18n['KCHVMSTOR0010M']];
        var selectFormatHTML = '';
        var i;
        for (i = 0; i < format.length; i++) {
            selectFormatHTML += '<option value="'+ format[i] + '">' + format[i] + '</option>';
        }
        formatTextbox.empty();
        formatTextbox.append(selectFormatHTML);
        formatTextbox.val("qcow2");
        $(formatTextbox).trigger('change');
        formatTextbox.selectpicker();
        $('.selectpicker').selectpicker('refresh');
    };

    typeTextbox.on('change',function() {
        var pathObject = {'cdrom': ".path-section", 'disk': '.volume-section'};
        selectType = $(this).val();
        $.each(pathObject, function(type, value) {
            if(selectType === type){
                $(value).removeClass('hidden');
            } else if ((selectType === null) && (type === 'disk')) {
                $(value).removeClass('hidden');
            } else {
                $(value).addClass('hidden');
            }
        });
        if ($(".path-section").hasClass('hidden')) {
            $(pathTextbox).val("");
            if ($('#new-disk').checked) {
                $('#existing-disk-box').addClass('hidden');
                $(newPoolTextbox).val('default');
                $(newPoolTextbox).trigger('change');
                $(formatTextbox).val('qcow2');
                $(formatTextbox).trigger('change');
            } else if ($('#existing-disk').checked) {
                $('#new-disk-box').addClass('hidden');
                $(poolTextbox).val('default');
                $(poolTextbox).trigger('change');
            } else {
                //Goes here the first time since radiobuttons are undefined
                if (rbExisting === 'true') {
                    $('#new-disk-box').addClass('hidden');
                } else {
                    $('#existing-disk-box').addClass('hidden');
                    $(formatTextbox).val('qcow2');
                    $(formatTextbox).trigger('change');
                }
            }
        } else {
            $(poolTextbox).val("");
            $(volTextbox).val("");
            $(newPoolTextbox).val("");
            $(capacityTextbox).val("");
            $(formatTextbox).val("");
        }
        $('.selectpicker').selectpicker('refresh');
    });

    var getStoragePools = function(radioButton) {
        kimchi.listStoragePools(function(result) {
            var options = [];
            selectStoragePoolHTML = ''; //reset string
            if (result && result.length) {
                $.each(result, function(index, storagePool) {
                    if (radioButton === 'existing') {
                        if ((storagePool.state==="active") && (storagePool.type !== 'kimchi-iso')) {
                            options.push({
                                label: storagePool.name,
                                value: storagePool.name
                                });
                            selectStoragePoolHTML += '<option value="'+ storagePool.name + '">' + storagePool.name + '</option>';
                        }
                    } else { //new disk
                        if ((storagePool.type !== 'iscsi') && (storagePool.type !== 'scsi') && (storagePool.type !== 'kimchi-iso')) {
                            options.push({
                                label: storagePool.name,
                                value: storagePool.name
                                });
                            selectStoragePoolHTML += '<option value="'+ storagePool.name + '">' + storagePool.name + '</option>';
                        }
                    }
                });
                if (radioButton === 'existing') {
                    poolTextbox.empty();
                    poolTextbox.append(selectStoragePoolHTML);
                    $(poolTextbox).trigger('change');
	            poolTextbox.selectpicker();
                    $('.selectpicker').selectpicker('refresh');
                } else if (radioButton === 'new') { //new disk
                    newPoolTextbox.empty();
                    newPoolTextbox.append(selectStoragePoolHTML);
                    $(newPoolTextbox).val("ISO");
                    newPoolTextbox.selectpicker();
                    getFormatList();
                }
            }
        });
    };

    //First time retrieving list of Storage Pools - defaulting to new disk
    getStoragePools('new');

    if(kimchi.hostarch === s390xArch){
        //initialize source dropdown for new disk
        $('#new-disk-box div.source').show();

        var getStorageSourceNew = function(sourceSelected ) {
            selectStorageSourceHTML = ''; //reset string
            $.each(source, function(index, storageSource) {
                selectStorageSourceHTML += '<option value="'+ storageSource.value + '">' + storageSource.label + '</option>';
            });

            sourcenewTextbox.empty();
            sourcenewTextbox.append(selectStorageSourceHTML);
            sourcenewTextbox.val(sourceSelected);
            $(sourcenewTextbox).trigger('change');
            sourcenewTextbox.selectpicker();
            $('.selectpicker').selectpicker('refresh');
        };

        getStorageSourceNew('pool');

        //initialize source dropdown for existing disk
        $('#existing-disk-box div.source').show();

        var getStorageSource = function(sourceSelected ) {
            selectStorageSourceHTML = ''; //reset string
            $.each(source, function(index, storageSource) {
                selectStorageSourceHTML += '<option value="'+ storageSource.value + '">' + storageSource.label + '</option>';
            });

            sourceTextbox.empty();
            sourceTextbox.append(selectStorageSourceHTML);
            sourceTextbox.val(sourceSelected);
            $(sourceTextbox).trigger('change');
            sourceTextbox.selectpicker();
            $('.selectpicker').selectpicker('refresh');
        };
        getStorageSource('pool');
    }

    poolTextbox.on('change',function() {
        var options = [];
        selectStorageVolHTML = '';
        volTextbox.empty();
        kimchi.listStorageVolumes($(this).val(), function(result) {
            var validVolType = { cdrom: /iso/, disk: /^(raw|qcow|qcow2|qed|vmdk|vpc)$/};
            if (result.length) {
                $.each(result, function(index, value) {
                    // Only unused volume can be attached
                    if (value.used_by.length === 0 && value.isvalid && (value.type !== 'file' || validVolType[selectType].test(value.format))) {
                        options.push({
                            label: value.name,
                            value: value.name
                        });
                    }
                });
                if (options.length) {
                    for (var i = 0; i < options.length; i++) {
                        selectStorageVolHTML += '<option value="'+ options[i].value + '">' + options[i].label + '</option>';
                    }
                    volTextbox.append(selectStorageVolHTML);
                    $(volTextbox).val(options[0].value);
                    $(volTextbox).trigger('change');
                    $(volTextbox).prop('disabled',false);
                }else {
                    $(volTextbox).prop('disabled',true);
                    $(submitButton).prop('disabled', true);
                }
            } else {
                $(volTextbox).prop('disabled',true);
                $(submitButton).prop('disabled', true);
            }
            volTextbox.selectpicker();
            $('.selectpicker').selectpicker('refresh');
        }, null, false);
    });

    if (kimchi.hostarch === s390xArch) {
        sourcenewTextbox.on('change', function() {
            switch ($(this).val()) {
                case 'path':
                    $('#new-disk-box div.pool').hide();
                    $('#new-disk-box div.directorypath').show();
                    $(directorypathTextbox).val("");

                    break;
                default:
                    $('#new-disk-box div.pool').show();
                    $('#new-disk-box div.directorypath').hide();
            }
            $(capacityTextbox).val("").trigger('change');
        });

        sourceTextbox.on('change', function() {
            switch ($(this).val()) {
                case 'path':
                    $('#existing-disk-box div.pool,div.volume').hide();
                    $('#existing-disk-box div.diskpath').show();
                    $(diskpathTextbox).val("").trigger('change');
                    $(submitButton).prop('disabled', true);

                    break;
                default:
                    $('#existing-disk-box div.pool,div.volume').show();
                    $('#existing-disk-box div.diskpath').hide();
                    $(submitButton).prop('disabled', false);
            }
        });
    }

    typeTextbox.on('change',function() {
        var pathObject = {'cdrom': ".path-section", 'disk': '.volume-section'};
        var selectType = $(this).val();
        $.each(pathObject, function(type, value) {
            if(selectType === type){
                $(value).removeClass('hidden');
            } else {
                $(value).addClass('hidden');
            }
        });
    });

    var currentPage = 'new-disk-box';
    $('#existing-disk').on('change',function() {
        if (this.checked) {
            rbExisting = 'true';
            if (currentPage === 'new-disk-box') {
                kimchi.switchPage(currentPage, 'existing-disk-box', 'right');
            }
            currentPage = 'existing-disk-box';
            $('#existing-disk-box').removeClass('hidden');
            $('#new-disk-box').addClass('hidden');
            $('#guest-storage-add-window .modal-body .template-pager').animate({
                height: "300px"
            }, 300);
            getStoragePools('existing');
            if(kimchi.hostarch === s390xArch){
                getStorageSource('pool');
                $(diskpathTextbox).val("").trigger('change');
            }
            $(pathTextbox).val("");
            $(newPoolTextbox).val("");
            $(capacityTextbox).val("");
            $(formatTextbox).val("");
        }
    });

    $('#new-disk').on('change',function() {
        if (this.checked) {
            $(formatTextbox).val("qcow2");
            $(formatTextbox).trigger('change');
            rbExisting = 'false';
            if (currentPage === 'existing-disk-box') {
                kimchi.switchPage(currentPage, 'new-disk-box', 'right');
            } else if($(capacityTextbox).is(":visible") === false ) {
                 kimchi.switchPage(currentPage, 'new-disk-box', 'right');
            }
            currentPage = 'new-disk-box';
            $('#existing-disk-box').addClass('hidden');
            $('#new-disk-box').removeClass('hidden');

            if(kimchi.hostarch === s390xArch){
                getStorageSourceNew('pool');
                $('#guest-storage-add-window .modal-body .template-pager').animate({
                    height: "400px"
                }, 400);
                $(capacityTextbox).val("").trigger('change');
            }else{
                $('#guest-storage-add-window .modal-body .template-pager').animate({
                    height: "300px"
                }, 400);
            }
            $(pathTextbox).val("");
            $(poolTextbox).val("");
            $(volTextbox).val("");
        }
    });

    var selectType = $(typeTextbox).val();
    if (kimchi.thisVMState === 'running') {
        types = typesRunning;
    }
    for (var i = 0; i < types.length; i++) {
        selectStorageTypeHTML += '<option value="'+ types[i].value + '">' + types[i].label + '</option>';
    }
    typeTextbox.append(selectStorageTypeHTML);
    typeTextbox.find('option:first').attr('selected','selected');
    typeTextbox.selectpicker();
    if (kimchi.thisVMState === 'running') {
        $(typeTextbox).val('disk');
        typeTextbox.trigger('change');
        poolTextbox.trigger('change');
    }

    var validateCDROM = function(settings) {
        if (/^((https|http|ftp|ftps|tftp|\/).*)+$/.test(settings['path'])){
            // Delete pool and vol properties since they are not needed for cdrom
            delete settings['pool'];
            delete settings['vol'];
            return true;
        }
        else {
            wok.message.error(i18n['KCHVMSTOR0001E'],'#alert-modal-container2');
            return false;
        }
    };

    var onError = function(result) {
        if(!result) {
            return;
        }
        var msg = result['message'] || (
            result['responseJSON'] && result['responseJSON']['reason']
        );
        wok.message.error(msg);
    };

    var addStorage = function(settings) {
        kimchi.addVMStorage(settings, function(result) {
            wok.window.close();
            wok.topic('kimchi/vmCDROMAttached').publish({
            result: result
            });
        }, function(result) {
            var errText = result['reason'] ||
            result['responseJSON']['reason'];
            wok.message.error(errText, '#alert-modal-container2');
            $.each([submitButton, pathTextbox, poolTextbox, volTextbox, newPoolTextbox, capacityTextbox, formatTextbox], function(i, c) {
                $(c).prop('disabled', false);
            });
        });
    }

    var createVol = function(settings, addVolSettings) {
        kimchi.createVolumeWithCapacity(settings['pool'], {
            name: settings['vol'],
            format: settings['format'],
            capacity: settings['capacity']
        }, function(result) {
            var taskId = result.id;
            function monitorTask() {
                kimchi.getTask(taskId, function(result) {
                    var status = result.status;
                    if (status === "finished") {
                        //Now add newly created volume to VM
                        addStorage(addVolSettings);
                    } else if (status === "running") {
                        setTimeout(monitorTask, 2000);
                        $(submitButton).prop('disabled', true);
                    } else if (status === "failed") {
                        var errText = result['message'] ||
                        result['responseJSON']['reason'];
                        $(submitButton).text(i18n['KCHVMCD6002M']);
                        $(submitButton).prop('disabled', false);
                        $(capacityTextbox).prop('disabled', false);
                        $(formatTextbox).prop('disabled', false);
                        wok.message.error(errText, '#alert-modal-container2');
                    }
                });
            }
            setTimeout(monitorTask, 2000);
        }, onError);
    };

    var bNewDisk = 'false';

    var validateDisk = function(settings) {
        bNewDisk = 'false';
        // Determine whether it's existing disk or new disk
        if($(capacityTextbox).is(":visible") === true ) {
            bNewDisk = 'true';
        }
        if (kimchi.hostarch === s390xArch && ((sourceTextbox.val() === 'path' || sourcenewTextbox.val() === 'path'))) {
            if (bNewDisk === 'true') {
                if ((/^((https|http|ftp|ftps|tftp|\/).*)+$/.test(settings['dir_path'])) && settings['size'] && settings['format']){
                    return true;
                }else{
                    wok.message.error(i18n['KCHVMSTOR0003E'],'#alert-modal-container2');
                    return false;
                }
            }else{
                if (/^((https|http|ftp|ftps|tftp|\/).*)+$/.test(settings['path'])){
                    return true;
                }else{
                    wok.message.error(i18n['KCHVMSTOR0004E'],'#alert-modal-container2');
                    return false;
                }
            }
        }else{
            if (bNewDisk === 'true') {
                if (settings['newpool'] && settings['capacity'] && settings['format']){
                    //Change settings['newpool'] to settings['pool']
                    settings['pool']=settings['newpool'];
                    var vmname = settings['vm'];
                    vmname = vmname + new Date().getTime();
                    //Unique vol name to be created
                    settings['vol']=vmname + ".img";
                    //This is all that is needed for attaching newly created volume to VM
                    var addVolSettings = {
                        vm: settings['vm'],
                        type: settings['type'],
                        vol:  settings['vol'],
                        pool: settings['pool']
                    };
                    var sizeInMB = parseInt(settings['capacity']) * 1024;
                    settings['capacity'] = sizeInMB;
                    //These need to be deleted so they don't get passed to backend
                    delete settings['path'];
                    delete settings['newpool'];
                    //Create an empty storage volume and attach to VM if successful
                    createVol(settings, addVolSettings);
                    return true;
                } else {
                    wok.message.error(i18n['KCHVMSTOR0005E'],'#alert-modal-container2');
                    return false;
                }
            } else {
                if (settings['pool'] && settings['vol']){
                    // Delete path property since it's not needed for disk
                    delete settings['path'];
                    return true;
                } else {
                    wok.message.error(i18n['KCHVMSTOR0002E'],'#alert-modal-container2');
                    return false;
                }
           }
       }
    };

    validator = {cdrom: validateCDROM, disk: validateDisk};
    var submitForm = function(event) {
        if (submitButton.prop('disabled')) {
            return false;
        }
        var bNewDisk = 'false';
        // Determine whether it's existing disk or new disk
        if($(capacityTextbox).is(":visible") === true ) {
            bNewDisk = 'true';
        }

        var formData = storageAddForm.serializeObject();
        if (kimchi.hostarch === s390xArch && ((sourceTextbox.val() === 'path' || sourcenewTextbox.val() === 'path'))) {
            if ($('#new-disk').prop('checked')) {
                var settings = {
                    vm: kimchi.selectedGuest,
                    dir_path: directorypathTextbox.val(),
                    name: kimchi.selectedGuest + '_' + $.now() + '.img',
                    size: capacityTextbox.val(),
                    type: typeTextbox.val(),
                    format: formatTextbox.val()
                };
            } else if ($('#existing-disk').prop('checked')) {
                var settings = {
                    vm: kimchi.selectedGuest,
                    path: diskpathTextbox.val(),
                    type: typeTextbox.val(),
                    format: formatTextbox.val()
                };
            }
        } else {
            var settings = {
                vm: kimchi.selectedGuest,
                type: typeTextbox.val(),
                path: pathTextbox.val(),
                pool: poolTextbox.val(),
                vol: volTextbox.val(),
                newpool: newPoolTextbox.val(),
                format: formatTextbox.val(),
                capacity: capacityTextbox.val()
            };
        }

        $(submitButton).prop('disabled', true);
        $.each([pathTextbox, poolTextbox, volTextbox, newPoolTextbox, capacityTextbox, formatTextbox], function(i, c) {
            $(c).prop('disabled', true);
        });

            // Validate form for cdrom and disk
            validateSpecifiedForm = validator[settings['type']];
            if (!validateSpecifiedForm(settings)) {
                $(submitButton).prop('disabled', false);
                $.each([submitButton, pathTextbox, poolTextbox, volTextbox, newPoolTextbox, capacityTextbox, formatTextbox], function(i, c) {
                    $(c).prop('disabled', false);
                });
                return false;
            }

            if((bNewDisk === 'false' || ((kimchi.hostarch === s390xArch && ((sourceTextbox.val() === 'path' || sourcenewTextbox.val() === 'path')))))){
                addStorage(settings);
            }

        $(submitButton).addClass('loading').text(i18n['KCHVMCD6003M']);
        event.preventDefault();
    };

    storageAddForm.on('submit', submitForm);
    submitButton.on('click', submitForm);
    pathTextbox.on('change input propertychange', function(event) {
        $(submitButton).prop('disabled', $(this).val() === '');
    });
    volTextbox.on('change propertychange', function (event) {
        $(submitButton).prop('disabled', $(this).val() === '');
    });


    if(kimchi.hostarch === s390xArch){
        $(capacityTextbox).on('change input propertychange', function(event){
            if(sourcenewTextbox.val() === 'path'){
                $(submitButton).prop('disabled', $(capacityTextbox).val() === '' || $(directorypathTextbox).val() === '');
            }else{
                $(submitButton).prop('disabled', $(capacityTextbox).val() === '');
            }
        });

        $(directorypathTextbox).on('change input propertychange', function(event){
            if(sourcenewTextbox.val() === 'path'){
                $(submitButton).prop('disabled', $(capacityTextbox).val() === '' || $(directorypathTextbox).val() === '');
            }else{
                $(submitButton).prop('disabled', $(capacityTextbox).val() === '');
            }
        });

        diskpathTextbox.on('change input propertychange', function(event) {
            $(submitButton).prop('disabled', $(this).val() === '');
        });
    }else{
        capacityTextbox.on('change input propertychange', function(event) {
            $(submitButton).prop('disabled', $(this).val() === '');
        });
    }
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.config = undefined;
kimchi.getConfig(function(result) {
    kimchi.config = result;
}, function() {
    kimchi.config = {}
});

kimchi.capabilities = undefined;
kimchi.getCapabilities(function(result) {
    kimchi.capabilities = result;
}, function() {
    kimchi.capabilities = {};
});

kimchi.hostarch = undefined;
kimchi.serverConfig(function(result) {
    kimchi.hostarch = result["arch"];
});

$(function(){
    $('body').removeClass('wok-list wok-gallery');
});
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.NETWORK_TYPE_MACVTAP = "macvtap";
kimchi.NETWORK_TYPE_PASSTHROUGH = "passthrough";
kimchi.NETWORK_TYPE_BRIDGED = "bridge";
kimchi.NETWORK_TYPE_VEPA = "vepa";

kimchi.initNetwork = function() {
    $('body').removeClass('wok-list wok-gallery');

    var toolsHtml = '<li><a id="networkAdd" class="btn-tool" href="javascript:void(0);">'
    toolsHtml += '<i class="fa fa-plus-circle"></i><span>' + i18n['KCHNET6003M'] + '</span></a></li>'

    if(wok.tabMode['network'] === 'admin') {
        $('#toolbar ul.tools').html(toolsHtml);
        $('#networkGrid .wok-nw-grid-header span:last-child').attr('style','display');
        kimchi.initNetworkCreation();
    }
    kimchi.initNetworkListView();
};

wok.addNotificationListener('METHOD:/kimchi/networks', function() {
    $("#networkBody").empty();
    kimchi.initNetworkListView();
});

kimchi.initNetworkListView = function() {
    $('.wok-mask').removeClass('hidden');
    kimchi.listNetworks(function(data) {
        $('[data-toggle="tooltip"]').tooltip();
        var listHtml = '';
        var netList = [];

        for (var i = 0; i < data.length; i++) {
            var network = {
                name : data[i].name,
                in_use : data[i].in_use,
                state : data[i].state === "active" ? "up" : "down"
            };
            if (data[i].connection === "macvtap") {
                network.type = kimchi.NETWORK_TYPE_MACVTAP;
            } else {
                network.type = data[i].connection;
            }
            network.interface = data[i].interfaces ? data[i].interfaces : null;
            network.interface.join();
            network.addrSpace = data[i].subnet ? data[i].subnet : null;
            network.persistent = data[i].persistent;
            netList.push(network);
            listHtml += kimchi.getNetworkItemHtml(network);
        }
        if($('#networkGrid').hasClass('wok-datagrid')) {
            $('#networkGrid').dataGrid('destroy');
        }
        $("#networkBody").html(listHtml);
        for (var i = 0; i < netList.length; i++) {
            kimchi.addNetworkActions(netList[i]);
        }
        if(wok.tabMode["network"] === "admin") {
            $(".column-action").attr("style","display");
        }
        $('#networkGrid').dataGrid({enableSorting: false});
        $('#networkGrid').removeClass('hidden');
        $('.wok-mask').fadeOut(300, function() {});
        $('input', $('.grid-control', '#network-content-container')).on('keyup', function(){
            $('#networkGrid').dataGrid('filter', $(this).val());
        });
    });
};

kimchi.getNetworkItemHtml = function(network) {
    if(!network.interface) {
        network.interface = i18n["KCHNET6001M"];
    }
    if(!network.addrSpace) {
        network.addrSpace = i18n["KCHNET6001M"];
    }
    if(i18n["network_type_" + network.type]) {
        network.type = i18n["network_type_" + network.type];
    }

    var disable_in_use = network.in_use ? "disabled" : "";
    var networkItem = wok.substitute($('#networkItem').html(), {
        name : network.name,
        state : network.state,
        type : network.type,
        interface: network.interface,
        addrSpace : network.addrSpace,
        startClass : network.state === "up" ? "wok-hide-action-item" : "",
        stopClass : network.state === "down" ? "wok-hide-action-item" : disable_in_use,
        stopDisabled : network.in_use ? "disabled" : "",
        editClass : network.state === "up" || network.in_use ? "disabled" : "",
        editDisabled : network.state === "up" || network.in_use ? "disabled" : "",
        deleteClass : network.state === "up" || network.in_use ? "disabled" : "",
        deleteDisabled: network.state === "up" || network.in_use ? "disabled" : ""
    });
    return networkItem;
};

kimchi.stopNetwork = function(network,menu) {
    $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("up", "loading");
    $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass();
    $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-spinner fa-pulse fa-3x fa-fw");
    $("[nwAct='stop']", menu).addClass("disabled");
    kimchi.toggleNetwork(network.name, false, function() {
        $("[nwAct='start']", menu).removeClass("wok-hide-action-item");
        $("[nwAct='stop']", menu).addClass("wok-hide-action-item");
        $("[nwAct='stop']", menu).removeClass("disabled");
        if (!network.in_use) {
            $("[nwAct='delete']", menu).removeClass("disabled");
            $(":first-child", $("[nwAct='delete']", menu)).removeAttr("disabled");
            $("[nwAct='edit']", menu).removeClass("disabled");
            $(":first-child", $("[nwAct='edit']", menu)).removeAttr("disabled");
        }
        $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("loading", "down");
        $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass("fa-power-off");
        $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-power-off");
    }, function(err) {
        $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("loading", "up");
        $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass("fa-power-off");
        $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-power-off");
        if (!network.in_use) {
            $("[nwAct='stop']", menu).removeClass("disabled");
        }
        wok.message.error(err.responseJSON.reason);
    });
}

kimchi.addNetworkActions = function(network) {
    //$(".dropdown-menu", "#" + wok.escapeStr(network.name)).menu();

    $('#' + wok.escapeStr(network.name)).on('click', '.dropdown-menu li', function(evt) {
        var menu = $(evt.currentTarget).parent();
        if ($(evt.currentTarget).attr("nwAct") === "start") {
            $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("down", "loading");
            $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass("fa-power-off");
            $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-spinner fa-pulse fa-3x fa-fw");
            $("[nwAct='start']", menu).addClass("disabled");
            $("[nwAct='delete']", menu).addClass("disabled");
            $(":first-child", $("[nwAct='delete']", menu)).attr("disabled", true);
            $("[nwAct='edit']", menu).addClass("disabled");
            $(":first-child", $("[nwAct='edit']", menu)).attr("disabled", true);
            kimchi.toggleNetwork(network.name, true, function() {
                $("[nwAct='start']", menu).addClass("wok-hide-action-item");
                $("[nwAct='start']", menu).removeClass("disabled");
                $("[nwAct='stop']", menu).removeClass("wok-hide-action-item");
                network.state = "up";
                if (network.in_use) {
                    $("[nwAct='stop']", menu).addClass("disabled");
                }
                $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("loading", "up");
                $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass("fa-power-off");
                $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-power-off");
            }, function(err) {
                $(".network-state", $("#" + wok.escapeStr(network.name))).switchClass("loading","down");
                $(".network-state i", $("#" + wok.escapeStr(network.name))).removeClass("fa-power-off");
                $(".network-state i", $("#" + wok.escapeStr(network.name))).addClass("fa fa-power-off");
                $("[nwAct='start']", menu).removeClass("disabled");
                if (!network.in_use) {
                    $("[nwAct='delete']", menu).removeClass("disabled");
                    $("[nwAct='edit']", menu).removeClass("disabled");
                }
                $(":first-child", $("[nwAct='delete']", menu)).removeAttr("disabled");
                $(":first-child", $("[nwAct='edit']", menu)).removeAttr("disabled");
                wok.message.error(err.responseJSON.reason);
            });
        } else if ($(evt.currentTarget).attr("nwAct") === "stop") {
            if (network.in_use) {
                return false;
            }
            if (!network.persistent) {
                var confirmMessage = i18n['KCHNET6004M'].replace('%1', '<strong>'+network.name+'</strong>');
                var settings = {
                    title : i18n['KCHAPI6001M'],
                    content : confirmMessage,
                    confirm : i18n['KCHAPI6002M'],
                    cancel : i18n['KCHAPI6003M']
                };
                wok.confirm(settings, function() {
                    kimchi.stopNetwork(network, menu);
                    $('#networkGrid').dataGrid('deleteRow', $(evt.currentTarget).parents(".wok-datagrid-row"));
                }, null);
            }
            else {
                kimchi.stopNetwork(network, menu);
                network.state = "down";
            }
        } else if ($(evt.currentTarget).attr("nwAct") === "delete") {
            if (network.state === "up" || network.in_use) {
                return false;
            }
            var confirmMessage = i18n['KCHNET6002M'].replace('%1', '<strong>'+network.name+'</strong>');
            wok.confirm({
                title : i18n['KCHAPI6006M'],
                content : confirmMessage,
                confirm : i18n['KCHAPI6002M'],
                cancel : i18n['KCHAPI6003M']
            }, function() {
                kimchi.deleteNetwork(network.name, function() {
                    $('#networkGrid').dataGrid('deleteRow', $(evt.currentTarget).parents(".wok-datagrid-row"));
                });
            }, null);
        } else if ($(evt.currentTarget).attr("nwAct") === "edit") {
            if (network.state === "up" || network.in_use) {
                return false;
            }
            kimchi.selectedNetwork = network.name;
            wok.window.open('plugins/kimchi/network-edit.html');
        }
    });

    //$("#networkBody .column-action .dropdown.menu-flat").button();

};

kimchi.initNetworkCreation = function() {
    $("#networkAdd").on("click", function() {
        wok.window.open('plugins/kimchi/network-add.html');
    });
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2015-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

 kimchi.network_add_main = function() {
    kimchi.setupNetworkFormEvent();
    kimchi.openNetworkDialog();
};

kimchi.startNetworkCreation = function() {
    var errorCallback = function(){
        $("#networkFormOk").button("enable");
        $("#networkName").removeAttr("readonly");
        $("#networkVlanID").removeAttr("readonly");
        $("#networkFormOk").text(i18n.KCHAPI6005M);
    };
    var network = kimchi.getNetworkDialogValues();
    var data = {
        name : network.name,
        connection: network.type,
        interfaces: [ network.interface ],
        vlan_id: network.vlan_id
    };
    // in PASSTHROUGH and VEPA connection case,
    // network.interface is already an array
    if (data.connection === kimchi.NETWORK_TYPE_PASSTHROUGH ||
        data.connection === kimchi.NETWORK_TYPE_VEPA ) {
        data.interfaces = network.interface;
    }

    kimchi.createNetwork(data, function(result) {
        wok.window.close();
    }, function(data) {
        wok.message.error(data.responseJSON.reason,'#alert-modal-container');
        errorCallback();
    });
};

kimchi.openNetworkDialog = function(okCallback) {
    kimchi.loadInterfaces(undefined, false);

    $("#networkFormOk").on("click", function() {
        $("#networkFormOk").button("disable");
        $("#networkName").prop("readonly", "readonly");
        $("#networkVlanID").prop("readonly", "readonly");
        $("#networkFormOk").text(i18n.KCHAPI6008M);
        kimchi.startNetworkCreation();
    });
    $("#enableVlan").on("click", function() {
        $("#networkVlanID").prop("disabled", !this.checked);
        if (!this.checked) {
            $("#networkVlanID").val("");
        }
    });
};

kimchi.setDefaultNetworkType = function(isInterfaceAvail, bEdit) {
    $("#networkType").selectpicker();
    if (!isInterfaceAvail) {
        if (!bEdit) {
            kimchi.enableBridgeOptions(false);
        }
        $("#destinationList button").addClass("disabled");
        $("#networkDestinationID").attr("title", "No interface available");
    }
};

kimchi.getNetworkDialogValues = function() {
    var network = {
        name : $("#networkName").val(),
        type : $("#networkType").val()
    };
    if (network.type === kimchi.NETWORK_TYPE_MACVTAP ||
        network.type === kimchi.NETWORK_TYPE_PASSTHROUGH ||
        network.type === kimchi.NETWORK_TYPE_VEPA) {
        network.interface = $("#networkDestinationID").val();
    }
    if (network.type === kimchi.NETWORK_TYPE_BRIDGED) {
        network.interface = $("#networkDestinationID").val();
        if ($("#enableVlan").prop("checked") && ($("#networkDestinationID").find(':selected').data('type') === 'nic' || $("#networkDestinationID").find(':selected').data('type') === 'bonding')) {
            network.vlan_id = parseInt($("#networkVlanID").val());
        }
    }
    return network;
};

kimchi.setupNetworkFormEvent = function() {
    if (kimchi.capabilities && kimchi.capabilities.nm_running) {
            wok.message.warn(i18n['KCHNET6001W'],'#alert-modal-container');
    }
    $('#bridgedContent').hide();
    $("#networkName").on("keyup", function(event) {
        $("#networkName").toggleClass("invalid-field", !$("#networkName").val().match(/^[^\"\/]+$/));
        kimchi.updateNetworkFormButton();
    });

    $('#networkType').on('change', function() {
        var selectedType = $("#networkType").val();
        if(selectedType === kimchi.NETWORK_TYPE_MACVTAP ||
           selectedType === kimchi.NETWORK_TYPE_PASSTHROUGH ||
           selectedType === kimchi.NETWORK_TYPE_VEPA) {

            if (selectedType === kimchi.NETWORK_TYPE_MACVTAP) {
                $('#networkDestinationID').attr('multiple', false).data('liveSearch',false);
            }
            else {
                $('#networkDestinationID').attr('multiple', true);
                if($('#networkDestinationID option').length > 10 ) {
                    $('#networkDestinationID').data('liveSearch',true);
                }
            }
            $('#networkDestinationID').selectpicker('destroy');
            kimchi.loadInterfaces(new Array("nic", "bonding"), false);
        } else {
            kimchi.loadInterfaces(undefined, false);
        }
    });

    $('#networkDestinationID').on('change', function() {
        kimchi.changeNetworkDestination();
    });
};

kimchi.changeNetworkDestination = function() {
    var selectedType = $("#networkType").val();
    var selectedDestinationType = $("#networkDestinationID").find(':selected').data('type');
    if(selectedType ==  'isolated' ||  selectedType ==  'nat') {
        kimchi.enableBridgeOptions(false);
    } else {
        kimchi.enableBridgeOptions(true, selectedType, selectedDestinationType);
    }
}

kimchi.updateNetworkFormButton = function() {
    if($("#networkName").hasClass("invalid-field")){
        $("#networkFormOk").attr('disabled', true);
    } else{
        $("#networkFormOk").attr('disabled', false);
    }
};

kimchi.enableBridgeOptions = function(enable, networkType, networkDestinationType) {
    $("#enableVlan").prop("checked", false);
    $("#networkVlanID").val("");
    $('#vlan').hide();
    if (enable) {
        $('#bridgedContent').slideDown(300);
        $('#enableVlan').prop("disabled", false);
        $('#networkVlanID').prop("disabled", true);
        if (networkType === kimchi.NETWORK_TYPE_BRIDGED && (networkDestinationType === 'nic' || networkDestinationType === 'bonding')) {
            $('#vlan').show();
        }
    } else {
        $('#bridgedContent').slideUp(300);
        $('#enableVlan').prop("disabled", true);
        $('#networkVlanID').prop("disabled", true);
    };
};

kimchi.createInterfacesOpts = function(ifaces, interfaceFilterArray) {
    var options = [];
    $selectDestination = $('#networkDestinationID');
    var nics = {};
    $('#networkDestinationID').find('option').remove();
    var selectDestinationOptionHTML = '';
    for (var i = 0; i < ifaces.length; i++) {
        if (typeof interfaceFilterArray === 'undefined') {
            options.push({label:ifaces[i].name,value:ifaces[i].name});
            nics[ifaces[i].name] = ifaces[i];
            selectDestinationOptionHTML += '<option data-type="' + ifaces[i].type + '" value="'+ ifaces[i].name + '">' + ifaces[i].name + '</option>';
        } else {
            for (var k = 0; k < interfaceFilterArray.length; k++) {
                if (ifaces[i].type == interfaceFilterArray[k]) {
                    options.push({label:ifaces[i].name,value:ifaces[i].name});
                    nics[ifaces[i].name] = ifaces[i];
                    selectDestinationOptionHTML += '<option data-type="'+ ifaces[i].type +'" value="'+ ifaces[i].name + '">' + ifaces[i].name + '</option>';
                }
            }
        }
    }
    $selectDestination.append(selectDestinationOptionHTML);
    $('#networkDestinationID').selectpicker('refresh');
};

kimchi.loadInterfaces = function(interfaceFilterArray, bEdit) {

    var loadInterfacesHTML = function(result) {
        kimchi.createInterfacesOpts(result, interfaceFilterArray);
        kimchi.setDefaultNetworkType(result.length!==0, bEdit);
        if (!bEdit) {
            kimchi.changeNetworkDestination();
        }
    };

    var networkType = $("#networkType").val();
    if (networkType === kimchi.NETWORK_TYPE_VEPA) {
        kimchi.getVEPAInterfaces(loadInterfacesHTML);
    } else {
        kimchi.getInterfaces(loadInterfacesHTML);
    }
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2016-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.network_edit_main = function() {
    var initNetwork = function(network) {
        var networkType = network['connection'];
        $('#bridgedContent').hide();
        $('#networkType').val(networkType);
        $('#networkName').val(kimchi.selectedNetwork);

        var subnetValue = network['subnet'];
        if (subnetValue === "") {
            $('#networkSubnetRange').val("unavailable");
        } else {
            $('#networkSubnetRange').val(subnetValue);
        }

        // Default to hide Subnet
        $('#subnetRange').hide();

        if(networkType === "nat" || networkType === "isolated") {
            //Show subnet/dhcp range
            $('#subnetRange').show();
        }

        if (networkType === kimchi.NETWORK_TYPE_MACVTAP ||
            networkType === kimchi.NETWORK_TYPE_PASSTHROUGH ||
            networkType === kimchi.NETWORK_TYPE_VEPA ||
            networkType === kimchi.NETWORK_TYPE_BRIDGED) {
            $('#bridgedContent').show();
            $('#networkDestination').show();
            $('#vlan').hide();
            if (networkType === kimchi.NETWORK_TYPE_BRIDGED) {
                //Now check if there's a vlan id and only show if one exists
                var netInterface = network['interfaces'];
                var netInterfaceParts = netInterface[0].split('-', 2);
                var netvlanID = netInterfaceParts[1];
                if (netvlanID !== undefined) {
                    //Show vlan ID field; do not show the checkbox
                    $('#vlan').show();
                    $('#vlan_chkbox').hide();
                    $('#vlan-enabled').show();
                    $('#networkVlanID').val(netvlanID);
                }
            }
        }

        kimchi.setupNetworkFormEventForEdit(network);
    };

    kimchi.retrieveNetwork(kimchi.selectedNetwork, initNetwork);

    var generalSubmit = function(event) {
        $('#networkFormOk').text(i18n['KCHAPI6010M']);
        $('#networkFormOk').prop('disabled', true);

        var data = $('#networkConfig').serializeObject();
        kimchi.updateNetworkValues();
    };

    $('#networkConfig').on('submit', generalSubmit);
    $('#networkFormOk').on('click', generalSubmit);
};

kimchi.setupNetworkFormEventForEdit = function(network) {
    var selectedType = network['connection'];
    if (selectedType === kimchi.NETWORK_TYPE_BRIDGED) {
        if (kimchi.capabilities && kimchi.capabilities.nm_running) {
          wok.message.warn(i18n['KCHNET6001W'],'#alert-modal-container');
        }
    }

    // Network name validation
    $("#networkName").on("keyup", function(event) {
        $("#networkName").toggleClass("invalid-field", !$("#networkName").val().match(/^[^\"\/]+$/));
        kimchi.updateNetworkFormButtonForEdit();
    });

    var loadIfaces = function(interfaceFilterArray){
        var buildInterfaceOpts = function(result) {
            var currentIfaces = network['interfaces'];
            for (var i = 0; i < currentIfaces.length; i++) {
                kimchi.getInterface(currentIfaces[i], function(iface) {
                    result.push(iface);
                } , null, true);
            }
            kimchi.createInterfacesOpts(result, interfaceFilterArray);

            for (var i = 0; i < currentIfaces.length; i++) {
                $("#networkDestinationID option[value='" + currentIfaces[i] + "']").attr('selected','selected');
            }
            $('#networkDestinationID').selectpicker('refresh');
        };

        var networkType = $("#networkType").val();
        if (networkType === kimchi.NETWORK_TYPE_VEPA) {
            kimchi.getVEPAInterfaces(buildInterfaceOpts);
        } else {
            kimchi.getInterfaces(buildInterfaceOpts);
        }
    }

    var selectedType = network['connection'];
    if(selectedType === kimchi.NETWORK_TYPE_MACVTAP ||
       selectedType === kimchi.NETWORK_TYPE_PASSTHROUGH ||
       selectedType === kimchi.NETWORK_TYPE_VEPA) {
        if (selectedType === kimchi.NETWORK_TYPE_MACVTAP) {
            $('#networkDestinationID').attr('multiple', false).data('liveSearch',false);
        } else {
            $('#networkDestinationID').attr('multiple', true);
            if($('#networkDestinationID option').length > 10 ) {
                $('#networkDestinationID').data('liveSearch',true);
            }
        }
        $('#networkDestinationID').selectpicker('destroy');

        loadIfaces(new Array("nic", "bonding"));
    } else {
        loadIfaces(undefined);
    }
};

kimchi.updateNetworkFormButtonForEdit = function() {
    if ($("#networkName").hasClass("invalid-field")) {
        $('#networkFormOk').prop('disabled', true);
    } else{
        $('#networkFormOk').prop('disabled', false);
    }
};

kimchi.getNetworkDialogValuesForEdit = function() {
    var network = {
        name : $("#networkName").val(),
        type : $("#networkType").val(),
        subnetRange: $("#networkSubnetRange").val(),
        interface: $("#networkDestinationID").val(),
        vlan_id: $("#networkVlanID").val()
    };
    if (network.type === kimchi.NETWORK_TYPE_BRIDGED) {
        if (network.vlan_id !== "") {
            network.vlan_id = parseInt($("#networkVlanID").val());
        }
    }
    return network;
};

kimchi.updateNetworkValues = function() {
    kimchi.retrieveNetwork(kimchi.selectedNetwork, function(settings) {
        var network = kimchi.getNetworkDialogValuesForEdit();
        var data = {
            name : network.name,
            subnet: network.subnetRange,
            interfaces: [ network.interface ],
            vlan_id: network.vlan_id
        };
        var originalDest = settings.interfaces;
        var updatedDest = $('#networkDestinationID').val();
        if (originalDest === updatedDest || updatedDest === null) {
            delete data['interfaces'];
        }
        if (network.type !== "nat" && network.type !== "isolated") {
            delete data['subnet'];
        } else { // either nat or isolated
            delete data['interfaces'];
            delete data['vlan_id'];
        }
        if (network.type === kimchi.NETWORK_TYPE_BRIDGED) {
            if (data.vlan_id === "") {
                delete data['vlan_id'];
            } else {
                data.vlan_id = parseInt($("#networkVlanID").val());
            }
        } else {
            delete data['vlan_id'];
        }

        // Just like in Add Network, VEPA connection - network.interface - is already an array
        if (network.type === kimchi.NETWORK_TYPE_VEPA || network.type === kimchi.NETWORK_TYPE_PASSTHROUGH) {
            if (network.interface !== null) {
                data.interfaces = network.interface;
            }
        }

        kimchi.updateNetwork(kimchi.selectedNetwork, data, function(result) {
            wok.window.close();
        }, function(settings) {
            wok.message.error(settings.responseJSON.reason,'#alert-modal-container');
            $('#networkFormOk').text(i18n['KCHAPI6007M']);
            $('#networkFormOk').prop('disabled', false);
        });
    });
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the 'License');
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.doListStoragePools = function() {
    $('.wok-mask').removeClass('hidden');
    kimchi.listStoragePools(function(result) {
        var storageHtml = $('#storageTmpl').html();
        if (result && result.length) {
            var listHtml = '';
            $.each(result, function(index, value) {
                value.usage = Math.round(value.allocated / value.capacity * 100) || 0;
                if (value.usage <= 100 && value.usage >= 85) {
                    value.icon = 'icon-high';
                }else if (value.usage <= 85 && value.usage >= 75 ) {
                    value.icon = 'icon-med';
                } else {
                    value.icon = 'icon-low';
                }
                value.capacity = wok.changetoProperUnit(value.capacity,1);
                value.allocated = wok.changetoProperUnit(value.allocated,1);
                value.enableExt = value.type==="logical" ? "" : "hide-content";
                if ('kimchi-iso' !== value.type) {
                    listHtml += wok.substitute(storageHtml, value);
                }
            });
            if($('#storageGrid').hasClass('wok-datagrid')) {
                $('#storageGrid').dataGrid('destroy');
            }
            $('#storagepoolsList').html(listHtml);
            if(wok.tabMode['storage'] === 'admin') {
                $('.storage-button').attr('style','display');
            } else {
                $('.storage-allocate').addClass('storage-allocate-padding-user');
            }
            $('#storageGrid').dataGrid({enableSorting: false});
            $('#storageGrid').removeClass('hidden');
            $('.wok-mask').fadeOut(300, function() {});
            $('input', $('.grid-control', '.storage')).on('keyup', function(){
                $('#storageGrid').dataGrid('filter', $(this).val());
            });
            kimchi.storageBindClick();
        } else {
            $('.wok-mask').fadeOut(300, function() {});
            $('#storagepoolsList').html('');
        }
    }, function(err) {
        $('.wok-mask').fadeOut(300, function() {});
        wok.message.error(err.responseJSON.reason);
    });
};

kimchi.storageBindClick = function() {

   $('.volumes').on('click','.toggle-gallery',function(e){
        e.preventDefault();
        e.stopPropagation();
        var button = $(this);
        var volumeBlock = $(this).parent().parent().parent();
        var text = $('span.text', button).text();
        $(".wok-list, .wok-gallery",volumeBlock).toggleClass("wok-list wok-gallery");
        $('span.text', button).text(text == i18n['KCHTMPL6005M'] ? i18n['KCHTMPL6004M'] : i18n['KCHTMPL6005M']);
    });

    if(wok.tabMode['storage'] === 'admin') {

        $('.volumes').on('click','.volume-delete',function(e){
            e.preventDefault();
            e.stopPropagation();
            var button = $(this);
            $('.dropdown.pool-action.open .dropdown-toggle').dropdown('toggle');
            kimchi.selectedSP = $(this).data('name');
            var volumeBlock = $(this).data('name');
            var volumes = $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').map(function(){
              return this.value;
            }).get();
            kimchi.selectedVolumes = volumes.slice();
            var formatedVolumes = '';
            if(kimchi.selectedVolumes.length && !button.parent().is('disabled')){
                for (i = 0; i < kimchi.selectedVolumes.length; i++) {
                    formatedVolumes += "<li>" + kimchi.selectedVolumes[i] + "</li>";
                }
                var confirmMessage = i18n['KCHPOOL6010M'].replace('%1','<ul>'+formatedVolumes+'</ul>'+i18n['KCHPOOL6009M']);
                var settings = {
                    title : i18n['KCHAPI6001M'],
                    content : confirmMessage,
                    confirm : i18n['KCHAPI6002M'],
                    cancel : i18n['KCHAPI6003M']
                };
                wok.confirm(settings, function() {
                    $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').prop('disabled',true);
                    $.each(kimchi.selectedVolumes, function(i,j) {
                        $('[data-volume-name="'+j+'"] .volume-inline-progress').removeClass('hidden');
                        volumes = jQuery.grep(volumes, function(value) {
                          return value != j;
                        });
                        kimchi.deleteStoragePoolVolume(kimchi.selectedSP,j,function(){
                            wok.topic('kimchi/storageVolumeDeleted').publish();
                        },function(err){
                            wok.message.error(err.responseJSON.reason);
                        });
                        if(volumes.length === 0){
                            kimchi.selectedVolumes = '';
                            wok.topic('kimchi/storageVolumeDeleted').publish();
                        }
                    });
                });
            }else {
                return false;
            }
        });

        $('.volumes').on('click','.volume-wipe',function(e){
            e.preventDefault();
            e.stopPropagation();
            var button = $(this);
            $('.dropdown.pool-action.open .dropdown-toggle').dropdown('toggle');
            kimchi.selectedSP = $(this).data('name');
            var volumeBlock = $(this).data('name');
            var volumes = $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').map(function(){
              return this.value;
            }).get();
            kimchi.selectedVolumes = volumes.slice();
            var formatedVolumes = '';
            if(kimchi.selectedVolumes.length && !button.parent().is('disabled')){
                for (i = 0; i < kimchi.selectedVolumes.length; i++) {
                    formatedVolumes += "<li>" + kimchi.selectedVolumes[i] + "</li>";
                }
                var confirmMessage = i18n['KCHPOOL6017M'].replace('%1','<ul>'+formatedVolumes+'</ul>'+i18n['KCHPOOL6009M']);
                var settings = {
                    title : i18n['KCHPOOL6018M'],
                    content : confirmMessage,
                    confirm : i18n['KCHAPI6002M'],
                    cancel : i18n['KCHAPI6003M']
                };
                wok.confirm(settings, function() {
                    $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').prop('disabled',true);
                    $.each(kimchi.selectedVolumes, function(i,j) {
                        $('[data-volume-name="'+j+'"] .volume-inline-progress').removeClass('hidden');
                        volumes = jQuery.grep(volumes, function(value) {
                          return value != j;
                        });
                        kimchi.wipeStoragePoolVolume(kimchi.selectedSP,j,function(){
                            wok.topic('kimchi/storageVolumeWiped').publish();
                        },function(err){
                            wok.message.error(err.responseJSON.reason);
                        });
                        if(volumes.length === 0){
                            kimchi.selectedVolumes = '';
                            wok.topic('kimchi/storageVolumeWiped').publish();
                        }
                    });
                });
            }else {
                return false;
            }
        });

        $('.volumes').on('click','.volume-resize',function(e){
            e.preventDefault();
            e.stopPropagation();
            var button = $(this);
            $('.dropdown.pool-action.open .dropdown-toggle').dropdown('toggle');
            kimchi.selectedSP = $(this).data('name');
            var volumes = $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').map(function(){
              return this.value;
            }).get();
            kimchi.selectedVolumes = volumes.slice(0,1);
            if(kimchi.selectedVolumes.length && !button.parent().is('disabled')){
                wok.window.open('plugins/kimchi/storagepool-resize-volume.html');
            }else {
                return false;
            }
        });

        $('.volumes').on('click','.volume-clone',function(e){
            e.preventDefault();
            e.stopPropagation();
            var button = $(this);
            $('.dropdown.pool-action.open .dropdown-toggle').dropdown('toggle');
            kimchi.selectedSP = $(this).data('name');
            var volumeBlock = $(this).data('name');
            var volumes = $('[data-name="'+kimchi.selectedSP+'"] input:checkbox:checked').map(function(){
              return this.value;
            }).get();
            kimchi.volumesToClone = volumes.slice();
            var formatedVolumes = '';
            if(kimchi.volumesToClone.length && !button.parent().is('disabled')){
                    $.each(kimchi.volumesToClone, function(i,j) {
                        volumes = jQuery.grep(volumes, function(value) {
                          return value != j;
                        });
                        var data = {};
                        data = {
                            pool: kimchi.selectedSP
                        }
                        kimchi.cloneStoragePoolVolume(kimchi.selectedSP,j,data,function(){
                            wok.topic('kimchi/storageVolumeCloned').publish();
                        },function(err){
                            wok.message.error(err.responseJSON.reason);
                        });
                        if(volumes.length === 0){
                            kimchi.volumesToClone = '';
                            wok.topic('kimchi/storageVolumeCloned').publish();
                        }
                    });
            }else {
                return false;
            }
        });

        $('.volumes').on('click','.wok-datagrid-row',function(e){
            if (!$(e.target).is("input[type='checkbox']") && !$(e.target).is("label")) {
                var volumeBlock = $(this);
                var checkbox = volumeBlock.find('[name="selected-volume[]"]');
                checkbox.trigger('click');
            }
        });

        $('.volumes').on('change','[name="selected-volume[]"]',function(e){
            var checkbox = $(this);
            var volumeBlock = $(this).closest('.wok-datagrid-row');
            var volumesBlock = $(this).closest('.volumeslist');
            var poolType = volumesBlock.data('type')
            var selectedVolumes = $('[name="selected-volume[]"]:checked',volumesBlock)
            var disabled = [];
            var enabled = [];

            // No volume selected
            if (selectedVolumes.length === 0) {
                disabled = ['volume-resize','volume-clone','volume-wipe','volume-delete'];
                enabled = [];
            // One or more volumes selected
            } else {
                // Read-write pools
                if (poolType !== 'scsi' && poolType !== 'iscsi') {
                    // Not able to resize more than one volume
                    // Logical pools don't enable resize of their volumes
                    if (selectedVolumes.length > 1 || poolType === 'logical') {
                        disabled = ['volume-resize'];
                        enabled = ['volume-clone','volume-wipe','volume-delete'];
                    } else {
                        disabled = [];
                        enabled = ['volume-resize','volume-clone','volume-wipe', 'volume-delete'];
                    }
                }
            }

            for (i = 0; i < disabled.length; i++) {
                $('.'+disabled[i],volumesBlock).parent().addClass('disabled');
            }

            for (i = 0; i < enabled.length; i++) {
                $('.'+enabled[i],volumesBlock).parent().removeClass('disabled');
            }

            if(checkbox.is(":checked")){
                volumeBlock.addClass('selected');
            }else {
                volumeBlock.removeClass('selected');
            }
        });

    }

    $('.inactive').each(function(index) {
        if ('active' === $(this).data('state')) {
            $(this).hide();
        } else {
            $(this).show();
        }
    });

    $('.list-storage .storage-state .active').each(function(index) {
        if ('active' === $(this).data('state')) {
            $(this).show();
        } else {
            $(this).hide();
        }
    });

    $('.pool-activate').each(function(index) {
        if ('active' === $(this).data('stat')) {
            $(this).hide();
        } else {
            $(this).show();
        }
    });

    $('.pool-deactivate').each(function(index) {
        if ('active' === $(this).data('stat')) {
            $(this).show();
        } else {
            $(this).hide();
        }
    });

    $('.volume-add').each(function(index) {
        var canAddVolume =
            $(this).data('stat') === 'active' &&
            $(this).data('type') !== 'iscsi' &&
            $(this).data('type') !== 'scsi';
        if(canAddVolume) {
            $(this).parent().removeClass('disabled');
        }
        else {
            $(this).parent().addClass('disabled');
        }
    });

    $('.volumeslist').each(function(index) {
        var rwpool = $(this).data('type') !== 'iscsi' &&
                      $(this).data('type') !== 'scsi'

        if (!rwpool)
            $('.pool-action', $(this)).addClass('hidden');
    });

    if(wok.tabMode['storage'] === 'admin') {
        $('.pool-delete').on('click', function(event) {
            event.preventDefault();
            var $pool = $(this);
            var poolName = $pool.data('name');
            var confirmMessage = i18n['KCHPOOL6001M'].replace('%1', '<strong>'+poolName+'</strong>');
            var in_use = $pool.data('inuse');
            if ('active' === $pool.data('stat') || in_use) {
                $pool.parent().addClass('disabled');
                return false;
            } else {
                $pool.parent().removeClass('disabled');
            }
            var settings = {
                title : i18n['KCHAPI6001M'],
                content : confirmMessage,
                confirm : i18n['KCHAPI6002M'],
                cancel : i18n['KCHAPI6003M']
            };
            wok.confirm(settings, function() {
                kimchi.deleteStoragePool(poolName, function() {
                    kimchi.doListStoragePools();
                }, function(err) {
                    wok.message.error(err.responseJSON.reason);
                });
            });
        });

        $('.pool-activate').on('click', function(event) {
            event.preventDefault();
            var poolName = $(this).data('name');
            kimchi.changePoolState(poolName, 'activate', function() {
                kimchi.doListStoragePools();
            }, function(err) {
                wok.message.error(err.responseJSON.reason);
            });
        });

        $('.pool-deactivate').on('click', function(event) {
            event.preventDefault();
            var poolName = $(this).data('name');
            var confirmMessage = i18n['KCHPOOL6012M'].replace('%1', '<strong>'+poolName+'</strong>');
            var $poolDeactivate = $(this);
            var in_use = $poolDeactivate.data('inuse');
            if (in_use) {
                $poolDeactivate.parent().addClass('disabled');
                return false;
            } else {
                $poolDeactivate.parent().removeClass('disabled');
            }
            var settings = {
                title : i18n['KCHAPI6001M'],
                content : confirmMessage,
                confirm : i18n['KCHAPI6002M'],
                cancel : i18n['KCHAPI6003M']
            };
            if (!$(this).data('persistent')) {
                wok.confirm(settings, function() {
                    kimchi.changePoolState(poolName, 'deactivate', function() {
                        kimchi.doListStoragePools();
                    }, function(err) {
                        wok.message.error(err.responseJSON.reason);
                    });
                }, function() {
                    return false;
                });
            }
            else {
                kimchi.changePoolState(poolName, 'deactivate', function() {
                    kimchi.doListStoragePools();
                }, function(err) {
                    wok.message.error(err.responseJSON.reason);
                });
            }
        });

        $('.volume-add').on('click', function(event) {
            event.preventDefault();
            var poolName = $(this).data('name');
            kimchi.selectedSP = poolName;
            wok.window.open('plugins/kimchi/storagepool-add-volume.html');
        });

        $('.storage-action').on('click', function(event) {
            event.preventDefault();
            var storage_action = $(this);
            var deleteButton = storage_action.find('.pool-delete');
            var deactivateButton = storage_action.find('.pool-deactivate');
            var in_use = deleteButton.data('inuse');
            if ('active' === deleteButton.data('stat') || in_use) {
                deleteButton.parent().addClass('disabled');
            } else {
                deleteButton.parent().removeClass('disabled');
            }

            if (in_use) {
                deactivateButton.parent().addClass('disabled');
            } else {
                deactivateButton.parent().removeClass('disabled');
            }
        });

        $('.pool-extend').on('click', function(event) {
            event.preventDefault();
            var poolName = $(this).data('name');
            kimchi.selectedSP = poolName;
        });
    }

    $('.wok-datagrid-row .handle ').on('click', function(event) {
        if (!$(event.target).parents().hasClass('bottom')) {
            if ($(this).parent().parent().data('stat') === 'active') {
                var that = $(this).parent().parent();
                var volumeDiv = $('#volume' + that.data('name'));
                var slide = $('.volumes', $(this).parent().parent());
                if (that.hasClass('in')) {
                    that.css('height','auto');
                    kimchi.doListVolumes(that);
                } else {
                    slide.slideUp('slow', function(){
                        that.css('height','');
                    });
                    that.addClass('in');
                    kimchi.changeArrow($('.arrow-up', $(this).parent().parent()));
                }
            }
        }
    });
};

kimchi._generateVolumeHTML = function(volume) {
    if(volume['type'] === 'kimchi-iso') {
        return '';
    }
    var volumeHtml = $('#volumeTmpl').html();
    volume.used_by_formatted = '';
    volume.used_by_text = '';
    volume.checkbox = volume.name.replace(/[`~!@#$%^&*()_|+\-=?;:'",.<>\{\}\[\]\\\/]/gi,'-'),
    volume.capacityLevel = Math.round(volume.allocation / volume.capacity * 100) || 0;
    if (volume.capacityLevel > 100) {
        volume.capacityIcon = 'icon-high';
        volume.capacityLevel = 100;
    } else if (volume.capacityLevel <= 100 && volume.capacityLevel >= 85) {
        volume.capacityIcon = 'icon-high';
    }else if (volume.capacityLevel <= 85 && volume.capacityLevel >= 75 ) {
        volume.capacityIcon = 'icon-med';
    } else {
        volume.capacityIcon = 'icon-low';
    }
    if(volume.used_by.length){
        for (var i = 0; i < volume.used_by.length; i++) {
                    (i + 1 < volume.used_by.length) ? volume.used_by_text += volume.used_by[i] +', ' : volume.used_by_text += volume.used_by[i];
                    (i + 1 < volume.used_by.length) ? volume.used_by_formatted += volume.used_by[i] +'<br />' : volume.used_by_formatted += volume.used_by[i];
        }
    }else {
        volume.used_by_formatted = '';
        volume.used_by_text = '--';
    }
    volume.capacity = wok.changetoProperUnit(volume.capacity,1);
    volume.allocation = wok.changetoProperUnit(volume.allocation,1);
    volumeHtml = wok.substitute(volumeHtml, volume);
    volumeHtml = $.trim(volumeHtml);
    volumeHtml = $.parseHTML(volumeHtml);
    if(!volume.used_by.length){
        $('i.fa.fa-exclamation-circle',volumeHtml).remove();
        $('span.format-text',volumeHtml).removeAttr('title data-toggle data-original-title data-placement');
    }
    return volumeHtml[0].outerHTML;
};


kimchi.getPoolUsageIcon = function(usage) {
    if (usage <= 100 && usage >= 85)
        return 'icon-high';

    if (usage <= 85 && usage >= 75)
        return 'icon-med';

    return 'icon-low';
};


kimchi.doUpdateStoragePool = function(poolObj){
    var poolName = poolObj.data('name');
    kimchi.getStoragePool(poolName, function(result) {
        result.usage = Math.round(result.allocated / result.capacity * 100) || 0;
        result.icon = kimchi.getPoolUsageIcon(result.usage);
        result.allocated = wok.changetoProperUnit(result.allocated,1);
        $('> .column-usage > .usage-icon',poolObj).attr('class', 'usage-icon').addClass(result.icon).text(result.usage);
        $('> .column-allocated',poolObj).attr('val',result.allocated).text(result.allocated);
    },function(){
        return false;
    });
};

kimchi.doListVolumes = function(poolObj) {
    var poolName = poolObj.data('name');

    var getOngoingVolumes = function() {
        var result = {};
        var clone = 'status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/storagepools/.+/storagevolumes/.+/clone');
        var filter = 'status=running&target_uri=' + encodeURIComponent('^/plugins/kimchi/storagepools/' + poolName + '/*');
        kimchi.getTasksByFilter(filter, function(tasks) {
            for(var i = 0; i < tasks.length; i++) {
                if(tasks[i].message !== 'cloning volume') {
                    var volumeName = tasks[i].target_uri.split('/').pop();
                    result[volumeName] = tasks[i];

                    if(kimchi.trackingTasks.indexOf(tasks[i].id) >= 0) {
                        continue;
                    }

                    kimchi.trackTask(tasks[i].id, function(result) {
                        wok.topic('kimchi/volumeTransferFinished').publish(result);
                    }, function(result) {
                        wok.topic('kimchi/volumeTransferError').publish(result);
                    }, function(result) {
                        wok.topic('kimchi/volumeTransferProgress').publish(result);
                    });
                }
            }
        }, null, true);
        kimchi.getTasksByFilter(clone, function(tasks) {
            for(var i = 0; i < tasks.length; i++) {
                if(tasks[i].message === 'cloning volume') {
                    var volumeName = tasks[i].target_uri.split('/')[6];
                    result[volumeName] = tasks[i];

                    if(kimchi.trackingTasks.indexOf(tasks[i].id) >= 0) {
                        continue;
                    }

                    kimchi.trackTask(tasks[i].id, function(result) {
                        wok.topic('kimchi/volumeCloneFinished').publish(result);
                    }, function(result) {
                        wok.topic('kimchi/volumeCloneError').publish(result);
                    }, function(result) {
                        wok.topic('kimchi/volumeCloneProgress').publish(result);
                    });
                }
            }
        }, null, true);
        return result;
    };

    var volumeDiv = $('#volume-' + poolName);
    var volumeDatatable = $('.wok-datagrid > .wok-datagrid-body',volumeDiv);
    var slide = $('.volumes', poolObj);
    var handleArrow = $('.arrow-down', poolObj);
    kimchi.listStorageVolumes(poolName, function(result) {
        var listHtml = '';
        var ongoingVolumes = [];
        var ongoingVolumesMap = getOngoingVolumes();
        $.each(ongoingVolumesMap, function(volumeName, task) {
            ongoingVolumes.push(volumeName);
                var volume = {
                    poolName: poolName,
                    used_by: [],
                    capacity: 0,
                    name: volumeName,
                    format: '',
                    bootable: null,
                    os_distro: '',
                    allocation: 0,
                    os_version: '',
                    path: '',
                    type: 'file',
                    capacityLevel: 0,
                    capacityIcon: ''
                };
                listHtml += kimchi._generateVolumeHTML(volume);
        });

        $.each(result, function(index, value) {
            if (ongoingVolumes.indexOf(value.name) === -1) {
                $(volumeDatatable).empty();
                value.poolname = poolName;
                listHtml += kimchi._generateVolumeHTML(value);
            }
        });

        if (listHtml.length > 0) {
            $(volumeDatatable).empty();
            $('.filter',volumeDiv).prop('disabled',false);
            $('.toggle-gallery',volumeDiv).prop('disabled',false);
            $(volumeDatatable).html(listHtml);

        } else {
            $(volumeDatatable).empty();
            $('.filter',volumeDiv).prop('disabled',true);
            $('.toggle-gallery',volumeDiv).prop('disabled',true);
            $(volumeDatatable).html("<div class='pool-empty wok-datagrid-row'><span class='volume-empty'>" + i18n['KCHPOOL6002M'] + "</span></div>");
        }

        $.each(ongoingVolumesMap, function(volumeName, task) {
            wok.topic('kimchi/volumeTransferProgress').publish(task);
        });

        var checkbox = volumeDiv.find('[name="selected-volume[]"]');
        checkbox.trigger('change');
        checkbox.prop('checked',false);
        poolObj.removeClass('in');
        kimchi.changeArrow(handleArrow);
        slide.slideDown('slow');

        $(window).resize(function() {
          $('.pool-action.open', volumeDiv).removeClass('open');
        });

        $('.pool-action', volumeDiv).on('show.bs.dropdown', function () {
            $(volumeDiv).scrollTop(0);
            $(volumeDiv).bind('mousewheel DOMMouseScroll', function(e) {
                e.preventDefault();
            });
        });

        $('.pool-action', volumeDiv).on('hide.bs.dropdown', function () {
            $(volumeDiv).unbind('mousewheel DOMMouseScroll');
            $(this).removeAttr( 'style' );
            $('.toggle-gallery',volumeDiv).removeAttr( 'style' );
        });

        kimchi.doUpdateStoragePool(poolObj);

        $('[data-toggle="tooltip"]', volumeDiv).tooltip();

        volumeDivId = volumeDiv.attr('id');

        volumeOptions = {
            valueNames: ['volume-name-filter', 'volume-format-filter', 'volume-type-filter']
        };
        volumeFilterList = new List(volumeDivId, volumeOptions);

        volumeFilterList.sort('volume-name-filter', {
            order: "asc"
        });

    }, function(err) {
        wok.message.error(err.responseJSON.reason);
    }, false);
};

kimchi.initLogicalPoolExtend = function() {
    $('#logicalPoolExtend').on('hidden.bs.modal', function () {
        $('.host-partition', '#logicalPoolExtend').empty();
    });

    $('#logicalPoolExtend').on('show.bs.modal', function() {
        // Make any change in the form fields enables the
        // 'savePartitions' button if all the visible form
        // fields are filled, disables it otherwise.
        $('#logicalPoolExtend').on('input change propertychange', function() {
            if ($("input[name=devices]:checked").length === 0) {
                $("#savePartitions").attr("disabled", true);
            }
            else {
                $("#savePartitions").attr("disabled", false);
            }
        });

        kimchi.listHostPartitions(function(data) {
            if (data.length > 0) {
                var deviceHtml = $('#partitionTmpl').html();
                var listHtml = '<table class="table table-hover"><thead><tr><th></th><th>Device</th><th>Path</th><th>Size (GiB)</th></tr></thead><tbody>';
                valid_types = ['part', 'disk', 'mpath'];
                $.each(data, function(index, value) {
                    if (valid_types.indexOf(value.type) !== -1) {
                        value.size = (value.size / 1000000000).toFixed(2);
                        listHtml += wok.substitute(deviceHtml, value);
                    }
                });
                listHtml += '</tbody></table>';
                var infoHtml = '<h3>' + i18n['KCHPOOL6019M'].replace('%1', '<strong>' + kimchi.selectedSP + '</strong>') + '</h3>';
                $('.host-partition', '#logicalPoolExtend').html(infoHtml + listHtml);
            } else {
                $('.host-partition').html(i18n['KCHPOOL6011M']);
                $('.host-partition').addClass('text-help');
            }
        }, function(err) {
            $('.host-partition').html(i18n['KCHPOOL6013M'] + '<br/>(' + err.responseJSON.reason + ')');
            $('.host-partition').addClass('text-help');
        });

        $('#savePartitions', '#logicalPoolExtend').on('click', function(event) {
            event.preventDefault();
            var devicePaths = [];
            $("input[type='checkbox']:checked", "#logicalPoolExtend").each(function() {
                devicePaths.push($(this).prop('value'));
            });
            kimchi.updateStoragePool(kimchi.selectedSP, {
                disks: devicePaths
            }, function(pool) {
                $('#logicalPoolExtend').modal('hide');
                var item = '#' + pool.name;
                var usage = Math.round(pool.allocated / pool.capacity * 100) || 0;
                var usageIcon = kimchi.getPoolUsageIcon(usage);
                $(".usage-icon", $(".column-usage", item)).attr('class', 'usage-icon').addClass(usageIcon).text(usage);
                $(".column-capacity", item).text(wok.changetoProperUnit(pool.capacity, 1));
                $(".column-allocated", item).text(wok.changetoProperUnit(pool.allocated, 1));
            }, function(err) {
                $('#savePartitions', '#logicalPoolExtend').prop('disabled', true);
                $('#logicalPoolExtend').modal('hide');
            });
        });

    });

};

kimchi.storage_main = function() {
    $('body').removeClass('wok-list wok-gallery');

    var toolsHtml = '<li><a id="storage-pool-add" class="btn-tool" href="javascript:void(0);">'
    toolsHtml += '<i class="fa fa-plus-circle"></i><span>' + i18n['KCHPOOL6020M'] + '</span></a></li>'

    if(wok.tabMode['storage'] === 'admin') {
        $('#toolbar ul.tools').html(toolsHtml);
        $('#storage-pool-add').on('click', function() {
            wok.window.open('plugins/kimchi/storagepool-add.html');
        });
        $('.list-title .title-actions').attr('style','display');
    }
    kimchi.doListStoragePools();
    kimchi.initLogicalPoolExtend();
    wok.addNotificationListener('METHOD:/kimchi/storages', kimchi.doListStoragePools);

    wok.topic('kimchi/storageVolumeAdded').subscribe(function() {
        pool = kimchi.selectedSP;
        var poolNode = $('.storage-li[data-name="' + pool + '"]');
        kimchi.doListVolumes(poolNode);
    });

    wok.topic('kimchi/storageVolumeDeleted').subscribe(function() {
        pool = kimchi.selectedSP;
        var poolNode = $('.storage-li[data-name="' + pool + '"]');
        kimchi.doListVolumes(poolNode);
    });

    wok.topic('kimchi/storageVolumeWiped').subscribe(function() {
        pool = kimchi.selectedSP;
        var poolNode = $('.storage-li[data-name="' + pool + '"]');
        kimchi.doListVolumes(poolNode);
    });
    wok.topic('kimchi/storageVolumeCloned').subscribe(function() {
        pool = kimchi.selectedSP;
        var poolNode = $('.storage-li[data-name="' + pool + '"]');
        kimchi.doListVolumes(poolNode);
    });

    wok.topic('kimchi/storageVolumeResized').subscribe(function() {
        pool = kimchi.selectedSP;
        var poolNode = $('.storage-li[data-name="' + pool + '"]');
        kimchi.doListVolumes(poolNode);
    });

    wok.topic('kimchi/volumeTransferProgress').subscribe(function(result) {
        var extractProgressData = function(data) {
            var sizeArray = /(\d+)\/(\d+)/g.exec(data) || [0, 0, 0];
            var downloaded = sizeArray[1];
            var total = sizeArray[2];
            var percent = 0;
            if(downloaded) {
                if(!isNaN(total)) {
                    percent = downloaded / total * 100;
                }
            }
            var formatted = wok.formatMeasurement(downloaded, { base: 10,  converter: wok.localeConverters["number-locale-converter"]});
            var formattedTotal = !isNaN(total) ? wok.formatMeasurement(total, { base: 10,  converter: wok.localeConverters["number-locale-converter"]}) : '';
            var size = (1.0 * formatted['v']).toFixed(1) + formatted['s'] + ( formattedTotal !== '' ? ' / '+ (1.0 * formattedTotal['v']).toFixed(1) + formattedTotal['s'] : formattedTotal );
            return {
                size: size,
                percent: percent
            };
        };

        var uriElements = result.target_uri.split('/');
        var poolName = uriElements[4];
        var volumeName = uriElements.pop();
        var progress = extractProgressData(result['message']);
        var size = progress['size'];
        var percent = progress['percent'];
        volumeBox = $('#volume-' + poolName + ' [data-volume-name="' + volumeName + '"]').closest('.wok-datagrid-row');
        $('.volume-progress', volumeBox).removeClass('hidden');
        $('.column-progress', volumeBox).removeClass('hidden');
        $('.column-progress', '.wok-datagrid-header').removeClass('hidden');
        $('.volume-inline-progress', volumeBox).removeClass('hidden');
        $('.column-format > .format-text', volumeBox).text('--');
        $('.progress-bar', volumeBox).attr('aria-valuenow',percent+'%').css('width',percent+'%');
        $('input[type="checkbox"]',volumeBox).prop('disabled',true);
        $(volumeBox).addClass('in-progress')
        $('.volume-box-inner', volumeBox).attr({'data-toggle':'tooltip','data-original-title': i18n['KCHPOOL6014M'] + ' ' +size});
        $('.tooltip-inner', volumeBox).text(i18n['KCHPOOL6014M']+' '+size);
        $('.progress-transferred', volumeBox).text(size);
        $('.progress-status', volumeBox).text(i18n['KCHPOOL6014M']);
        $('[data-toggle="tooltip"]',volumeBox).tooltip();
    });

    wok.topic('kimchi/volumeTransferFinished').subscribe(function(result) {
        var uriElements = result.target_uri.split('/');
        var poolName = uriElements[4];
        var volumeName = uriElements.pop();
        volumeBox = $('#volume-' + poolName + ' [data-volume-name="' + volumeName + '"]').closest('.wok-datagrid-row');
        $(volumeBox).removeClass('in-progress')
        $('.volume-progress', volumeBox).addClass('hidden');
        $('.column-progress', volumeBox).addClass('hidden');
        $('.column-progress', '.wok-datagrid-header').addClass('hidden');
        $('.volume-inline-progress', volumeBox).addClass('hidden');
        kimchi.getStoragePoolVolume(poolName, volumeName, function(volume) {
            var html = kimchi._generateVolumeHTML(volume);
            $(volumeBox).replaceWith(html);
        }, function(err) {
            wok.message.error(err.responseJSON.reason);
        });
    });

    wok.topic('kimchi/volumeTransferError').subscribe(function(result) {
        // Error message from Async Task status
        if (result['message']) {
            var errText = result['message'];
        }
        // Error message from standard kimchi exception
        else {
            var errText = result['responseJSON']['reason'];
        }
        result && wok.message.error(errText);

        var uriElements = result.target_uri.split('/');
        var poolName = uriElements[4];
        var volumeName = uriElements.pop();
        volumeBox = $('#volume-' + poolName + ' [data-volume-name="' + volumeName + '"]').closest('.wok-datagrid-row');
        $('.progress-status', volumeBox).text(i18n['KCHPOOL6015M']);
    });

    wok.topic('kimchi/volumeCloneFinished').subscribe(function(result) {
        var uriElements = result.target_uri.split('/');
        var poolName = uriElements[4];
        var poolNode = $('.storage-li[data-name="' + poolName + '"]');
        kimchi.doListVolumes(poolNode);
    });

    wok.topic('kimchi/volumeCloneProgress').subscribe(function(result) {
        var uriElements = result.target_uri.split('/');
        var poolName = uriElements[4];
        var volumeName = uriElements[6];
        volumeBox = $('#volume-' + poolName + ' [data-volume-name="' + volumeName + '"]').closest('.wok-datagrid-row');
        $('.column-progress', volumeBox).removeClass('hidden');
        $('.column-progress', '.wok-datagrid-header').removeClass('hidden');
        $('.volume-inline-progress', volumeBox).removeClass('hidden');
        $('.column-format > .format-text', volumeBox).text('--');
        $('input[type="checkbox"]',volumeBox).prop('disabled',true);
        $(volumeBox).addClass('in-progress')
        $('.volume-box-inner', volumeBox).attr({'data-toggle':'tooltip','data-original-title': i18n['KCHPOOL6014M'] });
        $('.tooltip-inner', volumeBox).text(i18n['KCHPOOL6014M']);
        $('.progress-status', volumeBox).text(i18n['KCHPOOL6014M']);
        $('[data-toggle="tooltip"]',volumeBox).tooltip();
    });

    wok.topic('kimchi/volumeCloneError').subscribe(function(result) {
        // Error message from Async Task status
        if (result['message']) {
            var errText = result['message'];
        }
        // Error message from standard kimchi exception
        else {
            var errText = result['responseJSON']['reason'];
        }
        result && wok.message.error(errText);
    });

};

kimchi.changeArrow = function(obj) {
    if ($(obj).hasClass('arrow-down')) {
        $(obj).removeClass('arrow-down').addClass('arrow-up');
    } else {
        $(obj).removeClass('arrow-up').addClass('arrow-down');
    }
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2016
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.storagepool_add_main = function() {
    kimchi.initStorageAddPage();
    sessionStorage.clear();
    $('#form-pool-add').on('submit', kimchi.addPool);
    $('#pool-doAdd').on('click', kimchi.addPool);
    // 'pool-doAdd' button starts as disabled.
    $("#pool-doAdd").attr("disabled", true);
    // Make any change in the form fields enables the
    // 'pool-doAdd' button if all the visible form
    // fields are filled, disables it otherwise.
    $('#form-pool-add').on('input change propertychange', function() {
        if (!kimchi.inputsNotBlank()){
                    $("#pool-doAdd").attr("disabled", true);
        }
        else {
           $("#pool-doAdd").attr("disabled", false);
        }
    });
};

kimchi.storageFilterSelect = function(id, isUpdate) {
    var input = $('input', '#'+id);
    var options = $(".option", '#'+id);
    var filter = function(container, key){
        container.children().each(function(){
            $(this).css("display", $(this).text().indexOf(key)===-1 ? "none" : "");
        });
    };
    if(!isUpdate){
        input.on("keyup", function(){
            filter(options, input.val());
        });
    }
    options.children().each(function(){
        $(this).click(function(){
            options.children().removeClass("active");
            input.val($(this).text());
            input.trigger("change");
            $(this).addClass("active");
            filter(options, "");
        });
    });
};

kimchi.setupISCSI = function(){
    var loadTargets = function(server, port, callback){
        var isUpdate = $(".option", "#iSCSITarget").children().length > 0;
        $(".option", "#iSCSITarget").empty();
        $('input', "#iSCSITarget").attr("placeholder", i18n['KCHPOOL6006M']);
        kimchi.getISCSITargets(server, port, function(data){
            if(data.length===0){
                $('input', "#iSCSITarget").attr("placeholder", i18n['KCHPOOL6007M']);
            }else{
                for(var i=0; i<data.length; i++){
                    var itemNode = $.parseHTML("<li>"+data[i].target+"</li>");
                    $(".option", "#iSCSITarget").append(itemNode);
                }
                $('input', "#iSCSITarget").attr("placeholder", "");
                $(".popover", "#iSCSITarget").css("display", "block");
            }
            kimchi.storageFilterSelect('iSCSITarget', isUpdate);
            $('input', "#iSCSITarget").trigger("focus");
            callback();
        }, function(data){
            $('input', "#iSCSITarget").attr("placeholder", i18n['KCHPOOL6008M']);
            callback();
            wok.message.error(data.responseJSON.reason,'#alert-modal-container');
        });
    };
    var triggerLoadTarget = function(){
        $('input', "#iSCSITarget").val("");
        var server = $("#iscsiserverId").val().trim();
        var port = $("#iscsiportId").val().trim();
        if(server!=="" && !$("#iscsiserverId").hasClass("invalid-field") && !$("#iscsiportId").hasClass("invalid-field")){
            $("#iscsiserverId").attr("disabled", true);
            $("#iscsiportId").attr("disabled", true);
            loadTargets(server, port, function(){
                $("#iscsiserverId").attr("disabled", false);
                $("#iscsiportId").attr("disabled", false);
            });
        }
    };
    $("#iscsiserverId").change(function(){
        $('input', "#iSCSITarget").off('focus', triggerLoadTarget);
        $('input', "#iSCSITarget").one('focus', triggerLoadTarget);
    });
    $("#iscsiportId").change(function(){
        $('input', "#iSCSITarget").off('focus', triggerLoadTarget);
        $('input', "#iSCSITarget").one('focus', triggerLoadTarget);
    });
    var initISCSIServers = function(){
        kimchi.getStorageServers("iscsi", function(data){
            for(var i=0;i<data.length;i++){
                var itemNode = $.parseHTML("<li>"+data[i].host+"</li>");
                $(".option", "#iSCSIServer").append(itemNode);
                $(itemNode).click(function(){
                    $("#iscsiportId").val($(this).prop("port"));
                    $("#iscsiserverId").val($(this).text());
                    triggerLoadTarget();
                }).prop("port", data[i].port);
            }
            kimchi.storageFilterSelect('iSCSIServer', false);
         });
    };
    initISCSIServers();
};

kimchi.initStorageAddPage = function() {
    kimchi.listHostPartitions(function(data) {
        if (data.length > 0) {
            var deviceHtml = $('#partitionTmpl').html();
            var listHtml = '<table class="table table-hover"><thead><tr><th></th><th>'+i18n['KCHPOOL6025M']+'</th><th>'+i18n['KCHPOOL6026M']+'</th><th>'+i18n['KCHPOOL6027M']+'</th></tr></thead><tbody>';
            valid_types = ['part', 'disk', 'mpath'];
            $.each(data, function(index, value) {
                if (valid_types.indexOf(value.type) !== -1) {
                    value.size = (value.size / 1000000000).toFixed(2);
                    listHtml += wok.substitute(deviceHtml, value);
                }
            });
            listHtml += '</tbody></table>';
            $('.host-partition', '#form-pool-add').html(listHtml);
        } else {
            $('.host-partition').html(i18n['KCHPOOL6011M']);
            $('.host-partition').addClass('text-help');
        }
    }, function(err) {
        $('.host-partition').html(i18n['KCHPOOL6013M'] + '<br/>(' + err.responseJSON.reason + ')');
        $('.host-partition').addClass('text-help');
    });

    kimchi.getHostVgs(function(data){
        if (data.length > 0) {
            var deviceHtml = $('#existingLvmTmpl').html();
            var listHtml = '<table class="table table-hover"><thead><tr><th></th><th>'+i18n['KCHPOOL6025M']+'</th><th>'+i18n['KCHPOOL6027M']+'</th><th>'+i18n['KCHPOOL6028M']+'</th></tr></thead><tbody>';
            $.each(data, function(index, value) {
                value.size = (value.size / 1000000000).toFixed(2);
                value.free = (value.free / 1000000000).toFixed(2);
                listHtml += wok.substitute(deviceHtml, value);
            });
            listHtml += '</tbody></table>';
            $('.lvm-partition').html(listHtml);
        } else {
            $('.lvm-partition').html(i18n['KCHPOOL6016M']);
            $('.lvm-partition').addClass('text-help');
        }
    }, function(err) {
        $('.lvm-partition').html(i18n['KCHPOOL6013M'] + '<br/>(' + err.responseJSON.reason + ')');
        $('.lvm-partition').addClass('text-help');
    });

    kimchi.getHostFCDevices(function(data){
        $scsiSelect = $('#scsiAdapter');
        if(data.length>0){
            for(var i=0;i<data.length;i++){
                data[i].label = data[i].name;
                data[i].value = data[i].name;
            }
            //$('#scsiAdapter').selectMenu();
            var scsiOptionHtml = '';
            for (var i=0;i<data.length;i++){
              scsiOptionHtml += '<option value="'+ data[i].value + '">' + data[i].label + '</option>';
            }
            $scsiSelect.append(scsiOptionHtml);
            $scsiSelect.selectpicker();
        } else {
            $scsiSelect.remove();
            $('.scsi-adapters-list').html(i18n['KCHPOOL6005M']);
            $('.scsi-adapters-list').addClass('text-help');
        }
    });

    $('#serverComboboxId').combobox();
    $('#targetFilterSelectId').filterselect();
    var options = [ {
        label : i18n.KCHPOOL6021M,
        value : "dir"
    }, {
        label : i18n.KCHPOOL6022M,
        value : "netfs"
    }, {
        label : i18n.KCHPOOL6023M,
        value : "iscsi"
    }, {
        label : i18n.KCHPOOL6024M,
        value : "logical"
    }, {
        label : i18n.KCHPOOL6004M,
        value : "scsi"
    } ];
    var $select = $('#poolTypeInputId');
    var optionHtml = '';
    for (var i=0;i<options.length;i++){
      optionHtml += '<option value="'+ options[i].value + '">' + options[i].label + '</option>';
    }
    $select.append(optionHtml);
    $select.selectpicker();

    kimchi.getStorageServers('netfs', function(data) {
        var serverContent = [];
        if (data.length > 0) {
            $.each(data, function(index, value) {
                serverContent.push({
                    label : value.host,
                    value : value.host
                });
            });
            $('#serverComboboxId').combobox("setData", serverContent);
        }else {
            $('#serverComboboxId').combobox("destroy");
        }

        $('input[name=nfsServerType]').change(function() {
            if ($(this).val() === 'input') {
                $('#nfsServerInputDiv').removeClass('tmpl-html');
                $('#nfsServerChooseDiv').addClass('tmpl-html');
            } else {
                $('#nfsServerInputDiv').addClass('tmpl-html');
                $('#nfsServerChooseDiv').removeClass('tmpl-html');
            }
        });
        $('#nfsserverId').on("change keyup",function() {
            if ($(this).val() !== '' && wok.isServer($(this).val())) {
                $('#nfspathId').prop('disabled',false);
                $(this).removeClass("invalid-field");
            } else {
                $(this).addClass("invalid-field");
                $('#nfspathId').prop( "disabled",true);
            }
            $('#targetFilterSelectId').filterselect('clear');
        });
        $('#nfspathId').focus(function() {
            var targetContent = [];
            kimchi.getStorageTargets($('#nfsserverId').val(), 'netfs', function(data) {
                if (data.length > 0) {
                    $.each(data, function(index, value) {
                        targetContent.push({
                            label : value.target,
                            value : value.target
                        });
                    });
                    $('#targetFilterSelectId').filterselect("setData", targetContent);
                }else {
                    $('#targetFilterSelectId').filterselect('destroy');
                }
            });
        });
    });

    $('#poolTypeInputId').change(function() {

        kimchi.cleanLogicalForm();
        $('#poolId').css("background-color", "#ffffff").attr('readonly', false);
        $('[name="logicalRadioSelection"]')[1].checked = true;
        $('.lvm-group').addClass('hidden');
        $('.disk-group').removeClass('hidden');
        kimchi.setOldStorageName();

        var poolObject = {'dir': ".path-section", 'netfs': '.nfs-section',
                          'iscsi': '.iscsi-section', 'scsi': '.scsi-section',
                          'logical': '.logical-section'};
        var selectType = $(this).val();
        $.each(poolObject, function(type, value) {
            if(selectType === type){
                $(value).removeClass('hidden');
            } else {
                $(value).addClass('hidden');
            }
        });
    });
    $('#authId').click(function() {
        if ($(this).prop("checked")) {
            $('.authenticationfield').removeClass('hidden');
        } else {
            $('.authenticationfield').addClass('hidden');
        }
    });
    $('#iscsiportId').keyup(function(event) {
        $(this).toggleClass("invalid-field",!/^[0-9]*$/.test($(this).val()));
    });
    $('#iscsiserverId').keyup(function(event) {
        $(this).toggleClass("invalid-field",!wok.isServer($(this).val().trim()));
    }).change(function(event) {
        $(this).toggleClass("invalid-field",!wok.isServer($(this).val().trim()));
    });

    $('[name="logicalRadioSelection"]').change(function(){
        kimchi.cleanLogicalForm();
        kimchi.setOldStorageName();
        var selectedRadio = ($(this).val());
        var logicalObject = {'existingLvm' : '.lvm-group', 'rawDisk' : '.disk-group'};

        if(selectedRadio === 'existingLvm') {
            $('[name="lvmTmplRadioSelection"]').change(function(){
                $('#poolId').css("background-color", "#EEE").val($(this).val()).attr('readonly', true);
            });
        } else {
            $('#poolId').css("background-color", "#ffffff").attr('readonly', false);
        }

        $.each(logicalObject, function(type, value) {
            if(selectedRadio === type){
                $(value).removeClass('hidden');
            } else {
                $(value).addClass('hidden');
            }
        });
    });

    $('#poolId').blur(function() {
        sessionStorage.setItem('oldStorageName', $('#poolId').val());
    })

    kimchi.setupISCSI();
};

kimchi.setOldStorageName = function() {
    if(sessionStorage.getItem('oldStorageName') !== ''){
        $('#poolId').val(sessionStorage.getItem('oldStorageName'));
    } else {
        $('#poolId').val('');
    }
}

kimchi.cleanLogicalForm = function() {
    $("input[name=devices]").attr('checked', false);
    $("input[name=lvmTmplRadioSelection]").attr('checked', false);
}

/* Returns 'true' if all form fields were filled, 'false' if
 * any field is left blank. The function takes into account
 * the current poolType selected.
 *
 * Any 'field is blank' verification that were done in other
 * validate functions were deleted, since we're doing it here
 * already.
 */
kimchi.inputsNotBlank = function() {
    if (!$('#poolId').val()) { return false; }
    var poolType = $("#poolTypeInputId").val();
    if (poolType === "dir") {
        if (!$('#pathId').val()) { return false; }
    } else if (poolType === "netfs") {
        if (!$('#nfspathId').val()) { return false; }
        if (!$('#nfsserverId').val()) { return false; }
    } else if (poolType === "iscsi") {
        if (!$('#iscsiserverId').val()) { return false; }
        if (!$('#iscsiTargetId').val()) { return false; }
    } else if (poolType === "logical") {
        if ($("input[name=devices]:checked").length === 0 && $("input[name=lvmTmplRadioSelection]:checked").length === 0){
                    return false;
            }
    }
    return true;
};

kimchi.validateForm = function() {
    var poolType = $("#poolTypeInputId").val();
    if (poolType === "dir") {
        return kimchi.validateDirForm();
    } else if (poolType === "netfs") {
        return kimchi.validateNfsForm();
    } else if (poolType === "iscsi") {
        return kimchi.validateIscsiForm();
    } else if (poolType === "logical") {
        return kimchi.validateLogicalForm();
    } else {
        return true;
    }
};

kimchi.validateDirForm = function () {
    var path = $('#pathId').val();
    if (!/(^\/.*)$/.test(path)) {
        wok.message.error.code('KCHAPI6003E','#alert-modal-container');
        return false;
    }
    return true;
};

kimchi.validateNfsForm = function () {
    var nfspath = $('#nfspathId').val();
    var nfsserver = $('#nfsserverId').val();
    if (!kimchi.validateServer(nfsserver)) {
        return false;
    }
    if (!/((\/([0-9a-zA-Z-_\.]+)))$/.test(nfspath)) {
        wok.message.error.code('KCHPOOL6005E','#alert-modal-container');
        return false;
    }
    $('#nfs-mount-loading').removeClass('hidden');
    return true;
};

kimchi.validateIscsiForm = function() {
    var iscsiServer = $('#iscsiserverId').val();
    var iscsiTarget = $('#iscsiTargetId').val();
    if (!kimchi.validateServer(iscsiServer)) {
        return false;
    }
    return true;
};

kimchi.validateServer = function(serverField) {
    if(!wok.isServer(serverField)) {
        wok.message.error.code('KCHPOOL6009E','#alert-modal-container');
        return false;
    }
    return true;
};

kimchi.validateLogicalForm = function () {
    if ($("input[name=devices]:checked").length === 0 && $("input[name=lvmTmplRadioSelection]:checked").length === 0) {
        wok.message.error.code('KCHPOOL6006E','#alert-modal-container');
        return false;
    } else {
        return true;
    }
};

kimchi.addPool = function(event) {
    if (kimchi.validateForm()) {
        var formData = $('#form-pool-add').serializeObject();
        delete formData.authname;
        delete formData.logicalRadioSelection;
        delete formData.lvmTmplRadioSelection;
        var poolType = $('#poolTypeInputId').val();
        formData.type = poolType;
        if (poolType === 'dir') {
            formData.path = $('#pathId').val();
        } else if (poolType === 'logical') {
            var logicalrRadioSelected = $("input[name='logicalRadioSelection']:checked").val();
            var source = {};
            if (logicalrRadioSelected === 'rawDisk') {
                if (!$.isArray(formData.devices)) {
                    var deviceObj = [];
                    deviceObj[0] =  formData.devices;
                    source.devices = deviceObj;
                } else {
                    source.devices = formData.devices;
                }
                delete formData.devices;
            } else if (logicalrRadioSelected === 'existingLvm') {
                source.from_vg = true;
            }
            formData.source = source;
        } else if (poolType === 'netfs'){
            var source = {};
            source.path = $('#nfspathId').val();
            source.host = $('#nfsserverId').val();
            formData.source = source;
        } else if (poolType === 'iscsi') {
            var source = {};
            source.target = $('#iscsiTargetId').val();
            source.host = $('#iscsiserverId').val();
            $('#iscsiportId').val() !== '' ? source.port = parseInt($('#iscsiportId').val()): null;
            if ($('#authId').prop("checked")) {
                source.auth = {
                    "username" : $('#usernameId').val(),
                    "password" : $('#passwordId').val()
                };
            }
            formData.source = source;
        } else if (poolType === 'scsi'){
            formData.source = { adapter_name: $('#scsiAdapter').val() };
        }
        var storagePoolAddingFunc = function() {
            $('input', '#form-pool-add').attr('disabled','disabled');
            $('#pool-doAdd').hide();
            $('#pool-loading').show();
            kimchi.createStoragePool(formData, function() {
                    kimchi.doListStoragePools();
                    wok.window.close();
                }, function(err) {
                    wok.message.error(err.responseJSON.reason,'#alert-modal-container');
                    $('input', '#form-pool-add').removeAttr('disabled');
                    $('#pool-loading').hide();
                    $('#pool-doAdd').show();
                });
        };
        if (poolType === 'logical' && $("input[name='logicalRadioSelection']:checked").val() === 'rawDisk') {
            var settings = {
                title : i18n['KCHAPI6001M'],
                content : i18n['KCHPOOL6003M'],
                confirm : i18n['KCHAPI6002M'],
                cancel : i18n['KCHAPI6003M']
            };
            wok.confirm(settings, function() {
                storagePoolAddingFunc();
            }, function() {
            });
        } else {
            storagePoolAddingFunc();
        }
    }
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2014-2016
 *
 * Licensed under the Apache License, Version 2.0 (the 'License');
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.sp_add_volume_main = function() {
    // download from remote server or upload from local file
    var type = 'download';

    var addButton = $('#sp-add-volume-button');
    var remoteURLBox = $('#volume-remote-url');
    var localFileBox = $('#volume-input-file');
    var typeRadios = $('input.volume-type');
    var selectedStoragePool = kimchi.selectedSP.slice(0); // Makes a copy of kimchi.selectedSP

    var isValidURL = function() {
        var url = $(remoteURLBox).val();
        return kimchi.template_check_url(url);
    };

    var isValidFile = function() {
        var fileName = $(localFileBox).val();
        return fileName.length > 0;
    };

    $(typeRadios).change(function(event) {
        $('.volume-input').prop('disabled', true);
        $('.volume-input.' + this.value).prop('disabled', false);
        type = this.value;
        if(type === 'download') {
            $(addButton).prop('disabled', !isValidURL());
        }
        else {
            $(addButton).prop('disabled', !isValidFile());
        }
    });

    $(remoteURLBox).on('input propertychange', function(event) {
        $(addButton).prop('disabled', !isValidURL());
    });

    $(localFileBox).on('change', function(event) {
        $(addButton).prop('disabled', !isValidFile());
    });

    var onError = function(result) {
        $(this).prop('disabled', false);
        $(typeRadios).prop('disabled', false);
        if(!result) {
            return;
        }
        var msg = result['message'] || (
            result['responseJSON'] && result['responseJSON']['reason']
        );
        wok.message.error(msg);
    };

    var fetchRemoteFile = function() {
        var volumeURL = remoteURLBox.val();
        var volumeName = volumeURL.split(/(\\|\/)/g).pop();
        kimchi.downloadVolumeToSP({
            sp: selectedStoragePool,
            url: volumeURL
        }, function(result) {
            wok.window.close();
            wok.topic('kimchi/storageVolumeAdded').publish();
        }, onError);
    };

    var uploadFile = function() {
        var chunkSize = 2 * 1024 * 1024; // 2MB
        var uploaded = 0;

        var blobFile = $(localFileBox)[0].files[0];

        var createUploadVol = function() {
            kimchi.createVolumeWithCapacity(selectedStoragePool, {
                name: blobFile.name,
                format: '',
                capacity: blobFile.size,
                upload: true
            }, function(result) {
                wok.window.close();
                trackVolCreation(result.id);
            }, onError);
        };

        var uploadRequest = function(blob) {
            var fd = new FormData();
            fd.append('chunk', blob);
            fd.append('chunk_size', blob.size);

            kimchi.uploadVolumeToSP(selectedStoragePool, blobFile.name, {
                formData: fd
            }, function(result) {
                if (uploaded < blobFile.size){
                    setTimeout(doUpload, 500);
                }
            }, onError);

            uploaded += blob.size;
        };

        // Check file exists and has read permission
        try {
            var blob = blobFile.slice(0, 20);
            var reader = new FileReader();
            reader.onloadend = function(e) {
                if (e.loaded === 0){
                    wok.message.error.code('KCHAPI6008E');
                }
                else{
                    createUploadVol();
                }
            };

            reader.readAsBinaryString(blob);
        } catch (err) {
            wok.message.error.code('KCHAPI6008E');
            return;
        }

        var doUpload = function() {
            try {
                var blob = blobFile.slice(uploaded, uploaded + chunkSize);
                var reader = new FileReader();
                reader.onloadend = function(e) {
                    if (e.loaded === 0) {
                        wok.message.error.code('KCHAPI6009E');
                    }
                    else {
                        uploadRequest(blob);
                    }
                };

                reader.readAsBinaryString(blob);
            } catch (err) {
                wok.message.error.code('KCHAPI6009E');
                return;
            }
        };

        var trackVolCreation = function(taskid) {
            var onTaskResponse = function(result) {
                var taskStatus = result['status'];
                var taskMsg = result['message'];
                if (taskStatus === 'running') {
                    if (taskMsg !== 'ready for upload') {
                        setTimeout(function() {
                            trackVolCreation(taskid);
                        }, 2000);
                    } else {
                        wok.topic('kimchi/storageVolumeAdded').publish();
                        doUpload();
                    }
                }
            };
            kimchi.getTask(taskid, onTaskResponse, onError);
        };
    };

    $(addButton).on('click', function(event) {
        $(this).prop('disabled', true);
        $(typeRadios).prop('disabled', true);
        if(type === 'download') {
            fetchRemoteFile();
        }
        else {
            uploadFile();
        }
        event.preventDefault();
            wok.window.close();
    });
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2016-2017
 *
 * Licensed under the Apache License, Version 2.0 (the 'License');
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an 'AS IS' BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.sp_resize_volume_main = function() {

    var addButton = $('#sp-resize-volume-button');
    var size = $('#volume-size');
    var form = $('form#form-sp-resize-volume');

    // set storage volume size
    kimchi.getStoragePoolVolume(kimchi.selectedSP, kimchi.selectedVolumes[0], function(volume) {
        size.val(volume["capacity"] / (1024 * 1024));
    });

    $(addButton).prop('disabled',true);
    $(size).on('keyup change', function(){
        if($(this).val() > 0) {
            addButton.prop('disabled', false);
        } else{
            addButton.prop('disabled',true);
        }
    });
    $(addButton).on('click',function(e){
        e.preventDefault();
        e.stopPropagation();
        $(form).submit();
    });
    $(form).on('submit',function(e){
        e.preventDefault();
        e.stopPropagation();
        var newsize = parseInt($(size).val());
        var bytes = newsize * 1048576;
        var data = {};
        data = {
            size: bytes
        };
      kimchi.resizeStoragePoolVolume(kimchi.selectedSP, kimchi.selectedVolumes[0], data, function() {
          $(size).prop('disabled', true);
          $(addButton).prop('disabled',true);
          wok.topic('kimchi/storageVolumeResized').publish();
          wok.window.close();
      }, function(err) {
          wok.message.error(err.responseJSON.reason, '#alert-modal-container');
          $(size).prop('disabled', false);
          $(addButton).prop('disabled',false);
          $(size).focus();
      });
  });
}
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
kimchi.template_add_main = function() {
    "use strict";
    var currentPage = 'iso-local-box';
    $('#loading-isos').fadeIn(100, function() {});
    kimchi.deepScanHandler = null;
    var isos = [];
    var local_isos = [];
    var remote_isos = [];
    var s390xArch = 's390x';

    var deepScan = function(button) {
        kimchi.deepScanHandler = kimchi.stepListDeepScanIsos(function(isos, isFinished) {
            if (isos && isos.length) {
                if (button === '#iso-search') {
                    $(button + '-loading').hide();
                    button = '#iso-more';
                    $(button + '-loading').show();
                }
                showLocalIsoField(isos);
                $('[data-toggle="tooltip"]').tooltip();
            } else {
                if (isFinished) {
                    wok.message.warn(i18n['KCHTMPL6001W'], '#local-iso-warning-container');
                }
            }
            if (isFinished) {
                $(button + '-loading').hide();
                $(button).show();
            }
        }, function(err) {
            wok.message.error(err.responseJSON.reason, '#local-iso-error-container');
            $(button + '-loading').hide();
            $(button).show();
        });
    };

    var initLocalIsoField = function() {
        kimchi.isoInfo = {};
        $('#local-iso-field').hide();
        $('#select-all-local-iso').prop('checked', false);
        $('#btn-template-local-iso-create').attr('disabled', 'disabled');
        $('#btn-template-netboot-create').attr('disabled', 'disabled');
        $('#iso-search').hide();
        $('#iso-more').hide();
        $('#iso-search-loading').hide();
        $('#iso-more-loading').hide();
        $('#list-local-iso').empty();

        // Resets input fields and hide other buttons
        $('#iso-file').val(''); // 1 - Folder path text
        $('#iso-url').val(''); // 4 - Remote folder path text
        $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'inline-block'); // 1 - Folder path
        $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'none'); // 2 - Selected ISOs
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot
        $('#select-all-local-iso, #select-all-remote-iso').prop('checked', false); // False to all select-all checkboxes
        $('#list-local-iso [type="checkbox"], #list-remote-iso [type="checkbox"]').prop('checked', false); // False to all list checkboxes
    };

    var showLocalIsoField = function(isos) {
        var html = '';
        var template = $('#tmpl-list-local-iso').html();
        $.each(isos, function(index, volume) {
            if ((volume.path).indexOf('http') === -1) { // Didn't find 'http', so must be local
                volume.icon = 'fa fa-hdd-o';
            } else {
                volume.icon = 'fa fa-globe';
            }
            if ((volume.path).substr((volume.path).lastIndexOf('.')+1) === 'iso'){
                volume.format = 'iso';
            } else {
                volume.format = 'img';
            }
            if (!volume.hasOwnProperty('has_permission')) {
                volume.has_permission = true;
            }
            if (volume.has_permission){
                volume.volume_hidden = 'hidden';
            } else {
                volume.disabled = "disabled";
            }
            var isoId = volume.os_distro + '*' + volume.name + '*' + volume.os_version;
            if (!kimchi.isoInfo[isoId]) {
                volume.isoId = isoId;
                volume.capacity = wok.changetoProperUnit(volume.capacity, 1);
                if (volume.capacity === "") {
                    volume.capacity = i18n['KCHTMPL6006M'];
                }
                kimchi.isoInfo[isoId] = volume;
                html += wok.substitute(template, volume);
            }
        });

        $('#list-local-iso').append(html);
        $('#local-iso-field').show();
    };

    var initIsoFileField = function() {
        $('#iso-file').val('');
        $('#iso-url').val('');
        $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'inline-block');
        $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'none'); // 2 - Selected ISOs
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot
        $('#select-all-local-iso, #select-all-remote-iso').prop('checked', false); // False to all select-all checkboxes
        $('#list-local-iso [type="checkbox"], #list-remote-iso [type="checkbox"]').prop('checked', false); // False to all list checkboxes
    };

    $('#iso-file').on('input propertychange keyup focus cut paste click', function() {
        $('#btn-template-file-create').css('display', 'inline-block'); // 1 - Folder path
        $('#select-all-local-iso, #select-all-remote-iso').prop('checked', false);
        $('#list-local-iso [type="checkbox"], #list-remote-iso [type="checkbox"]').prop('checked', false);
        setTimeout(function() {
            var isValid = kimchi.template_check_path($('input#iso-file').val());
            $('input#iso-file').parent().toggleClass('has-error', !isValid);
            $('#btn-template-file-create').attr('disabled', (isValid ? false : true));
        }, 0);
        if ($('#iso-file').val()) {
            $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'none'); // 2 - Selected ISOs
        } else {
            $('#btn-template-file-create').attr('disabled', 'disabled');
        }
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot
    });

    initLocalIsoField();
    initIsoFileField();

    kimchi.listIsos(function(local_isos) { //local ISOs
        kimchi.listDistros(function(remote_isos) {  //remote ISOs
            isos = local_isos.concat(remote_isos); //all isos
            if (isos && isos.length) {
                showLocalIsoField(isos);
                $('#iso-more').show();
            } else {
                $('#iso-search').show();
            }
            $('#loading-isos').fadeOut(100, function() {});
            $('[data-toggle="tooltip"]').tooltip();
        });
    }, function(err) {
        wok.message.error(err.responseJSON.reason, '#local-iso-error-container');
        $('#loading-isos').fadeOut(300, function() {});
    });

    $('#template-add-window .modal-body .template-pager').animate({
        height: "689px"
    }, 400);

    var filterISOs = function(group, text) {
        text = text.trim().split(" ");
        var list = $('#isoRow').find('li');
        if(text === ""){
            list.show();
            return;
        }
        list.hide();

        list.filter(function(index, value){
            var $li = $(this);
            for (var i = 0; i < text.length; ++i){
                if ($li.is(":containsNC('" + text[i] + "')")) {
                    if (group === 'all') {
                        return true;
                    } else if (group === 'local') {
                        return true;
                    } else if (group === 'remote') {
                        return true;
                    }
                }
            }
            return false;
        }).show();
    };

    var setupFilters = function() {
        $('input#template-add-iso-filter', '#template-filter').on('keyup', function() {
            filterISOs("all", $(this).val());  // Default to 'all' for now
        });
    };

    setupFilters();

    $('#iso-search').click(function() {
        var settings = {
            content: i18n['KCHTMPL6002M']
        };
        wok.confirm(settings, function() {
            $('#iso-search').hide();
            $('#iso-search-loading').show();
            deepScan('#iso-search');
        });
    });

    $('#iso-more').click(function() {
        var settings = {
            content: i18n['KCHTMPL6002M']
        };
        wok.confirm(settings, function() {
            $('#iso-more').hide();
            $('#iso-more-loading').show();
            $('#iso-more-loading').attr('disabled', 'disabled');
            deepScan('#iso-more');
        });
    });

    $('#iso-search-loading').click(function() {
        $('#iso-search-loading').hide();
        $('#iso-search').show();
        if (kimchi.deepScanHandler) {
            kimchi.deepScanHandler.stop = true;
        }
    });

    $('#iso-more-loading').click(function() {
        $('#iso-more-loading').hide();
        $('#iso-more').show();
        if (kimchi.deepScanHandler) {
            kimchi.deepScanHandler.stop = true;
        }
    });

    $('#select-all-local-iso').click(function() {
        $('#list-local-iso [data-permission="true"]').prop('checked', $(this).prop('checked'));
        if ($(this).prop('checked')) {
            $('#iso-file').val('');
            $('#iso-file').parent().removeClass('has-error');

            $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'none'); // 1 - Folder path
            $('#btn-template-local-iso-create').removeAttr('disabled').css('display', 'inline-block'); // 2 - Selected ISOs
        } else {
            $('#btn-template-local-iso-create').attr('disabled', 'disabled');
        }
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot
    });

    $('#list-local-iso').on('click', '[type="checkbox"]', function() {
        $('#iso-file').parent().removeClass('has-error');
        var checkedLength = $('#list-local-iso [type="checkbox"]:checked').length;
        $('#iso-file').val('');
        $('#iso-url').val('');

        if (checkedLength && checkedLength != 1) {
            $('#tmpl-name').val('');
            $('#tmpl-name').attr('disabled', 'disabled');
        } else {
            $('#tmpl-name').removeAttr('disabled');
        }

        $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'none'); // 1 - Folder path
        $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'inline-block'); // 2 - Selected ISOs
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot

        if (checkedLength) {
            $('#btn-template-local-iso-create').removeAttr('disabled');
            var length = $('#list-local-iso [type="checkbox"]').length;
            $('#select-all-local-iso').prop('checked', length === checkedLength);
            $('#btn-template-local-iso-create').removeAttr('disabled');
        } else {
            $('#select-all-local-iso').prop('checked', false);
            $('#btn-template-local-iso-create').attr('disabled', 'disabled');
        }
    });

    $('#btn-template-netboot-create').click(function() {
        var tmpl_name = $('#tmpl-name').val();
        var data = {
            "source_media": {"type": "netboot"}
        };

        if (tmpl_name && tmpl_name != "") {
            data['name'] = tmpl_name
        }

        addTemplate(data, function() {
            $('#btn-template-netboot-create').text(i18n['KCHAPI6005M']);
            $('#btn-template-netboot-create').prop('disabled', false);
        });
    });

    $('#btn-template-local-iso-create').click(function() {
        var tmpl_name = $('#tmpl-name').val();
        $('input', '#iso-file-box').prop('disabled', true);
        $('#btn-template-local-iso-create').text(i18n['KCHAPI6008M']);
        $('#btn-template-local-iso-create').prop('disabled', true);
        submitIso();
    });

    $('#btn-template-file-create').click(function() {
        var tmpl_name = $('#tmpl-name').val();
        var isoFile = $('#iso-file').val();
        $('input', '#iso-file-box').prop('disabled', true);
        $('#btn-template-file-create').text(i18n['KCHAPI6008M']);
        $('#btn-template-file-create').prop('disabled', true);
        if (!kimchi.template_check_path(isoFile)) {
            wok.message.error(i18n['KCHAPI6003E'],'#local-iso-error-container');
            return;
        }
        var data = {
            "source_media": {"type": "disk", "path": isoFile}
        };
        if (tmpl_name && tmpl_name != "") {
            data['name'] = tmpl_name
        }
        addTemplate(data, function() {
            $('input', '#iso-file-box').prop('disabled', false);
            $('#btn-template-file-create').text(i18n['KCHAPI6005M']);
            $('#btn-template-file-create').prop('disabled', false);
        });
    });

    var enabledRemoteIso = function() {
        if (kimchi.capabilities === undefined) {
            setTimeout(enabledRemoteIso, 2000);
            return;
        }

        if (kimchi.capabilities.qemu_stream !== true) {
            return;
        }
    };

    enabledRemoteIso();

    var initRemoteIsoField = function() {
        $('#load-remote-iso').show();
        $('#remote-iso-field').hide();
        $('#iso-url-field').hide();
        $('#select-all-remote-iso').prop('checked', false);

        $('#iso-file').val('');
        $('#iso-url').val('');

        $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'none'); // 1 - Folder path
        $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'none'); // 2 - Selected ISOs
        $('#btn-template-netboot-create').attr('disabled', 'disabled').css('display', 'none'); // 3 - Netboot
        $('#select-all-local-iso, #select-all-remote-iso').prop('checked', false); // False to all select-all checkboxes
        $('#list-local-iso [type="checkbox"], #list-remote-iso [type="checkbox"]').prop('checked', false); // False to all list checkboxes

    };

    var showRemoteIsoField = function(isos) {
        if (isos && isos.length) {
            kimchi.isoInfo = {};
            var html = '';
            var template = $('#tmpl-list-remote-iso').html();
            $.each(isos, function(index, volume) {
                var isoId = volume.os_distro + '*' + volume.name + '*' + volume.os_version;
                if (!kimchi.isoInfo[isoId]) {
                    volume.isoId = isoId;
                    kimchi.isoInfo[isoId] = volume;
                    html += wok.substitute(template, volume);
                }
            });
            $('#list-remote-iso').html(html);
            $('#load-remote-iso').hide();
            $('#remote-iso-field').show();
            $('#iso-url-field').show();
        } else {
            $('#load-remote-iso').hide();
            $('#iso-url-field').show();
            wok.message.warn(i18n['KCHTMPL6001W'],"#remote-iso-warning-container");
        }
    };

    $('#iso-url').on('input propertychange keyup focus cut paste click', function() {
        $('#select-all-local-iso, #select-all-remote-iso').prop('checked', false);
        $('#list-local-iso [type="checkbox"], #list-remote-iso [type="checkbox"]').prop('checked', false);
        setTimeout(function() {
            var isValid = kimchi.template_check_url($('input#iso-url').val());
            $('input#iso-url').parent().toggleClass('has-error', !isValid);
        }, 0);
    });

    $('#image-src').change(function() {
        if (this.checked) {
            if (currentPage === 'netboot-path') {
                kimchi.switchPage(currentPage, 'iso-local-box', 'right');
            }
            currentPage = 'iso-local-box';
            $('#template-add-window .modal-body .template-pager').animate({
                height: "700px"
            }, 400);
            initLocalIsoField();
            initIsoFileField();
            $('#loading-isos').fadeIn(100, function() {});
            kimchi.listIsos(function(local_isos) { //local ISOs
                kimchi.listDistros(function(remote_isos) {  //remote ISOs

                    isos = local_isos.concat(remote_isos); //all isos
                    if (isos && isos.length) {
                        showLocalIsoField(isos);
                        $('#iso-more').show();
                    } else {
                        $('#iso-search').show();
                    }
                    $('#loading-isos').fadeOut(100, function() {});
                });
            }, function(err) {
                wok.message.error(err.responseJSON.reason, '#local-iso-error-container');
                $('#loading-isos').fadeOut(300, function() {});
            });
            setupFilters();
            enabledRemoteIso();
        }
    });

    $('#netboot-src').change(function() {
        if (this.checked) {
            if (currentPage === 'iso-local-box') {
                kimchi.switchPage(currentPage, 'netboot-path', 'left');
            }
            currentPage = 'netboot-path';
            $('#template-add-window .modal-body .template-pager').animate({
                height: "300px"
            }, 400);
            $('#btn-template-file-create').attr('disabled', 'disabled').css('display', 'none'); // 1 - Folder path
            $('#btn-template-local-iso-create').attr('disabled', 'disabled').css('display', 'none'); // 2 - Selected ISOs
            $('#btn-template-netboot-create').removeAttr('disabled').css('display', 'inline-block'); // 3 - Netboot
        }
    });

    //do create
    var addTemplate = function(data, callback) {
        kimchi.createTemplate(data, function() {
            if (callback) {
                callback();
            }
            kimchi.doListTemplates();
            wok.window.close();
            wok.topic('templateCreated').publish();
        }, function(err) {
            if (callback) {
                callback();
            }
            wok.message.error(err.responseJSON.reason, '#alert-modal-container');
        });
    };

    var submitIso = function() {
        var formData = $('#form-local-iso').serializeObject();
        if (formData.iso) {
            var length = 0;
            var successNum = 0;
            var addTemplate = function(isoInfo) {
                var tmpl_name = $('#tmpl-name').val();
                var data = {
                    "os_distro": isoInfo.os_distro,
                    "os_version": isoInfo.os_version,
                    "source_media": {"type": "disk", "path": isoInfo.path}
                };
                if (length == 1 && tmpl_name && tmpl_name != "") {
                    data['name'] = tmpl_name
                }
                kimchi.createTemplate(data, function() {
                    successNum++;
                    $('input[value="' + isoInfo.isoId + '"]').prop('checked', false);
                    $('.check-all>input').prop('checked', false);
                    kimchi.doListTemplates();
                    wok.topic('templateCreated').publish(data);
                    if (successNum === length) {
                        wok.window.close();
                    }
                }, function(err) {
                    wok.message.error(err.responseJSON.reason, '#alert-modal-container');
                    $('input', '#iso-file-box').prop('disabled', false);
                    $('#btn-template-local-iso-create').text(i18n['KCHAPI6005M']);
                    $('#btn-template-local-iso-create').prop('disabled', false);
                });
            };
            if (formData.iso instanceof Array) {
                length = formData.iso.length;
                $.each(formData.iso, function(index, value) {
                    addTemplate(kimchi.isoInfo[value]);
                });
            } else {
                length = 1;
                addTemplate(kimchi.isoInfo[formData.iso]);
            }
        }
    };

    if(kimchi.hostarch === s390xArch){
        $('#template-add-window .netboot-template').hide();
    }
};

kimchi.template_check_url = function(url) {
    var reg = /(https|http|ftp|ftps|tftp):\/\//;
    if (url.constructor === String) {
        return reg.test(url);
    }
    return false;
};

kimchi.template_check_path = function(filePath) {
    var reg = /((\/([0-9a-zA-Z-_ \.]+))+)$/;
    if (filePath.constructor === String) {
        return reg.test(filePath);
    }
    return false;
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.init_processor_tab = function(cpu_info, save_form_button) {

    var getMaxVCpus = function() {
        if (!$('#sockets').hasClass("invalid-field") &&
            !$('#cores').hasClass("invalid-field") &&
            !$('#threads').hasClass("invalid-field") &&
            $('#sockets').val() != "" && $('#cores').val() != "" &&
            $('#threads').val() != "") {

                var sockets = parseInt($("#sockets").val());
                var cores = parseInt($("#cores").val());
                var threads = parseInt($("#threads").val());
                var computedCpu = sockets * cores * threads;

                return computedCpu;
        }
        return undefined;
    };

    var setCPUValue = function() {
        var computedCpu = getMaxVCpus();
        var vcpus = parseInt($("#vcpus").val());

        if (computedCpu && $("#cpus-check").prop("checked")) {
            var threads = parseInt($("#threads").val());
            $("#guest-edit-max-processor-textbox").val(computedCpu);
            if (vcpus % threads != 0) {
                $("#vcpus").val(threads);
            } else if (vcpus > computedCpu) {
                $("#vcpus").val(computedCpu);
            }
        } else {
            var maxCpu = parseInt($("#guest-edit-max-processor-textbox").val());
            if (vcpus > maxCpu) {
                $("#vcpus").val(maxCpu);
            }
        }
    };

    $("input:text", "#form-edit-processor").on('keyup', function() {
        var invalid_field = !$(this).val().match('^[0-9]*$');
        $(this).toggleClass("invalid-field", invalid_field);
        save_form_button.prop('disabled', invalid_field);

        if ($(this).prop('id') == 'sockets' ||
            $(this).prop('id') == 'cores' ||
            $(this).prop('id') == 'threads') {

            setCPUValue();
        }
    });

    $("input:checkbox", "#form-edit-processor").click(function() {
        $(".topology", "#form-edit-processor").slideToggle();
        $("#guest-edit-max-processor-textbox").attr("disabled", $(this).prop("checked"));
        setCPUValue();
    });

    $("#guest-edit-max-processor-textbox").change(function() {
        save_form_button.prop('disabled', false);
        var vcpus = parseInt($('#vcpus').val());
        var maxCpu = parseInt($("#guest-edit-max-processor-textbox").val());
        if (vcpus > maxCpu) {
            $("#vcpus").val(maxCpu);
        }
    });

    $('#vcpus').change(function() {
        var computedCpu = getMaxVCpus();
        var vcpus = parseInt($('#vcpus').val());

        if (computedCpu && $("#cpus-check").prop("checked")) {
            var threads = parseInt($("#threads").val());
            var invalid_vcpu = (vcpus % threads != 0) || (vcpus > computedCpu);
            $(this).toggleClass("invalid-field", invalid_vcpu);
            save_form_button.prop('disabled', invalid_vcpu);
        } else {
            save_form_button.prop('disabled', false);
            var maxCpu = parseInt($("#guest-edit-max-processor-textbox").val());
            if (vcpus > maxCpu) {
                $("#vcpus").val(maxCpu);
            }
         }
    });

    kimchi.getCPUInfo(function(data) {
        var options = "";
        var topo = cpu_info.topology;

        var threads_help_text = i18n['KCHVM0003E'].replace('%1', data.threads_per_core);
        $('#threads-recommended-values').text(threads_help_text);

        if (cpu_info.vcpus) {
            $("#vcpus").val(cpu_info.vcpus);
        }
        if (cpu_info.maxvcpus) {
            $("#guest-edit-max-processor-textbox").val(cpu_info.maxvcpus);
        }

        $("#sockets").val(data.sockets);
        $("#cores").val(data.cores);
        $('#threads').val(data.threads_per_core);

        if (topo) {
            if (topo.sockets) {
                $("#sockets").val(topo.sockets);
            }
            if (topo.cores) {
                $("#cores").val(topo.cores);
            }
            if (topo.threads) {
                $('#threads').val(topo.threads);
            }
            if (topo.sockets && topo.cores && topo.threads) {
                $("input:checkbox", "#form-edit-processor").trigger('click');
            }
        }
    });
};


kimchi.template_edit_main = function() {
    var templateEditMain = $('#edit-template-tabs');
    var origDisks;
    var origNetworks;
    var origInterfaces;
    var origmacvtapNetworks;
    var origovsNetworks;
    var templateDiskSize;
    var baseImageTemplate;
    var s390xArch = 's390x';

    $('#template-name', templateEditMain).val(kimchi.selectedTemplate);
    $('#edit-template-tabs a[data-toggle="tab"]').on('shown.bs.tab', function(e) {
        $('.tab-content').css('overflow', 'hidden');
        var target = $(this).attr('href');
        $(target).css('left', '-' + $(window).width() + 'px');
        var left = $(target).offset().left;
        $(target).css({
            left: left
        }).animate({
            "left": "0px"
        }, 400, function() {
            $('.tab-content').css('overflow', 'visible');
        });
    });

    $('#template-show-max-memory').on('click', function(e) {
        e.preventDefault;
        $('.max-memory-field').slideToggle();
        var text = $('#template-show-max-memory span.text').text();
        $('#template-show-max-memory span.text').text(text == i18n['KCHVMED6008M'] ? i18n['KCHVMED6009M'] : i18n['KCHVMED6008M']);
        $('#template-show-max-memory i.fa').toggleClass('fa-plus-circle fa-minus-circle');
    });

    var initTemplate = function(template) {
        origDisks = template.disks;
        origNetworks = template.networks;
        origInterfaces = template.interfaces;
        for (var i = 0; i < template.disks.length; i++) {
            if (template.disks[i].base) {
                template["vm-image"] = template.disks[i].base;
                $('.templ-edit-cdrom').addClass('hide');
                $('.templ-edit-vm-image').removeClass('hide');
                break;
            }
        }
        for (var prop in template) {
            var value = template[prop];
            if (prop == 'graphics') {
                value = value["type"];
            }
            $('input[name="' + prop + '"]', templateEditMain).val(value);
        }
        if(kimchi.hostarch == s390xArch){
            $('.graphics', templateEditMain).hide();
            $('.console', templateEditMain).show();
            var consoleData = template.console ? template.console : '';
            $('#template-edit-console', templateEditMain).val(consoleData);
            $('#template-edit-console').selectpicker();
        }

        $('#template-edit-memory-textbox').val(template.memory.current);
        $('#template-edit-max-memory-textbox').val(template.memory.maxmemory);

        if (template.graphics.type == 'vnc') {
            $('#template-edit-graphics').append('<option value="vnc" selected="selected">VNC</option>');
        } else {
            $('#template-edit-graphics').append('<option value="vnc">VNC</option>');
        }
        var enableSpice = function() {
            if (kimchi.capabilities == undefined) {
                setTimeout(enableSpice, 2000);
                return;
            }
            if (kimchi.capabilities.qemu_spice == true) {
                if (template.graphics.type == 'spice') {
                    $('#template-edit-graphics').append('<option value="spice" selected="selected">Spice</option>');
                } else {
                    $('#template-edit-graphics').append('<option value="spice">Spice</option>');
                }
            }
        };
        var isImageBasedTemplate = function() {
            if (template["vm-image"] && typeof template["vm-image"] == "string") {
                return true;
            }
            return false;
        }
        baseImageTemplate = isImageBasedTemplate();
        enableSpice();
        $('#template-edit-graphics').selectpicker();

        var initStorage = function(result) {
            // Gather storagepools data
            var storagePoolsInfo = new Object();
            $.each(result, function(index, pool) {
                if (pool.state === 'active' && pool.type != 'kimchi-iso') {
                    if (pool.type === 'iscsi' || pool.type === 'scsi') {
                        volumes = new Object();
                        kimchi.listStorageVolumes(pool.name, function(vols) {
                            $.each(vols, function(i, vol) {
                                storagePoolsInfo[pool.name + "/" + vol.name] = {
                                    'type': pool.type,
                                    'volSize': vol.capacity / Math.pow(1024, 3)
                                };
                            });
                        }, null, true);
                    } else {
                        storagePoolsInfo[pool.name] = { 'type': pool.type };
                    }
                }
            });

            var addStorageItem = function(storageData) {
                var thisName = storageData.storageName;
                // Compatibility with old versions
                if (storageData.storageVolume) {
                    storageData.storageDisk = storagePoolsInfo[thisName].volSize;
                }
                if (!storageData.storageType) {
                    storageData.storageType = storagePoolsInfo[thisName].type;
                }

                var nodeStorage = $.parseHTML(wok.substitute($('#template-storage-pool-tmpl').html(), storageData));
                $('.template-tab-body', '#form-template-storage').append(nodeStorage);
                var storageRow = '#storageRow' + storageData.storageIndex;

                var storageOptions = '';
                $.each(storagePoolsInfo, function(poolName, value) {
                    storageOptions += '<option value="' + poolName + '">' + poolName + '</option>';
                });

                $(storageRow + ' .selectStorageName').append(storageOptions);
                if (!$(storageRow + ' .selectStorageName option[value="' + storageData.storageName + '"]').length) {
                    var invalidOption = '<option disabled="disabled" selected="selected" value="' + storageData.storageName + '">' + storageData.storageName + '</option>';
                    $(storageRow + ' .selectStorageName').prepend(invalidOption);
                    $(storageRow + ' .selectStorageName').parent().addClass('has-error')
                }
                $(storageRow + ' .selectStorageName').val(storageData.storageName);
                $(storageRow + ' .selectStorageName').selectpicker();

                if (storageData.storageType === 'iscsi' || storageData.storageType === 'scsi') {
                    $(storageRow + ' .template-storage-disk').attr('readonly', true).prop('disabled', true);
                    $(storageRow + ' #diskFormat').val('raw');
                    $(storageRow + ' #diskFormat').prop('disabled', true).change();
                } else if (storageData.storageType === 'logical') {
                    $(storageRow + ' #diskFormat').val('raw');
                    $(storageRow + ' #diskFormat').prop('disabled', true).change();
                }

                // Set disk format
                if (isImageBasedTemplate()) {
                    $(storageRow + ' #diskFormat').val('qcow2');
                    $(storageRow + ' #diskFormat').prop('disabled', 'disabled');
                } else {
                    $(storageRow + ' #diskFormat').val(storageData.storageDiskFormat);
                    $(storageRow + ' #diskFormat').on('change', function() {
                        $(storageRow + ' .template-storage-disk-format').val($(this).val());
                    });
                }
                $(storageRow + ' #diskFormat').selectpicker();

                $('.delete', '#form-template-storage').on("click", function(event) {
                    event.preventDefault();
                    $(this).parent().parent().remove();
                });

                $(storageRow + ' select.selectStorageName').change(function() {
                    $(this).parent().parent().removeClass('has-error');
                    var poolType = storagePoolsInfo[$(this).val()].type;
                    $(storageRow + ' .template-storage-name').val($(this).val());
                    $(storageRow + ' .template-storage-type').val(poolType);
                    if (poolType === 'iscsi' || poolType === 'scsi') {
                        $(storageRow + ' .template-storage-disk').attr('readonly', true).prop('disabled', true).val(storagePoolsInfo[$(this).val()].volSize);
                        if (!isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('raw').prop('disabled', true).change();
                        }
                    } else if (poolType === 'logical') {
                        $(storageRow + ' .template-storage-disk').attr('readonly', false).prop('disabled', false);
                        if (!isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('raw').prop('disabled', true).change();
                        }
                    } else {
                        $(storageRow + ' .template-storage-disk').attr('readonly', false).prop('disabled', false);
                        if ($(storageRow + ' #diskFormat').prop('disabled') == true && !isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('qcow2').prop('disabled', false).change();
                        }
                    }
                    $(storageRow + ' #diskFormat').selectpicker('refresh');
                });
            }; // End of addStorageItem funtion

            if (origDisks && origDisks.length) {
                origDisks.sort(function(a, b) {
                    return a.index - b.index });
                $.each(origDisks, function(index, diskEntities) {
                    var defaultPool = diskEntities.pool.name.split('/').pop()
                    var storageNodeData = {
                        storageIndex: diskEntities.index,
                        storageName: diskEntities.volume ? defaultPool + '/' + diskEntities.volume : defaultPool,
                        storageType: diskEntities.pool.type,
                        storageDisk: diskEntities.size,
                        storageDiskFormat: diskEntities.format ? diskEntities.format : 'qcow2',
                        storageVolume: diskEntities.volume
                    }
                    addStorageItem(storageNodeData);
                });
            }

            var storageID = origDisks.length - 1;
            $('#template-edit-storage-add-button').on("click", function(event) {
                event.preventDefault();
                storageID = storageID + 1;
                var storageNodeData = {
                    storageName: 'default',
                    storageType: 'dir',
                    storageDisk: '10',
                    storageDiskFormat: 'qcow2',
                    storageIndex: storageID
                }
                addStorageItem(storageNodeData);
            });
        };

        var initStorage_s390 = function(result) {
            // Gather storage data
            var storagePoolsInfo = new Object();
            $.each(result, function(index, pool) {
                if (pool.state === 'active' && pool.type != 'kimchi-iso') {
                    if (pool.type === 'iscsi' || pool.type === 'scsi') {
                        volumes = new Object();
                        kimchi.listStorageVolumes(pool.name, function(vols) {
                            $.each(vols, function(i, vol) {
                                storagePoolsInfo[pool.name + "/" + vol.name] = {
                                    'type': pool.type,
                                    'volSize': vol.capacity / Math.pow(1024, 3)
                                };
                            });
                        }, null, true);
                    } else {
                        storagePoolsInfo[pool.name] = {
                            'type': pool.type
                        };
                    }
                }
            });

            var addStorageItem = function(storageData) {
                if (storageData.storageSource == 'pool') {
                    var thisName = storageData.storageName;
                    // Compatibility with old versions
                    if (storageData.storageVolume) {
                        storageData.storageDisk = storagePoolsInfo[thisName].volSize;
                    }
                    if (!storageData.storageType) {
                        storageData.storageType = storagePoolsInfo[thisName].type;
                    }
                }

                var nodeStorage = $.parseHTML(wok.substitute($('#template-storage-pool-tmpl').html(), storageData));
                $('.template-tab-body', '#form-template-storage').append(nodeStorage);
                var storageRow = '#storageRow' + storageData.storageIndex;

                var storageOptions = '<option disabled="disabled" selected="selected" value=""></option>';
                $.each(storagePoolsInfo, function(poolName, value) {
                    storageOptions += '<option value="' + poolName + '">' + poolName + '</option>';
                });

                $(storageRow + ' .selectStorageName').append(storageOptions);
                if (storageData.storageSource == 'pool') {
                    $(storageRow + ' .selectStorageName').val(storageData.storageName);
                    if(!storageData.storageName){
                        $(storageRow + ' .selectStorageName').parent().addClass('has-error');
                    }
                    $(storageRow + ' span.storage-pool').show();
                    $(storageRow + ' span.storage-path').hide();
                } else {
                    $(storageRow + ' span.storage-pool').hide();
                    $(storageRow + ' span.storage-path').show();
                }

                $(storageRow + ' .selectStorageName').selectpicker();
                if (storageData.storageType === 'iscsi' || storageData.storageType === 'scsi') {
                    $(storageRow + ' .template-storage-disk').attr('readonly', true).prop('disabled', true);
                    $(storageRow + ' #diskFormat').val('raw');
                    $(storageRow + ' #diskFormat').prop('disabled', true).change();
                } else if (storageData.storageType === 'logical') {
                    $(storageRow + ' #diskFormat').val('raw');
                    $(storageRow + ' #diskFormat').prop('disabled', true).change();
                }
                $('#form-template-storage .template-tab-header span.storage-pool').hide();
                $('#form-template-storage .template-tab-header span.storage').show();

                //set source
                $('#form-template-storage span.source').show();
                $(storageRow + ' #source').val(storageData.storageSource);
                $(storageRow + ' #source').on('change', function() {
                    var source = $(this).val();
                    $(storageRow + ' .template-storage-source').val(source);
                    if (source == 'path') {
                        $(storageRow + ' span.storage-pool').hide();
                        $(storageRow + ' span.storage-path').show();
                        $(storageRow + ' span.storage-pool').removeClass('has-error');

                        if($(storageRow + ' input.storage-path').val()){
                            $(storageRow + ' span.storage-path').removeClass('has-error');
                        }else{
                            $(storageRow + ' span.storage-path').addClass('has-error');
                        }
                    } else {
                        if($(storageRow + ' select.selectStorageName').val()){
                            $(storageRow + ' span.storage-pool').removeClass('has-error');
                        }else{
                            $(storageRow + ' span.storage-pool').addClass('has-error');
                        }
                        $(storageRow + ' span.storage-pool').show();
                        $(storageRow + ' span.storage-path').hide();
                        $(storageRow + ' span.storage-path').removeClass('has-error');
                    }
                });

                $(storageRow + ' input.storage-path').on('change input keyup',function(){
                    var storagepath = $(storageRow + ' input.storage-path').val();
                    if( storagepath && storagepath.charAt(0) == '/'){
                        $(storageRow + ' span.storage-path').removeClass('has-error');
                    }else{
                        $(storageRow + ' span.storage-path').addClass('has-error');
                    }
                });

                $(storageRow + ' #source').selectpicker();

                // Set disk format
                if (isImageBasedTemplate()) {
                    $(storageRow + ' #diskFormat').val('qcow2');
                    $(storageRow + ' #diskFormat').prop('disabled', 'disabled');
                } else {
                    $(storageRow + ' #diskFormat').val(storageData.storageDiskFormat);
                    $(storageRow + ' #diskFormat').on('change', function() {
                        $(storageRow + ' .template-storage-disk-format').val($(this).val());
                    });
                }
                $(storageRow + ' #diskFormat').selectpicker();

                $('.delete', '#form-template-storage').on("click", function(event) {
                    event.preventDefault();
                    $(this).parent().parent().remove();
                });

                $(storageRow + ' select.selectStorageName').change(function() {
                    $(this).parent().parent().removeClass('has-error');
                    var poolType = storagePoolsInfo[$(this).val()].type;
                    $(storageRow + ' .template-storage-name').val($(this).val());
                    $(storageRow + ' .template-storage-type').val(poolType);
                    if (poolType === 'iscsi' || poolType === 'scsi') {
                        $(storageRow + ' .template-storage-disk').attr('readonly', true).prop('disabled', true).val(storagePoolsInfo[$(this).val()].volSize);
                        if (!isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('raw').prop('disabled', true).change();
                        }
                    } else if (poolType === 'logical') {
                        $(storageRow + ' .template-storage-disk').attr('readonly', false).prop('disabled', false);
                        if (!isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('raw').prop('disabled', true).change();
                        }
                    } else {
                        $(storageRow + ' .template-storage-disk').attr('readonly', false).prop('disabled', false);
                        if ($(storageRow + ' #diskFormat').prop('disabled') == true && !isImageBasedTemplate()) {
                            $(storageRow + ' #diskFormat').val('qcow2').prop('disabled', false).change();
                        }
                    }
                    $(storageRow + ' #diskFormat').selectpicker('refresh');
                });
            }; // End of addStorageItem funtion

            if (origDisks && origDisks.length) {
                origDisks.sort(function(a, b) {
                    return a.index - b.index
                });
                $.each(origDisks, function(index, diskEntities) {
                    if (typeof diskEntities.pool !== 'undefined') {
                        var defaultPool = diskEntities.pool.name.split('/').pop()
                        var storageNodeData = {
                            storageSource: 'pool',
                            storageName: diskEntities.volume ? defaultPool + '/' + diskEntities.volume : defaultPool,
                            storageType: diskEntities.pool.type,
                            storageIndex: diskEntities.index,
                            storageDisk: diskEntities.size,
                            storageDiskFormat: diskEntities.format ? diskEntities.format : 'qcow2',
                            storageVolume: diskEntities.volume
                        }
                    } else {
                        var storageNodeData = {
                            storageSource: 'path',
                            storagePath: diskEntities.path,
                            storageType: 'dir',
                            storageIndex: diskEntities.index,
                            storageDisk: diskEntities.size,
                            storageDiskFormat: diskEntities.format ? diskEntities.format : 'qcow2',
                            storageVolume: diskEntities.volume
                        }
                    }
                    addStorageItem(storageNodeData);
                });
            }

            var storageID = origDisks.length - 1;
            $('#template-edit-storage-add-button').on("click", function(event) {
                event.preventDefault();
                storageID = storageID + 1;
                var storageNodeData = {
                    storageSource: 'pool',
                    storageName: '',
                    storageType: 'dir',
                    storageDisk: '10',
                    storageDiskFormat: 'qcow2',
                    storageIndex: storageID
                }
                addStorageItem(storageNodeData);
            });
        };

        var initInterface = function(result) {
            var networkItemNum = 0;
            var addInterfaceItem = function(networkData) {
                var networkName = networkData.networkV;
                var nodeInterface = $.parseHTML(wok.substitute($('#template-interface-tmpl').html(), networkData));
                $('.template-tab-body', '#form-template-interface').append(nodeInterface);
                $('.delete', '#form-template-interface').on("click", function(event) {
                    event.preventDefault();
                    $(this).parent().parent().remove();
                });
                var networkOptions = '';
                for (var i = 0; i < result.length; i++) {
                    if (networkName === result[i].name) {
                        networkOptions += '<option selected="selected">' + result[i].name + '</option>';
                    }
                    if (result[i].state === "active" && networkName !== result[i].name) {
                        networkOptions += '<option>' + result[i].name + '</option>';
                    }
                }
                $('select', '#form-template-interface #networkID' + networkItemNum).append(networkOptions);
                $('select', '#form-template-interface #networkID' + networkItemNum).selectpicker();
                networkItemNum += 1;
            };
            if (result && result.length > 0) {
                for (var i = 0; i < origNetworks.length; i++) {
                    addInterfaceItem({
                        networkID: 'networkID' + networkItemNum,
                        networkV: origNetworks[i],
                        type: 'network'
                    });
                }
            }
            $('#template-edit-interface-add-button').on("click", function(event) {
                event.preventDefault();
                addInterfaceItem({
                    networkID: 'networkID' + networkItemNum,
                    networkV: 'default',
                    type: 'network'
                });
            });
        };

        var initInterface_s390x = function(result) {
            $('#form-template-interface-s390x').show();
            $('#form-template-interface').hide();
            var networkItemNum = 0;
            var addInterfaceItem = function(networkData) {
                var networkName = networkData.networkV;
                var nodeInterface = $.parseHTML(wok.substitute($('#template-interface-s390x-tmpl').html(), networkData));
                $('.template-tab-body', '#form-template-interface-s390x').append(nodeInterface);
                $('.delete', '#form-template-interface-s390x').on("click", function(event) {
                    event.preventDefault();
                    $(this).parent().parent().remove();
                });

                //initialize type option
                var typeOptionsdata = {};
                var typeOptions = '';
                typeOptionsdata.macvtap = i18n['KCHTMPL6009M'];
                typeOptionsdata.ovs = i18n['KCHTMPL6010M'];
                typeOptionsdata.network = i18n['KCHTMPL6011M'];

                $.each(typeOptionsdata, function(key, value) {
                    if (value === networkData.type) {
                        typeOptions += '<option  value="' + key + '" selected="selected">' + networkData.type + '</option>';
                    } else {
                        typeOptions += '<option value="' + key + '">' + value + '</option>';
                    }
                });

                $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.type').append(typeOptions);
                $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.type').on('change', function() {
                    var itemNode = $(this).closest('div.item');

                    switch ($(this).val()) {
                        case 'macvtap':
                            $('span.mode .label-mode', itemNode).addClass('hide');
                            $('span.mode .bootstrap-select', itemNode).toggleClass("hide", false);

                            var networkOptions = '';
                            for (var i = 0; i < origmacvtapNetworks.length; i++) {
                                networkOptions += '<option>' + origmacvtapNetworks[i].name + '</option>';
                            }

                            $('span.network select', itemNode).empty().append(networkOptions);
                            $('span.network select', itemNode).selectpicker('refresh');

                            break;
                        case 'ovs':
                            $('span.mode .label-mode', itemNode).removeClass('hide');
                            $('span.mode .bootstrap-select', itemNode).toggleClass("hide", true);
                            var networkOptions = '';
                            for (var i = 0; i < origovsNetworks.length; i++) {
                                networkOptions += '<option>' + origovsNetworks[i] + '</option>';
                            }

                            $('span.network select', itemNode).empty().append(networkOptions);
                            $('span.network select', itemNode).selectpicker('refresh');

                            break;
                        case 'network':
                            $('span.mode .label-mode', itemNode).removeClass('hide');
                            $('span.mode .bootstrap-select', itemNode).toggleClass("hide", true);

                            var networkOptions = '';
                            for (var i = 0; i < result.length; i++) {
                                if (result[i].state === "active") {
                                    networkOptions += '<option>' + result[i].name + '</option>';
                                }
                            }
                            $('span.network select', itemNode).empty().append(networkOptions);
                            $('span.network select', itemNode).selectpicker('refresh');
                            break;
                    }
                });

                switch (networkData.type) {
                    case 'macvtap':
                        //initialize network option
                        var networkOptions = '';
                        for (var i = 0; i < origmacvtapNetworks.length; i++) {
                            if (networkName === origmacvtapNetworks[i].name) {
                                networkOptions += '<option selected="selected">' + origmacvtapNetworks[i].name + '</option>';
                            }else{
                                networkOptions += '<option>' + origmacvtapNetworks[i].name + '</option>';
                            }
                        }
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.network').append(networkOptions);

                        //initialize Mode option for Macvtap
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.mode').val(networkData.mode);
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.mode').selectpicker('refresh');

                        $('span.mode .label-mode', nodeInterface).addClass('hide');
                        $('span.mode .bootstrap-select', nodeInterface).removeClass("hide");

                        break;
                    case 'ovs':
                        var networkOptions = '';
                        for (var i = 0; i < origovsNetworks.length; i++) {
                            if (networkName === origovsNetworks[i]) {
                                networkOptions += '<option selected="selected">' + origovsNetworks[i] + '</option>';
                            }else{
                                networkOptions += '<option>' + origovsNetworks[i] + '</option>';
                            }
                        }
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.network').append(networkOptions);

                        //initialize Mode option for ovs
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.mode').selectpicker('refresh');
                        $('span.mode .label-mode', nodeInterface).removeClass('hide');
                        $('span.mode .bootstrap-select', nodeInterface).addClass("hide");
                        break;
                    case 'network':
                        var networkOptions = '';
                        for (var i = 0; i < result.length; i++) {
                            if (networkName === result[i].name) {
                                networkOptions += '<option selected="selected">' + result[i].name + '</option>';
                            }else if (result[i].state === "active") {
                                networkOptions += '<option>' + result[i].name + '</option>';
                            }
                        }
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.network').append(networkOptions);

                        //initialize Mode option for Network
                        $('select', '#form-template-interface-s390x #networkID' + networkItemNum + ' span.mode').selectpicker('refresh');
                        $('span.mode .label-mode', nodeInterface).removeClass('hide');
                        $('span.mode .bootstrap-select', nodeInterface).addClass("hide");
                        break;
                }
                $('select', '#form-template-interface-s390x #networkID' + networkItemNum).selectpicker();
                networkItemNum += 1;
            };
            if (origInterfaces && origInterfaces.length > 0) {
                for (var i = 0; i < origInterfaces.length; i++) {
                    addInterfaceItem({
                        networkID: 'networkID' + networkItemNum,
                        networkV: origInterfaces[i].name,
                        type: origInterfaces[i].type,
                        mode: origInterfaces[i].mode
                    });
                }
            }
            if (result && result.length > 0) {
                for (var i = 0; i < origNetworks.length; i++) {
                    addInterfaceItem({
                        networkID: 'networkID' + networkItemNum,
                        networkV: origNetworks[i],
                        type: 'network'
                    });
                }
            }
            $('#template-edit-interface-add-button-s390x').on("click", function(event) {
                event.preventDefault();
                addInterfaceItem({
                    networkID: 'networkID' + networkItemNum,
                    networkV: 'default',
                    type: 'network',
                    mode: 'None'
                });
            });
        };

        var checkInvalids = function() {
            $.each(template.invalid, function(key, value) {
                if (key === 'cdrom' || key === 'vm-image') {
                    $('.tab-content input[name="' + key + '"]').attr('disabled', false).parent().addClass('has-error has-changes');
                    return true;
                } else if (key === 'storagepools') {
                    return true;
                } else {
                    return false;
                }
            });
        }

        if (kimchi.hostarch === s390xArch) {
            kimchi.listmacvtapNetworks(function(macvtapnet) {
                origmacvtapNetworks = macvtapnet;
                kimchi.listovsNetworks(function(ovsnet) {
                    origovsNetworks = ovsnet;
                    kimchi.listNetworks(initInterface_s390x);
                });
            });
            kimchi.listStoragePools(initStorage_s390);
        } else {
            kimchi.listNetworks(initInterface);
            kimchi.listStoragePools(initStorage);
        }

        kimchi.init_processor_tab(template.cpu_info, $('#tmpl-edit-button-save'));
        checkInvalids();
    };
    kimchi.retrieveTemplate(kimchi.selectedTemplate, initTemplate);

    $('#tmpl-edit-button-save').on('click', function() {
        $button = $(this);
        $button.html('<i class="wok-loading-icon fa fa-spinner fa-pulse fa-3x fa-fw"></i>' + i18n['KCHAPI6010M']);
        $button.prop('disabled', true);
        $('.modal .wok-mask').removeClass('hidden');
        $('.modal input[type="text"]').prop('disabled', true);
        $('.modal input[type="checkbox"]').prop('disabled', true);
        $('.modal select').prop('disabled', true);
        $('.modal .selectpicker').addClass('disabled');
        if(kimchi.hostarch === s390xArch){
            var editableFields = ['name', 'memory', 'graphics', 'max-memory', 'console'];
        }else {
            var editableFields = ['name', 'memory', 'graphics', 'max-memory'];
        }

        var data = {};
        var disks = $('.template-tab-body .item', '#form-template-storage');
        var disksForUpdate = new Array();
        $.each(disks, function(index, diskEntity) {
            if (kimchi.hostarch == s390xArch && ($(diskEntity).find('.template-storage-source').val()) == 'path') {
                var newDisk = {
                    'index': index,
                    'path': $(diskEntity).find('.template-storage-path').val(),
                    'size': Number($(diskEntity).find('.template-storage-disk').val()),
                    'format': $(diskEntity).find('.template-storage-disk-format').val()
                };
            } else {
                var newDisk = {
                    'index': index,
                    'pool': {
                        'name': '/plugins/kimchi/storagepools/' + $(diskEntity).find('.template-storage-name').val()
                    },
                    'size': Number($(diskEntity).find('.template-storage-disk').val()),
                    'format': $(diskEntity).find('.template-storage-disk-format').val()
                };
            }

            // image based template: add base to dictionary
            if ((baseImageTemplate) && (index == 0)) {
                newDisk["base"] = $('#template-edit-vmimage-textbox').val();
            }

            var storageType = $(diskEntity).find('.template-storage-type').val();
            if (storageType === 'iscsi' || storageType === 'scsi') {
                newDisk['volume'] = newDisk['pool']['name'].split('/').pop();
                newDisk['pool']['name'] = newDisk['pool']['name'].slice(0, newDisk['pool']['name'].lastIndexOf('/'));
                delete newDisk.size;
            }
            disksForUpdate.push(newDisk);
        });
        data.disks = disksForUpdate;

        $.each(editableFields, function(i, field) {
            if (field == 'graphics') {
                var type = $('#form-template-general [name="' + field + '"]').val();
                data[field] = { 'type': type };
            } else {
                data[field] = $('#form-template-general [name="' + field + '"]').val();
            }
        });
        data['memory'] = Number(data['memory']);
        data['max-memory'] = Number(data['max-memory']);

        memory = { 'current': data['memory'], 'maxmemory': data['max-memory'] };

        data['memory'] = memory;
        delete data['max-memory'];

        var cpu = parseInt($('#vcpus').val());
        var maxCpu = parseInt($('#guest-edit-max-processor-textbox').val());
        var maxCpuFinal = cpu; //Initially set maxCpu to be the same as cpu
        if (maxCpu >= cpu) {
            maxCpuFinal = maxCpu;
        }

        if ($('.tab-content .has-changes > input[name="cdrom"]').length) {
            data['cdrom'] = $('.tab-content input[name="cdrom"]').val();
        }

        if ($("input:checkbox", "#form-edit-processor").prop("checked")) {
            //Check if maxCpu field has a value
            data['cpu_info'] = {
                vcpus: cpu,
                maxvcpus: maxCpuFinal,
                topology: {
                    sockets: parseInt($("#sockets").val()),
                    cores: parseInt($("#cores").val()),
                    threads: parseInt($("#threads").val())
                }
            };
        } else {
            data['cpu_info'] = {
                vcpus: cpu,
                maxvcpus: maxCpuFinal,
                topology: {}
            };
        }

        if(kimchi.hostarch === s390xArch){
            var interfaces = $('.template-tab-body .item', '#form-template-interface-s390x');
            var networkForUpdate = new Array();
            var interfacceForUpdate = new Array();

            $.each(interfaces, function(index, interfaceEntities) {
                var fields =  $('span.type select', interfaceEntities);
                switch(fields.val()){
                    case 'network':
                        var thisValue = $('span.network select', interfaceEntities).val();
                        networkForUpdate.push(thisValue);
                    break;
                    case 'macvtap':
                        var thisdata = {};
                        thisdata.type = $('span.type select', interfaceEntities).val();
                        thisdata.name = $('span.network select', interfaceEntities).val();
                        thisdata.mode = $('span.mode select', interfaceEntities).val();
                        interfacceForUpdate.push(thisdata);
                    break;
                    case 'ovs':
                        var thisdata = {};
                        thisdata.type = $('span.type select', interfaceEntities).val();
                        thisdata.name = $('span.network select', interfaceEntities).val();
                        interfacceForUpdate.push(thisdata);
                    break;
                }
            });

            if (networkForUpdate instanceof Array) {
                data.networks = networkForUpdate;
            } else if (networkForUpdate != null) {
                data.networks = [networkForUpdate];
            } else {
                data.networks = [];
            }

            if (interfacceForUpdate instanceof Array) {
                data.interfaces = interfacceForUpdate;
            } else if (interfacceForUpdate != null) {
                data.interfaces = [interfacceForUpdate];
            } else {
                data.interfaces = [];
            }
        }else {
            var networks = $('.template-tab-body .item', '#form-template-interface');
            var networkForUpdate = new Array();
            $.each(networks, function(index, networkEntities) {
                var thisValue = $('select', networkEntities).val();
                networkForUpdate.push(thisValue);
            });

            if (networkForUpdate instanceof Array) {
                data.networks = networkForUpdate;
            } else if (networkForUpdate != null) {
                data.networks = [networkForUpdate];
            } else {
                data.networks = [];
            }
        }

        if ($('.has-error', '#form-template-storage').length) {
            // Workaround to check if invalid storage wasn't changed
            $('a[href="#storage"]', '#edit-template-tabs').tab('show');
            $('.modal .wok-mask').addClass('hidden');
            $button.html(i18n['KCHAPI6007M']);
            $button.prop('disabled', false);
            $('.modal input[type="text"]').prop('disabled', false);
            $('.modal input[type="checkbox"]').prop('disabled', false);
            $('.modal select').prop('disabled', false);
            $('.modal .selectpicker').removeClass('disabled');
            if(kimchi.hostarch === s390xArch){
                wok.message.error(i18n['KCHTMPL6008M'], '#alert-modal-container');
            }else{
                wok.message.error(i18n['KCHTMPL6007M'], '#alert-modal-container');
            }
        } else {
            kimchi.updateTemplate($('#template-name').val(), data, function() {
                kimchi.doListTemplates();
                wok.window.close();
            }, function(err) {
            $('.modal .wok-mask').addClass('hidden');
                $button.html(i18n['KCHAPI6007M']);
                $button.prop('disabled', false);
                $('.modal input[type="text"]').prop('disabled', false);
                $('.modal input[type="checkbox"]').prop('disabled', false);
                $('.modal select').prop('disabled', false);
                $('.modal .selectpicker').removeClass('disabled');
                wok.message.error(err.responseJSON.reason, '#alert-modal-container');
            });
        }
    });
};
/*
 * Project Kimchi
 *
 * Copyright IBM Corp, 2013-2017
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0invalid_indicator_template
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

kimchi.doListTemplates = function() {
    $('.wok-mask').removeClass('hidden');
    kimchi.listTemplates(function(result) {
        if (result && result.length) {
            $('#noTemplates').hide();
            var listHtml = '';
            var templateHtml = $('#templateTmpl').html();
            $.each(result, function(index, value) {
                value.invalid_indicator = "invalid";
                if ($.isEmptyObject(value.invalid)) {
                    value.invalid_indicator = "valid";
                }
                if (typeof templateHtml !== 'undefined') {
                    listHtml += wok.substitute(templateHtml, value);
                }
            });
            $('ul#templates-grid').removeClass('hidden');
            $('#templates-container').removeClass('hidden');
            $('#templateList').html(listHtml);
            kimchi.templateBindClick();
            $('.wok-mask').fadeOut(300, function() {});
            $('.template-status[data-invalid="valid"]').hide();
        } else {
            $('#templateList').html('');
            $('#noTemplates').show();
            $('ul#templates-grid').addClass('hidden');
            $('#templates-container').addClass('hidden');
            $('.wok-mask').fadeOut(300, function() {});
        }

        var options = {
            valueNames: ['name-filter', 'os-type-filter', 'os-version-filter', 'cpus-filter', 'memory-filter']
        };
        var templatesList = new List('templates-container', options);
        $('[data-invalid="invalid"][data-toggle="tooltip"]').tooltip();
    }, function(err) {
        wok.message.error(err.responseJSON.reason);
        $('.wok-mask').fadeOut(300, function() {
            $('.wok-mask').addClass('hidden');
        });
    });
};

kimchi.toggleTemplatesGallery = function() {
    $(".wok-vm-list, .wok-vm-gallery").toggleClass("wok-vm-list wok-vm-gallery");
    $(".wok-list, .wok-gallery").toggleClass("wok-list wok-gallery");
    var text = $('#gallery-table-button span.text').text();
    $('#gallery-table-button span.text').text(text == i18n['KCHTMPL6005M'] ? i18n['KCHTMPL6004M'] : i18n['KCHTMPL6005M']);
    var buttonText = $('#gallery-table-button span.text').text();
    if (buttonText.indexOf("Gallery") !== -1) {
        // Currently in list view
        kimchi.setTemplateView("templateView", "list");
    } else {
        // Currently in gallery
        kimchi.setTemplateView("templateView", "gallery");
    }
};

kimchi.setTemplateView = function(name, value) {
    window.localStorage.setItem(name, value);
};

kimchi.readTemplateView = function(name) {
    var viewName = window.localStorage.getItem(name);
    if (viewName !== "") {
        return viewName;
    } else {
        return null;
    }
};

kimchi.showTemplateGallery = function() {
    $(".wok-vm-list").addClass("wok-vm-gallery");
    $(".wok-list").addClass("wok-gallery");
    $(".wok-vm-gallery").removeClass("wok-vm-list");
    $(".wok-gallery").removeClass("wok-list");
    $('#gallery-table-button span.text').text(i18n['KCHTMPL6004M']);
};

kimchi.showTemplateList = function() {
    $(".wok-vm-gallery").addClass("wok-vm-list");
    $(".wok-gallery").addClass("wok-list");
    $(".wok-vm-list").removeClass("wok-vm-gallery");
    $(".wok-list").removeClass("wok-gallery");
    $('#gallery-table-button span.text').text(i18n['KCHTMPL6005M']);
};

kimchi.templateBindClick = function() {
    $('.template-edit a').on('click', function(event) {
        event.preventDefault();
        var templateName = $(this).data('template');
        kimchi.selectedTemplate = templateName;
        wok.window.open("plugins/kimchi/template-edit.html");
    });
    $('.template-clone a').on('click', function(event) {
        event.preventDefault();
        kimchi.selectedTemplate = $(this).data('template');
        $('.wok-mask').removeClass('hidden');
        kimchi.cloneTemplate(kimchi.selectedTemplate, function() {
            kimchi.doListTemplates();
        }, function(err) {
            wok.message.error(err.responseJSON.reason);
            kimchi.doListTemplates();
        });
    });
    $('.template-delete a').on('click', function(event) {
        event.preventDefault();
        var $template = $(this);
        var templateName = $template.data('template');
        var confirmMessage = i18n['KCHTMPL6003M'].replace('%1', '<strong>'+templateName+'</strong>');
        var settings = {
            title: i18n['KCHAPI6001M'],
            content: confirmMessage,
            confirm: i18n['KCHAPI6002M'],
            cancel: i18n['KCHAPI6003M']
        };
        wok.confirm(settings, function() {
            kimchi.deleteTemplate(templateName, function() {
                kimchi.doListTemplates();
            }, function(err) {
                wok.message.error(err.responseJSON.reason);
            });
        }, function() {});
    });

    $('#gallery-table-button').on('click', function(event) {
        kimchi.toggleTemplatesGallery();
    });

    $('.sort').on('click', function(event) {
        event.preventDefault();
        $('.filter-option').text($(this).text());
    });

}
kimchi.hideTitle = function() {
    $('#tempTitle').hide();
};

kimchi.template_main = function() {
    $('body').addClass('wok-list');

    var toolsHtml = '<li><a id="template-add" class="btn-tool" href="javascript:void(0);">'
    toolsHtml += '<i class="fa fa-plus-circle"></i><span>' + i18n['KCHTMPL6001M'] + '</span></a></li>'

    var viewFound = kimchi.readTemplateView("templateView");
    if (viewFound) {
        if(viewFound === "gallery") {
            // should be showing gallery
            kimchi.showTemplateGallery();
        } else {
            // Should be showing list
            kimchi.showTemplateList();
       }
    } else {
        // Default to showing list
        kimchi.showTemplateList();
    }

    if (wok.tabMode['templates'] === 'admin') {
        $('#toolbar ul.tools').html(toolsHtml);
        $("#template-add").on("click", function(event) {
            wok.window.open({
                url: 'plugins/kimchi/template-add.html',
                close: function() {
                    if (kimchi.deepScanHandler) {
                        kimchi.deepScanHandler.stop = true;
                    }
                }
            });
        });
    }

    // Register listeners to update the page according to user interactions
    wok.addNotificationListener('POST:/kimchi/templates', kimchi.doListTemplates);
    wok.addNotificationListener('DELETE:/kimchi/template', kimchi.doListTemplates);
    wok.addNotificationListener('PUT:/kimchi/template', kimchi.doListTemplates);

    kimchi.doListTemplates();
};
//# sourceURL=kimchi.min.js
